# generated by datamodel-codegen:
#   filename:  openapi.json
#   timestamp: 2026-02-20T16:29:25+00:00

from __future__ import annotations

from pydantic import Field

from gbizinfo.models._base import BaseModel


class ApiError(BaseModel):
    item: str | None = None
    """
    エラー箇所(項目)
    """
    message: str | None = None
    """
    エラーメッセージ
    """


class ChildMetadata(BaseModel):
    data_quality: str | None = None
    """
    データ品質
    """
    import_frequency: str | None = None
    """
    データ取込頻度
    """
    key_field: str | None = None
    """
    キー情報
    """
    last_acquisition_date: str | None = None
    """
    最終取得日
    """
    last_update_date: str | None = None
    """
    最終更新日
    """
    source: str | None = None
    """
    出典元
    """


class CommendationInfoV2(BaseModel):
    category: str | None = None
    """
    部門
    """
    date_of_commendation: str | None = None
    """
    年月日
    """
    government_departments: str | None = None
    """
    府省
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    note: str | None = None
    """
    備考
    """
    target: str | None = None
    """
    受賞対象
    """
    title: str | None = None
    """
    表彰名
    """


class CompatibilityOfChildcareAndWorkV2(BaseModel):
    maternity_leave_acquisition_num: int | None = None
    """
    育児休業取得者数（女性）
    """
    number_of_maternity_leave: int | None = None
    """
    育児休業対象者数（女性）
    """
    number_of_paternity_leave: int | None = None
    """
    育児休業対象者数（男性）
    """
    paternity_leave_acquisition_num: int | None = None
    """
    育児休業取得者数（男性）
    """


class CorporationInfo(BaseModel):
    corporation_location: str | None = None
    """
    事業所所在地
    """
    corporation_location_furigana: str | None = None
    """
    事業所所在地フリガナ
    """
    corporation_name: str | None = None
    """
    事業所名
    """
    corporation_name_furigana: str | None = None
    """
    事業所名フリガナ
    """
    insured_number: str | None = None
    """
    被保険者数
    """
    loss_date: str | None = None
    """
    全喪年月日
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """


class HojinInfoSearchV2(BaseModel):
    corporate_number: str = Field(..., min_length=1, pattern='^(\\s*|\\d{13})$')
    """
    法人番号
    """
    location: str | None = Field(None, max_length=200, min_length=0)
    """
    本社所在地
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    name: str | None = Field(None, max_length=200, min_length=0)
    """
    法人名
    """
    name_en: str | None = Field(
        None, max_length=200, min_length=0, pattern='^[a-zA-Z0-9 -/:-@\\[-\\`\\{-\\~]*$'
    )
    """
    法人名英語
    """
    number_of_activity: str | None = None
    """
    法人活動情報件数
    """
    postal_code: str | None = Field(None, pattern='^(\\s*|\\d{7})$')
    """
    郵便番号
    """
    status: str | None = None
    """
    ステータス
    """
    update_date: str | None = None
    """
    更新年月日
    """


class MajorShareholders(BaseModel):
    name_major_shareholders: str | None = Field(None, max_length=200, min_length=0)
    """
    氏名又は名称
    """
    shareholding_ratio: float | None = None
    """
    発行済株式総数に対する所有株式数の割合
    """


class ManagementIndex(BaseModel):
    capital_stock_summary_of_business_results: int | None = None
    """
    資本金
    """
    capital_stock_summary_of_business_results_unit_ref: str | None = None
    """
    資本金(単位)
    """
    gross_operating_revenue_summary_of_business_results: int | None = None
    """
    営業総収入
    """
    gross_operating_revenue_summary_of_business_results_unit_ref: str | None = None
    """
    営業総収入（単位）
    """
    net_assets_summary_of_business_results: int | None = None
    """
    純資産額
    """
    net_assets_summary_of_business_results_unit_ref: str | None = None
    """
    純資産額(単位)
    """
    net_income_loss_summary_of_business_results: int | None = None
    """
    当期純利益又は当期純損失(△)
    """
    net_income_loss_summary_of_business_results_unit_ref: str | None = None
    """
    当期純利益又は当期純損失(△)(単位)
    """
    net_premiums_written_summary_of_business_results_ins: int | None = None
    """
    正味収入保険料
    """
    net_premiums_written_summary_of_business_results_ins_unit_ref: str | None = None
    """
    正味収入保険料（単位）
    """
    net_sales_summary_of_business_results: int | None = None
    """
    売上高
    """
    net_sales_summary_of_business_results_unit_ref: str | None = None
    """
    売上高(単位)
    """
    number_of_employees: int | None = None
    """
    従業員数
    """
    number_of_employees_unit_ref: str | None = None
    """
    従業員数(単位)
    """
    operating_revenue1_summary_of_business_results: int | None = None
    """
    営業収益
    """
    operating_revenue1_summary_of_business_results_unit_ref: str | None = None
    """
    営業収益（単位）
    """
    operating_revenue2_summary_of_business_results: int | None = None
    """
    営業収入
    """
    operating_revenue2_summary_of_business_results_unit_ref: str | None = None
    """
    営業収入（単位）
    """
    ordinary_income_loss_summary_of_business_results: int | None = None
    """
    経常利益又は経常損失(△)
    """
    ordinary_income_loss_summary_of_business_results_unit_ref: str | None = None
    """
    経常利益又は経常損失(△)(単位)
    """
    ordinary_income_summary_of_business_results: int | None = None
    """
    経常収益
    """
    ordinary_income_summary_of_business_results_unit_ref: str | None = None
    """
    経常収益（単位）
    """
    period: str | None = None
    """
    回次
    """
    total_assets_summary_of_business_results: int | None = None
    """
    総資産額
    """
    total_assets_summary_of_business_results_unit_ref: str | None = None
    """
    総資産額(単位)
    """


class MetadataDataQuality(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分(メタデータ)
    """
    business_items: str | None = None
    """
    全省庁統一資格の営業品目(メタデータ)
    """
    business_summary: str | None = None
    """
    事業概要(メタデータ)
    """
    capital_stock: str | None = None
    """
    資本金(メタデータ)
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由(メタデータ)
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日(メタデータ)
    """
    company_size_female: str | None = None
    """
    企業規模詳細(女性)(メタデータ)
    """
    company_size_male: str | None = None
    """
    企業規模詳細(男性)(メタデータ)
    """
    company_url: str | None = None
    """
    企業ホームページ(メタデータ)
    """
    corporate_number: str | None = None
    """
    法人番号(メタデータ)
    """
    date_of_establishment: str | None = None
    """
    設立年月日(メタデータ)
    """
    employee_number: str | None = None
    """
    従業員数(メタデータ)
    """
    founding_year: str | None = None
    """
    創業年(メタデータ)
    """
    industry: str | None = None
    """
    業種(メタデータ)
    """
    kana: str | None = None
    """
    法人名フリガナ(メタデータ)
    """
    kind: str | None = None
    """
    法人種別(メタデータ)
    """
    location: str | None = None
    """
    本社所在地(メタデータ)
    """
    name: str | None = None
    """
    法人名(メタデータ)
    """
    name_en: str | None = None
    """
    法人名英語(メタデータ)
    """
    postal_code: str | None = None
    """
    郵便番号(メタデータ)
    """
    process: str | None = None
    """
    処理区分(メタデータ)
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)(メタデータ)
    """
    representative_name: str | None = None
    """
    法人代表者名(メタデータ)
    """
    status: str | None = None
    """
    ステータス(メタデータ)
    """
    update_date: str | None = None
    """
    更新年月日(メタデータ)
    """


class MetadataImportFrequency(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分(メタデータ)
    """
    business_items: str | None = None
    """
    全省庁統一資格の営業品目(メタデータ)
    """
    business_summary: str | None = None
    """
    事業概要(メタデータ)
    """
    capital_stock: str | None = None
    """
    資本金(メタデータ)
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由(メタデータ)
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日(メタデータ)
    """
    company_size_female: str | None = None
    """
    企業規模詳細(女性)(メタデータ)
    """
    company_size_male: str | None = None
    """
    企業規模詳細(男性)(メタデータ)
    """
    company_url: str | None = None
    """
    企業ホームページ(メタデータ)
    """
    corporate_number: str | None = None
    """
    法人番号(メタデータ)
    """
    date_of_establishment: str | None = None
    """
    設立年月日(メタデータ)
    """
    employee_number: str | None = None
    """
    従業員数(メタデータ)
    """
    founding_year: str | None = None
    """
    創業年(メタデータ)
    """
    industry: str | None = None
    """
    業種(メタデータ)
    """
    kana: str | None = None
    """
    法人名フリガナ(メタデータ)
    """
    kind: str | None = None
    """
    法人種別(メタデータ)
    """
    location: str | None = None
    """
    本社所在地(メタデータ)
    """
    name: str | None = None
    """
    法人名(メタデータ)
    """
    name_en: str | None = None
    """
    法人名英語(メタデータ)
    """
    postal_code: str | None = None
    """
    郵便番号(メタデータ)
    """
    process: str | None = None
    """
    処理区分(メタデータ)
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)(メタデータ)
    """
    representative_name: str | None = None
    """
    法人代表者名(メタデータ)
    """
    status: str | None = None
    """
    ステータス(メタデータ)
    """
    update_date: str | None = None
    """
    更新年月日(メタデータ)
    """


class MetadataLastAcquisitionDate(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分(メタデータ)
    """
    business_items: str | None = None
    """
    全省庁統一資格の営業品目(メタデータ)
    """
    business_summary: str | None = None
    """
    事業概要(メタデータ)
    """
    capital_stock: str | None = None
    """
    資本金(メタデータ)
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由(メタデータ)
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日(メタデータ)
    """
    company_size_female: str | None = None
    """
    企業規模詳細(女性)(メタデータ)
    """
    company_size_male: str | None = None
    """
    企業規模詳細(男性)(メタデータ)
    """
    company_url: str | None = None
    """
    企業ホームページ(メタデータ)
    """
    corporate_number: str | None = None
    """
    法人番号(メタデータ)
    """
    date_of_establishment: str | None = None
    """
    設立年月日(メタデータ)
    """
    employee_number: str | None = None
    """
    従業員数(メタデータ)
    """
    founding_year: str | None = None
    """
    創業年(メタデータ)
    """
    industry: str | None = None
    """
    業種(メタデータ)
    """
    kana: str | None = None
    """
    法人名フリガナ(メタデータ)
    """
    kind: str | None = None
    """
    法人種別(メタデータ)
    """
    location: str | None = None
    """
    本社所在地(メタデータ)
    """
    name: str | None = None
    """
    法人名(メタデータ)
    """
    name_en: str | None = None
    """
    法人名英語(メタデータ)
    """
    postal_code: str | None = None
    """
    郵便番号(メタデータ)
    """
    process: str | None = None
    """
    処理区分(メタデータ)
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)(メタデータ)
    """
    representative_name: str | None = None
    """
    法人代表者名(メタデータ)
    """
    status: str | None = None
    """
    ステータス(メタデータ)
    """
    update_date: str | None = None
    """
    更新年月日(メタデータ)
    """


class MetadataLastUpdateDate(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分(メタデータ)
    """
    business_items: str | None = None
    """
    全省庁統一資格の営業品目(メタデータ)
    """
    business_summary: str | None = None
    """
    事業概要(メタデータ)
    """
    capital_stock: str | None = None
    """
    資本金(メタデータ)
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由(メタデータ)
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日(メタデータ)
    """
    company_size_female: str | None = None
    """
    企業規模詳細(女性)(メタデータ)
    """
    company_size_male: str | None = None
    """
    企業規模詳細(男性)(メタデータ)
    """
    company_url: str | None = None
    """
    企業ホームページ(メタデータ)
    """
    corporate_number: str | None = None
    """
    法人番号(メタデータ)
    """
    date_of_establishment: str | None = None
    """
    設立年月日(メタデータ)
    """
    employee_number: str | None = None
    """
    従業員数(メタデータ)
    """
    founding_year: str | None = None
    """
    創業年(メタデータ)
    """
    industry: str | None = None
    """
    業種(メタデータ)
    """
    kana: str | None = None
    """
    法人名フリガナ(メタデータ)
    """
    kind: str | None = None
    """
    法人種別(メタデータ)
    """
    location: str | None = None
    """
    本社所在地(メタデータ)
    """
    name: str | None = None
    """
    法人名(メタデータ)
    """
    name_en: str | None = None
    """
    法人名英語(メタデータ)
    """
    postal_code: str | None = None
    """
    郵便番号(メタデータ)
    """
    process: str | None = None
    """
    処理区分(メタデータ)
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)(メタデータ)
    """
    representative_name: str | None = None
    """
    法人代表者名(メタデータ)
    """
    status: str | None = None
    """
    ステータス(メタデータ)
    """
    update_date: str | None = None
    """
    更新年月日(メタデータ)
    """


class MetadataSource(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分(メタデータ)
    """
    business_items: str | None = None
    """
    全省庁統一資格の営業品目(メタデータ)
    """
    business_summary: str | None = None
    """
    事業概要(メタデータ)
    """
    capital_stock: str | None = None
    """
    資本金(メタデータ)
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由(メタデータ)
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日(メタデータ)
    """
    company_size_female: str | None = None
    """
    企業規模詳細(女性)(メタデータ)
    """
    company_size_male: str | None = None
    """
    企業規模詳細(男性)(メタデータ)
    """
    company_url: str | None = None
    """
    企業ホームページ(メタデータ)
    """
    corporate_number: str | None = None
    """
    法人番号(メタデータ)
    """
    date_of_establishment: str | None = None
    """
    設立年月日(メタデータ)
    """
    employee_number: str | None = None
    """
    従業員数(メタデータ)
    """
    founding_year: str | None = None
    """
    創業年(メタデータ)
    """
    industry: str | None = None
    """
    業種(メタデータ)
    """
    kana: str | None = None
    """
    法人名フリガナ(メタデータ)
    """
    kind: str | None = None
    """
    法人種別(メタデータ)
    """
    location: str | None = None
    """
    本社所在地(メタデータ)
    """
    name: str | None = None
    """
    法人名(メタデータ)
    """
    name_en: str | None = None
    """
    法人名英語(メタデータ)
    """
    postal_code: str | None = None
    """
    郵便番号(メタデータ)
    """
    process: str | None = None
    """
    処理区分(メタデータ)
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)(メタデータ)
    """
    representative_name: str | None = None
    """
    法人代表者名(メタデータ)
    """
    status: str | None = None
    """
    ステータス(メタデータ)
    """
    update_date: str | None = None
    """
    更新年月日(メタデータ)
    """


class PatentInfoV2(BaseModel):
    application_date: str | None = None
    """
    出願年月日
    """
    classifications: list[dict[str, str]] | None = None
    """
    分類
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    patent_type: str | None = None
    """
    特許/意匠/商標
    """
    registration_number: str | None = None
    """
    登録番号
    """
    title: str | None = None
    """
    発明の名称(等)/意匠に係る物品/表示用商標
    """
    url: str | None = None
    """
    文献固定アドレス
    """


class ProcurementInfoV2(BaseModel):
    amount: int | None = None
    """
    金額
    """
    date_of_order: str | None = None
    """
    受注日
    """
    government_departments: str | None = None
    """
    府省
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    note: str | None = None
    """
    備考
    """
    title: str | None = None
    """
    事業名
    """


class SubsidyInfoV2(BaseModel):
    amount: str | None = None
    """
    金額
    """
    date_of_approval: str | None = None
    """
    認定日
    """
    government_departments: str | None = None
    """
    府省
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    target: str | None = None
    """
    対象
    """
    title: str | None = None
    """
    補助金等
    """


class WomenActivityInfosV2(BaseModel):
    female_share_of_manager: int | None = None
    """
    女性管理職人数
    """
    female_share_of_officers: int | None = None
    """
    女性役員人数
    """
    female_workers_proportion: float | None = None
    """
    労働者に占める女性労働者の割合
    """
    female_workers_proportion_type: str | None = None
    """
    労働者に占める女性労働者の割合-範囲
    """
    gender_total_of_manager: int | None = None
    """
    管理職全体人数（男女計）
    """
    gender_total_of_officers: int | None = None
    """
    役員全体人数（男女計）
    """


class WorkplaceBaseInfosV2(BaseModel):
    average_age: float | None = None
    """
    従業員の平均年齢
    """
    average_continuous_service_years: float | None = None
    """
    正社員の平均継続勤務年数
    """
    average_continuous_service_years_Female: float | None = None
    """
    平均継続勤務年数-女性
    """
    average_continuous_service_years_Male: float | None = None
    """
    平均継続勤務年数-男性
    """
    average_continuous_service_years_type: str | None = None
    """
    平均継続勤務年数-範囲
    """
    month_average_predetermined_overtime_hours: float | None = None
    """
    月平均所定外労働時間
    """


class WorkplaceInfoBeanV2(BaseModel):
    base_infos: WorkplaceBaseInfosV2 | None = None
    """
    勤務基本情報
    """
    compatibility_of_childcare_and_work: CompatibilityOfChildcareAndWorkV2 | None = None
    """
    育児・仕事の両立に関する情報
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    women_activity_infos: WomenActivityInfosV2 | None = None
    """
    女性の活躍に関する情報
    """


class CertificationInfoV2(BaseModel):
    category: str | None = None
    """
    部門
    """
    date_of_approval: str | None = None
    """
    認定日
    """
    government_departments: str | None = None
    """
    府省
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    target: str | None = None
    """
    対象
    """
    title: str | None = None
    """
    届出認定等
    """


class FinanceV2(BaseModel):
    accounting_standards: str | None = None
    """
    会計基準
    """
    fiscal_year_cover_page: str | None = None
    """
    事業年度
    """
    major_shareholders: list[MajorShareholders] | None = None
    """
    大株主
    """
    management_index: list[ManagementIndex] | None = None
    """
    財務
    """
    meta_data: ChildMetadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """


class HojinInfoForChildV2(BaseModel):
    certification: list[CertificationInfoV2] | None = None
    """
    届出・認定情報
    """
    commendation: list[CommendationInfoV2] | None = None
    """
    表彰情報
    """
    corporate_number: str = Field(..., min_length=1, pattern='^(\\s*|\\d{13})$')
    """
    法人番号
    """
    corporation_info: list[CorporationInfo] | None = Field(
        None, alias='corporation-info'
    )
    """
    事業所情報
    """
    finance: FinanceV2 | None = None
    """
    財務情報
    """
    location: str | None = Field(None, max_length=200, min_length=0)
    """
    本社所在地
    """
    name: str | None = Field(None, max_length=200, min_length=0)
    """
    法人名
    """
    patent: list[PatentInfoV2] | None = None
    """
    特許情報
    """
    procurement: list[ProcurementInfoV2] | None = None
    """
    調達情報
    """
    subsidy: list[SubsidyInfoV2] | None = None
    """
    補助金情報
    """
    workplace_info: WorkplaceInfoBeanV2 | None = None
    """
    職場情報
    """


class HojinInfoResponseForChildV2(BaseModel):
    errors: list[ApiError] | None = None
    """
    エラー情報(エラーがある場合に出力します。)
    """
    hojin_infos: list[HojinInfoForChildV2] | None = Field(None, alias='hojin-infos')
    """
    gBizINFOデータ
    """
    id: str | None = None
    """
    ID
    """
    message: str | None = None
    """
    メッセージ
    """


class HojinInfoResponseSearchV2(BaseModel):
    errors: list[ApiError] | None = None
    """
    エラー情報(エラーがある場合に出力します。)
    """
    hojin_infos: list[HojinInfoSearchV2] | None = Field(None, alias='hojin-infos')
    """
    gBizINFOデータ
    """
    id: str | None = None
    """
    ID
    """
    message: str | None = None
    """
    メッセージ
    """


class HojinInfoUpdateInfoResponseForChildV2(BaseModel):
    errors: list[ApiError] | None = None
    """
    エラー情報(エラーがある場合に出力します。)
    """
    hojin_infos: list[HojinInfoForChildV2] | None = Field(None, alias='hojin-infos')
    """
    gBizINFOデータ
    """
    id: str | None = None
    """
    ID
    """
    message: str | None = None
    """
    メッセージ
    """
    pageNumber: str | None = None
    """
    ページ番号
    """
    totalCount: str | None = None
    """
    総件数
    """
    totalPage: str | None = None
    """
    総ページ数
    """


class Metadata(BaseModel):
    data_quality: MetadataDataQuality | None = None
    """
    データ品質
    """
    import_frequency: MetadataImportFrequency | None = None
    """
    データ取込頻度
    """
    key_field: str | None = None
    """
    キー情報
    """
    last_acquisition_date: MetadataLastAcquisitionDate | None = None
    """
    最終取得日
    """
    last_update_date: MetadataLastUpdateDate | None = None
    """
    最終更新日
    """
    source: MetadataSource | None = None
    """
    出典元
    """


class HojinInfoV2(BaseModel):
    aggregated_year: str | None = None
    """
    訂正区分
    """
    business_items: list[str] | None = None
    """
    全省庁統一資格の営業品目
    """
    business_summary: str | None = None
    """
    事業概要
    """
    capital_stock: int | None = None
    """
    資本金
    """
    certification: list[CertificationInfoV2] | None = None
    """
    届出・認定情報
    """
    close_cause: str | None = None
    """
    登記記録の閉鎖等の事由
    """
    close_date: str | None = None
    """
    登記記録の閉鎖等年月日
    """
    commendation: list[CommendationInfoV2] | None = None
    """
    表彰情報
    """
    company_size_female: int | None = None
    """
    企業規模詳細(女性)
    """
    company_size_male: int | None = None
    """
    企業規模詳細(男性)
    """
    company_url: str | None = None
    """
    企業ホームページ
    """
    corporate_number: str = Field(..., min_length=1, pattern='^(\\s*|\\d{13})$')
    """
    法人番号
    """
    corporation_info: list[CorporationInfo] | None = Field(
        None, alias='corporation-info'
    )
    """
    事業所情報
    """
    date_of_establishment: str | None = None
    """
    設立年月日
    """
    employee_number: int | None = None
    """
    従業員数
    """
    finance: FinanceV2 | None = None
    """
    財務情報
    """
    founding_year: int | None = None
    """
    創業年
    """
    industry: list[str] | None = None
    """
    業種
    """
    kana: str | None = Field(None, max_length=200, min_length=0)
    """
    法人名フリガナ
    """
    kind: str | None = None
    """
    法人種別
    """
    location: str | None = Field(None, max_length=200, min_length=0)
    """
    本社所在地
    """
    meta_data: Metadata | None = Field(None, alias='meta-data')
    """
    メタデータ
    """
    name: str | None = Field(None, max_length=200, min_length=0)
    """
    法人名
    """
    name_en: str | None = Field(
        None, max_length=200, min_length=0, pattern='^[a-zA-Z0-9 -/:-@\\[-\\`\\{-\\~]*$'
    )
    """
    法人名英語
    """
    patent: list[PatentInfoV2] | None = None
    """
    特許情報
    """
    postal_code: str | None = Field(None, pattern='^(\\s*|\\d{7})$')
    """
    郵便番号
    """
    process: str | None = None
    """
    処理区分
    """
    procurement: list[ProcurementInfoV2] | None = None
    """
    調達情報
    """
    qualification_grade: str | None = None
    """
    全省庁統一資格の資格等級(物品の製造、物品の販売、役務の提供等、物品の買受け)
    """
    representative_name: str | None = Field(None, max_length=200, min_length=0)
    """
    法人代表者名
    """
    status: str | None = None
    """
    ステータス
    """
    subsidy: list[SubsidyInfoV2] | None = None
    """
    補助金情報
    """
    update_date: str | None = None
    """
    更新年月日
    """
    workplace_info: WorkplaceInfoBeanV2 | None = None
    """
    職場情報
    """


class HojinInfoResponseV2(BaseModel):
    errors: list[ApiError] | None = None
    """
    エラー情報(エラーがある場合に出力します。)
    """
    hojin_infos: list[HojinInfoV2] | None = Field(None, alias='hojin-infos')
    """
    gBizINFOデータ
    """
    id: str | None = None
    """
    ID
    """
    message: str | None = None
    """
    メッセージ
    """


class HojinInfoUpdateInfoResponseV2(BaseModel):
    errors: list[ApiError] | None = None
    """
    エラー情報(エラーがある場合に出力します。)
    """
    hojin_infos: list[HojinInfoV2] | None = Field(None, alias='hojin-infos')
    """
    gBizINFOデータ
    """
    id: str | None = None
    """
    ID
    """
    message: str | None = None
    """
    メッセージ
    """
    pageNumber: str | None = None
    """
    ページ番号
    """
    totalCount: str | None = None
    """
    総件数
    """
    totalPage: str | None = None
    """
    総ページ数
    """
