"""データモデル。"""

from gbizinfo.models._generated import (
    ApiError,
    CertificationInfoV2,
    ChildMetadata,
    CommendationInfoV2,
    CompatibilityOfChildcareAndWorkV2,
    CorporationInfo,
    FinanceV2,
    HojinInfoForChildV2,
    HojinInfoResponseForChildV2,
    HojinInfoResponseSearchV2,
    HojinInfoResponseV2,
    HojinInfoSearchV2,
    HojinInfoUpdateInfoResponseForChildV2,
    HojinInfoUpdateInfoResponseV2,
    HojinInfoV2,
    MajorShareholders,
    ManagementIndex,
    Metadata,
    PatentInfoV2,
    ProcurementInfoV2,
    SubsidyInfoV2,
    WomenActivityInfosV2,
    WorkplaceBaseInfosV2,
    WorkplaceInfoBeanV2,
)
from gbizinfo.models.responses import (
    HojinInfo,
    HojinInfoSearch,
    ListStrategy,
    SearchResult,
    UpdateResult,
)

__all__ = [
    "ApiError",
    "CertificationInfoV2",
    "ChildMetadata",
    "CommendationInfoV2",
    "CompatibilityOfChildcareAndWorkV2",
    "CorporationInfo",
    "FinanceV2",
    "HojinInfo",
    "HojinInfoForChildV2",
    "HojinInfoResponseForChildV2",
    "HojinInfoResponseSearchV2",
    "HojinInfoResponseV2",
    "HojinInfoSearch",
    "HojinInfoSearchV2",
    "HojinInfoUpdateInfoResponseForChildV2",
    "HojinInfoUpdateInfoResponseV2",
    "HojinInfoV2",
    "ListStrategy",
    "MajorShareholders",
    "ManagementIndex",
    "Metadata",
    "PatentInfoV2",
    "ProcurementInfoV2",
    "SearchResult",
    "SubsidyInfoV2",
    "UpdateResult",
    "WomenActivityInfosV2",
    "WorkplaceBaseInfosV2",
    "WorkplaceInfoBeanV2",
]
