"""担当府省コードの列挙型モジュール。

gBizINFO API の担当府省コードに対応する StrEnum を定義する。
"""

from __future__ import annotations

from enum import StrEnum


class Ministry(StrEnum):
    """担当府省の列挙型。

    gBizINFO API で使用される担当府省コードを定義する。
    検索時に ministry パラメータとして指定する。
    """

    国税庁 = "1"
    会計検査院 = "2"
    内閣官房 = "3"
    人事院 = "4"
    内閣府 = "5"
    宮内庁 = "6"
    国家公安委員会 = "7"
    防衛省 = "8"
    金融庁 = "9"
    総務省 = "10"
    法務省 = "11"
    外務省 = "12"
    財務省 = "13"
    文部科学省 = "14"
    厚生労働省 = "15"
    農林水産省 = "16"
    経済産業省 = "17"
    国土交通省 = "18"
    環境省 = "19"
    消費者庁 = "20"
    復興庁 = "21"
    公正取引委員会 = "22"
    個人情報保護委員会 = "23"
    特許庁 = "24"
    消防庁 = "25"
    資源エネルギー庁 = "26"
    中小企業庁 = "27"
    情報処理推進機構 = "28"
    製品評価技術基盤機構 = "29"
    国立研究開発法人新エネルギー産業技術総合開発機構 = "30"
    工業所有権情報研修館 = "31"
    中小企業基盤整備機構 = "32"
    石油天然ガス金属鉱物資源機構 = "33"
    日本貿易振興機構 = "34"
    観光庁 = "35"
    気象庁 = "36"
    原子力規制委員会 = "37"
    内閣法制局 = "38"
    水産庁 = "39"
    独立行政法人郵便貯金簡易生命保険管理郵便局ネットワーク支援機構 = "40"
    公益財団法人食品等流通合理化促進機構 = "41"
    海上保安庁 = "42"
    スポーツ庁 = "43"
    警察庁 = "44"
    デジタル庁 = "45"
    林野庁 = "46"
    文化庁 = "47"
    公害等調整委員会 = "48"
    こども家庭庁 = "49"
