"""全国地方公共団体コード（自動生成 - 編集禁止）。

scripts/generate_municipality.py から data/sources/000925835.xls を読み込んで生成。
"""

from __future__ import annotations

from typing import NamedTuple, NewType

MunicipalityCode = NewType("MunicipalityCode", str)
"""全国地方公共団体コード（6桁文字列）。"""


class MunicipalityEntry(NamedTuple):
    """地方公共団体の情報。"""

    code: MunicipalityCode
    prefecture_name: str
    city_name: str
    prefecture_name_kana: str
    city_name_kana: str

    @property
    def prefecture_code(self) -> str:
        """都道府県コード（先頭2桁）。"""
        return self.code[:2]


_MUNICIPALITIES: dict[str, MunicipalityEntry] = {

    "010006": MunicipalityEntry(MunicipalityCode("010006"), "北海道", "", "ﾎｯｶｲﾄﾞｳ", ""),
    "011002": MunicipalityEntry(MunicipalityCode("011002"), "北海道", "札幌市", "ﾎｯｶｲﾄﾞｳ", "ｻｯﾎﾟﾛｼ"),
    "012025": MunicipalityEntry(MunicipalityCode("012025"), "北海道", "函館市", "ﾎｯｶｲﾄﾞｳ", "ﾊｺﾀﾞﾃｼ"),
    "012033": MunicipalityEntry(MunicipalityCode("012033"), "北海道", "小樽市", "ﾎｯｶｲﾄﾞｳ", "ｵﾀﾙｼ"),
    "012041": MunicipalityEntry(MunicipalityCode("012041"), "北海道", "旭川市", "ﾎｯｶｲﾄﾞｳ", "ｱｻﾋｶﾜｼ"),
    "012050": MunicipalityEntry(MunicipalityCode("012050"), "北海道", "室蘭市", "ﾎｯｶｲﾄﾞｳ", "ﾑﾛﾗﾝｼ"),
    "012068": MunicipalityEntry(MunicipalityCode("012068"), "北海道", "釧路市", "ﾎｯｶｲﾄﾞｳ", "ｸｼﾛｼ"),
    "012076": MunicipalityEntry(MunicipalityCode("012076"), "北海道", "帯広市", "ﾎｯｶｲﾄﾞｳ", "ｵﾋﾞﾋﾛｼ"),
    "012084": MunicipalityEntry(MunicipalityCode("012084"), "北海道", "北見市", "ﾎｯｶｲﾄﾞｳ", "ｷﾀﾐｼ"),
    "012092": MunicipalityEntry(MunicipalityCode("012092"), "北海道", "夕張市", "ﾎｯｶｲﾄﾞｳ", "ﾕｳﾊﾞﾘｼ"),
    "012106": MunicipalityEntry(MunicipalityCode("012106"), "北海道", "岩見沢市", "ﾎｯｶｲﾄﾞｳ", "ｲﾜﾐｻﾞﾜｼ"),
    "012114": MunicipalityEntry(MunicipalityCode("012114"), "北海道", "網走市", "ﾎｯｶｲﾄﾞｳ", "ｱﾊﾞｼﾘｼ"),
    "012122": MunicipalityEntry(MunicipalityCode("012122"), "北海道", "留萌市", "ﾎｯｶｲﾄﾞｳ", "ﾙﾓｲｼ"),
    "012131": MunicipalityEntry(MunicipalityCode("012131"), "北海道", "苫小牧市", "ﾎｯｶｲﾄﾞｳ", "ﾄﾏｺﾏｲｼ"),
    "012149": MunicipalityEntry(MunicipalityCode("012149"), "北海道", "稚内市", "ﾎｯｶｲﾄﾞｳ", "ﾜｯｶﾅｲｼ"),
    "012157": MunicipalityEntry(MunicipalityCode("012157"), "北海道", "美唄市", "ﾎｯｶｲﾄﾞｳ", "ﾋﾞﾊﾞｲｼ"),
    "012165": MunicipalityEntry(MunicipalityCode("012165"), "北海道", "芦別市", "ﾎｯｶｲﾄﾞｳ", "ｱｼﾍﾞﾂｼ"),
    "012173": MunicipalityEntry(MunicipalityCode("012173"), "北海道", "江別市", "ﾎｯｶｲﾄﾞｳ", "ｴﾍﾞﾂｼ"),
    "012181": MunicipalityEntry(MunicipalityCode("012181"), "北海道", "赤平市", "ﾎｯｶｲﾄﾞｳ", "ｱｶﾋﾞﾗｼ"),
    "012190": MunicipalityEntry(MunicipalityCode("012190"), "北海道", "紋別市", "ﾎｯｶｲﾄﾞｳ", "ﾓﾝﾍﾞﾂｼ"),
    "012203": MunicipalityEntry(MunicipalityCode("012203"), "北海道", "士別市", "ﾎｯｶｲﾄﾞｳ", "ｼﾍﾞﾂｼ"),
    "012211": MunicipalityEntry(MunicipalityCode("012211"), "北海道", "名寄市", "ﾎｯｶｲﾄﾞｳ", "ﾅﾖﾛｼ"),
    "012220": MunicipalityEntry(MunicipalityCode("012220"), "北海道", "三笠市", "ﾎｯｶｲﾄﾞｳ", "ﾐｶｻｼ"),
    "012238": MunicipalityEntry(MunicipalityCode("012238"), "北海道", "根室市", "ﾎｯｶｲﾄﾞｳ", "ﾈﾑﾛｼ"),
    "012246": MunicipalityEntry(MunicipalityCode("012246"), "北海道", "千歳市", "ﾎｯｶｲﾄﾞｳ", "ﾁﾄｾｼ"),
    "012254": MunicipalityEntry(MunicipalityCode("012254"), "北海道", "滝川市", "ﾎｯｶｲﾄﾞｳ", "ﾀｷｶﾜｼ"),
    "012262": MunicipalityEntry(MunicipalityCode("012262"), "北海道", "砂川市", "ﾎｯｶｲﾄﾞｳ", "ｽﾅｶﾞﾜｼ"),
    "012271": MunicipalityEntry(MunicipalityCode("012271"), "北海道", "歌志内市", "ﾎｯｶｲﾄﾞｳ", "ｳﾀｼﾅｲｼ"),
    "012289": MunicipalityEntry(MunicipalityCode("012289"), "北海道", "深川市", "ﾎｯｶｲﾄﾞｳ", "ﾌｶｶﾞﾜｼ"),
    "012297": MunicipalityEntry(MunicipalityCode("012297"), "北海道", "富良野市", "ﾎｯｶｲﾄﾞｳ", "ﾌﾗﾉｼ"),
    "012301": MunicipalityEntry(MunicipalityCode("012301"), "北海道", "登別市", "ﾎｯｶｲﾄﾞｳ", "ﾉﾎﾞﾘﾍﾞﾂｼ"),
    "012319": MunicipalityEntry(MunicipalityCode("012319"), "北海道", "恵庭市", "ﾎｯｶｲﾄﾞｳ", "ｴﾆﾜｼ"),
    "012335": MunicipalityEntry(MunicipalityCode("012335"), "北海道", "伊達市", "ﾎｯｶｲﾄﾞｳ", "ﾀﾞﾃｼ"),
    "012343": MunicipalityEntry(MunicipalityCode("012343"), "北海道", "北広島市", "ﾎｯｶｲﾄﾞｳ", "ｷﾀﾋﾛｼﾏｼ"),
    "012351": MunicipalityEntry(MunicipalityCode("012351"), "北海道", "石狩市", "ﾎｯｶｲﾄﾞｳ", "ｲｼｶﾘｼ"),
    "012360": MunicipalityEntry(MunicipalityCode("012360"), "北海道", "北斗市", "ﾎｯｶｲﾄﾞｳ", "ﾎｸﾄｼ"),
    "013030": MunicipalityEntry(MunicipalityCode("013030"), "北海道", "当別町", "ﾎｯｶｲﾄﾞｳ", "ﾄｳﾍﾞﾂﾁｮｳ"),
    "013048": MunicipalityEntry(MunicipalityCode("013048"), "北海道", "新篠津村", "ﾎｯｶｲﾄﾞｳ", "ｼﾝｼﾉﾂﾑﾗ"),
    "013315": MunicipalityEntry(MunicipalityCode("013315"), "北海道", "松前町", "ﾎｯｶｲﾄﾞｳ", "ﾏﾂﾏｴﾁｮｳ"),
    "013323": MunicipalityEntry(MunicipalityCode("013323"), "北海道", "福島町", "ﾎｯｶｲﾄﾞｳ", "ﾌｸｼﾏﾁｮｳ"),
    "013331": MunicipalityEntry(MunicipalityCode("013331"), "北海道", "知内町", "ﾎｯｶｲﾄﾞｳ", "ｼﾘｳﾁﾁｮｳ"),
    "013340": MunicipalityEntry(MunicipalityCode("013340"), "北海道", "木古内町", "ﾎｯｶｲﾄﾞｳ", "ｷｺﾅｲﾁｮｳ"),
    "013374": MunicipalityEntry(MunicipalityCode("013374"), "北海道", "七飯町", "ﾎｯｶｲﾄﾞｳ", "ﾅﾅｴﾁｮｳ"),
    "013439": MunicipalityEntry(MunicipalityCode("013439"), "北海道", "鹿部町", "ﾎｯｶｲﾄﾞｳ", "ｼｶﾍﾞﾁｮｳ"),
    "013455": MunicipalityEntry(MunicipalityCode("013455"), "北海道", "森町", "ﾎｯｶｲﾄﾞｳ", "ﾓﾘﾏﾁ"),
    "013463": MunicipalityEntry(MunicipalityCode("013463"), "北海道", "八雲町", "ﾎｯｶｲﾄﾞｳ", "ﾔｸﾓﾁｮｳ"),
    "013471": MunicipalityEntry(MunicipalityCode("013471"), "北海道", "長万部町", "ﾎｯｶｲﾄﾞｳ", "ｵｼｬﾏﾝﾍﾞﾁｮｳ"),
    "013617": MunicipalityEntry(MunicipalityCode("013617"), "北海道", "江差町", "ﾎｯｶｲﾄﾞｳ", "ｴｻｼﾁｮｳ"),
    "013625": MunicipalityEntry(MunicipalityCode("013625"), "北海道", "上ノ国町", "ﾎｯｶｲﾄﾞｳ", "ｶﾐﾉｸﾆﾁｮｳ"),
    "013633": MunicipalityEntry(MunicipalityCode("013633"), "北海道", "厚沢部町", "ﾎｯｶｲﾄﾞｳ", "ｱｯｻﾌﾞﾁｮｳ"),
    "013641": MunicipalityEntry(MunicipalityCode("013641"), "北海道", "乙部町", "ﾎｯｶｲﾄﾞｳ", "ｵﾄﾍﾞﾁｮｳ"),
    "013676": MunicipalityEntry(MunicipalityCode("013676"), "北海道", "奥尻町", "ﾎｯｶｲﾄﾞｳ", "ｵｸｼﾘﾁｮｳ"),
    "013706": MunicipalityEntry(MunicipalityCode("013706"), "北海道", "今金町", "ﾎｯｶｲﾄﾞｳ", "ｲﾏｶﾈﾁｮｳ"),
    "013714": MunicipalityEntry(MunicipalityCode("013714"), "北海道", "せたな町", "ﾎｯｶｲﾄﾞｳ", "ｾﾀﾅﾁｮｳ"),
    "013919": MunicipalityEntry(MunicipalityCode("013919"), "北海道", "島牧村", "ﾎｯｶｲﾄﾞｳ", "ｼﾏﾏｷﾑﾗ"),
    "013927": MunicipalityEntry(MunicipalityCode("013927"), "北海道", "寿都町", "ﾎｯｶｲﾄﾞｳ", "ｽｯﾂﾁｮｳ"),
    "013935": MunicipalityEntry(MunicipalityCode("013935"), "北海道", "黒松内町", "ﾎｯｶｲﾄﾞｳ", "ｸﾛﾏﾂﾅｲﾁｮｳ"),
    "013943": MunicipalityEntry(MunicipalityCode("013943"), "北海道", "蘭越町", "ﾎｯｶｲﾄﾞｳ", "ﾗﾝｺｼﾁｮｳ"),
    "013951": MunicipalityEntry(MunicipalityCode("013951"), "北海道", "ニセコ町", "ﾎｯｶｲﾄﾞｳ", "ﾆｾｺﾁｮｳ"),
    "013960": MunicipalityEntry(MunicipalityCode("013960"), "北海道", "真狩村", "ﾎｯｶｲﾄﾞｳ", "ﾏｯｶﾘﾑﾗ"),
    "013978": MunicipalityEntry(MunicipalityCode("013978"), "北海道", "留寿都村", "ﾎｯｶｲﾄﾞｳ", "ﾙｽﾂﾑﾗ"),
    "013986": MunicipalityEntry(MunicipalityCode("013986"), "北海道", "喜茂別町", "ﾎｯｶｲﾄﾞｳ", "ｷﾓﾍﾞﾂﾁｮｳ"),
    "013994": MunicipalityEntry(MunicipalityCode("013994"), "北海道", "京極町", "ﾎｯｶｲﾄﾞｳ", "ｷｮｳｺﾞｸﾁｮｳ"),
    "014001": MunicipalityEntry(MunicipalityCode("014001"), "北海道", "倶知安町", "ﾎｯｶｲﾄﾞｳ", "ｸｯﾁｬﾝﾁｮｳ"),
    "014010": MunicipalityEntry(MunicipalityCode("014010"), "北海道", "共和町", "ﾎｯｶｲﾄﾞｳ", "ｷｮｳﾜﾁｮｳ"),
    "014028": MunicipalityEntry(MunicipalityCode("014028"), "北海道", "岩内町", "ﾎｯｶｲﾄﾞｳ", "ｲﾜﾅｲﾁｮｳ"),
    "014036": MunicipalityEntry(MunicipalityCode("014036"), "北海道", "泊村", "ﾎｯｶｲﾄﾞｳ", "ﾄﾏﾘﾑﾗ"),
    "014044": MunicipalityEntry(MunicipalityCode("014044"), "北海道", "神恵内村", "ﾎｯｶｲﾄﾞｳ", "ｶﾓｴﾅｲﾑﾗ"),
    "014052": MunicipalityEntry(MunicipalityCode("014052"), "北海道", "積丹町", "ﾎｯｶｲﾄﾞｳ", "ｼｬｺﾀﾝﾁｮｳ"),
    "014061": MunicipalityEntry(MunicipalityCode("014061"), "北海道", "古平町", "ﾎｯｶｲﾄﾞｳ", "ﾌﾙﾋﾞﾗﾁｮｳ"),
    "014079": MunicipalityEntry(MunicipalityCode("014079"), "北海道", "仁木町", "ﾎｯｶｲﾄﾞｳ", "ﾆｷﾁｮｳ"),
    "014087": MunicipalityEntry(MunicipalityCode("014087"), "北海道", "余市町", "ﾎｯｶｲﾄﾞｳ", "ﾖｲﾁﾁｮｳ"),
    "014095": MunicipalityEntry(MunicipalityCode("014095"), "北海道", "赤井川村", "ﾎｯｶｲﾄﾞｳ", "ｱｶｲｶﾞﾜﾑﾗ"),
    "014231": MunicipalityEntry(MunicipalityCode("014231"), "北海道", "南幌町", "ﾎｯｶｲﾄﾞｳ", "ﾅﾝﾎﾟﾛﾁｮｳ"),
    "014249": MunicipalityEntry(MunicipalityCode("014249"), "北海道", "奈井江町", "ﾎｯｶｲﾄﾞｳ", "ﾅｲｴﾁｮｳ"),
    "014257": MunicipalityEntry(MunicipalityCode("014257"), "北海道", "上砂川町", "ﾎｯｶｲﾄﾞｳ", "ｶﾐｽﾅｶﾞﾜﾁｮｳ"),
    "014273": MunicipalityEntry(MunicipalityCode("014273"), "北海道", "由仁町", "ﾎｯｶｲﾄﾞｳ", "ﾕﾆﾁｮｳ"),
    "014281": MunicipalityEntry(MunicipalityCode("014281"), "北海道", "長沼町", "ﾎｯｶｲﾄﾞｳ", "ﾅｶﾞﾇﾏﾁｮｳ"),
    "014290": MunicipalityEntry(MunicipalityCode("014290"), "北海道", "栗山町", "ﾎｯｶｲﾄﾞｳ", "ｸﾘﾔﾏﾁｮｳ"),
    "014303": MunicipalityEntry(MunicipalityCode("014303"), "北海道", "月形町", "ﾎｯｶｲﾄﾞｳ", "ﾂｷｶﾞﾀﾁｮｳ"),
    "014311": MunicipalityEntry(MunicipalityCode("014311"), "北海道", "浦臼町", "ﾎｯｶｲﾄﾞｳ", "ｳﾗｳｽﾁｮｳ"),
    "014320": MunicipalityEntry(MunicipalityCode("014320"), "北海道", "新十津川町", "ﾎｯｶｲﾄﾞｳ", "ｼﾝﾄﾂｶﾜﾁｮｳ"),
    "014338": MunicipalityEntry(MunicipalityCode("014338"), "北海道", "妹背牛町", "ﾎｯｶｲﾄﾞｳ", "ﾓｾｳｼﾁｮｳ"),
    "014346": MunicipalityEntry(MunicipalityCode("014346"), "北海道", "秩父別町", "ﾎｯｶｲﾄﾞｳ", "ﾁｯﾌﾟﾍﾞﾂﾁｮｳ"),
    "014362": MunicipalityEntry(MunicipalityCode("014362"), "北海道", "雨竜町", "ﾎｯｶｲﾄﾞｳ", "ｳﾘｭｳﾁｮｳ"),
    "014371": MunicipalityEntry(MunicipalityCode("014371"), "北海道", "北竜町", "ﾎｯｶｲﾄﾞｳ", "ﾎｸﾘｭｳﾁｮｳ"),
    "014389": MunicipalityEntry(MunicipalityCode("014389"), "北海道", "沼田町", "ﾎｯｶｲﾄﾞｳ", "ﾇﾏﾀﾁｮｳ"),
    "014524": MunicipalityEntry(MunicipalityCode("014524"), "北海道", "鷹栖町", "ﾎｯｶｲﾄﾞｳ", "ﾀｶｽﾁｮｳ"),
    "014532": MunicipalityEntry(MunicipalityCode("014532"), "北海道", "東神楽町", "ﾎｯｶｲﾄﾞｳ", "ﾋｶﾞｼｶｸﾞﾗﾁｮｳ"),
    "014541": MunicipalityEntry(MunicipalityCode("014541"), "北海道", "当麻町", "ﾎｯｶｲﾄﾞｳ", "ﾄｳﾏﾁｮｳ"),
    "014559": MunicipalityEntry(MunicipalityCode("014559"), "北海道", "比布町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾟｯﾌﾟﾁｮｳ"),
    "014567": MunicipalityEntry(MunicipalityCode("014567"), "北海道", "愛別町", "ﾎｯｶｲﾄﾞｳ", "ｱｲﾍﾞﾂﾁｮｳ"),
    "014575": MunicipalityEntry(MunicipalityCode("014575"), "北海道", "上川町", "ﾎｯｶｲﾄﾞｳ", "ｶﾐｶﾜﾁｮｳ"),
    "014583": MunicipalityEntry(MunicipalityCode("014583"), "北海道", "東川町", "ﾎｯｶｲﾄﾞｳ", "ﾋｶﾞｼｶﾜﾁｮｳ"),
    "014591": MunicipalityEntry(MunicipalityCode("014591"), "北海道", "美瑛町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾞｴｲﾁｮｳ"),
    "014605": MunicipalityEntry(MunicipalityCode("014605"), "北海道", "上富良野町", "ﾎｯｶｲﾄﾞｳ", "ｶﾐﾌﾗﾉﾁｮｳ"),
    "014613": MunicipalityEntry(MunicipalityCode("014613"), "北海道", "中富良野町", "ﾎｯｶｲﾄﾞｳ", "ﾅｶﾌﾗﾉﾁｮｳ"),
    "014621": MunicipalityEntry(MunicipalityCode("014621"), "北海道", "南富良野町", "ﾎｯｶｲﾄﾞｳ", "ﾐﾅﾐﾌﾗﾉﾁｮｳ"),
    "014630": MunicipalityEntry(MunicipalityCode("014630"), "北海道", "占冠村", "ﾎｯｶｲﾄﾞｳ", "ｼﾑｶｯﾌﾟﾑﾗ"),
    "014648": MunicipalityEntry(MunicipalityCode("014648"), "北海道", "和寒町", "ﾎｯｶｲﾄﾞｳ", "ﾜｯｻﾑﾁｮｳ"),
    "014656": MunicipalityEntry(MunicipalityCode("014656"), "北海道", "剣淵町", "ﾎｯｶｲﾄﾞｳ", "ｹﾝﾌﾞﾁﾁｮｳ"),
    "014681": MunicipalityEntry(MunicipalityCode("014681"), "北海道", "下川町", "ﾎｯｶｲﾄﾞｳ", "ｼﾓｶﾜﾁｮｳ"),
    "014699": MunicipalityEntry(MunicipalityCode("014699"), "北海道", "美深町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾞﾌｶﾁｮｳ"),
    "014702": MunicipalityEntry(MunicipalityCode("014702"), "北海道", "音威子府村", "ﾎｯｶｲﾄﾞｳ", "ｵﾄｲﾈｯﾌﾟﾑﾗ"),
    "014711": MunicipalityEntry(MunicipalityCode("014711"), "北海道", "中川町", "ﾎｯｶｲﾄﾞｳ", "ﾅｶｶﾞﾜﾁｮｳ"),
    "014729": MunicipalityEntry(MunicipalityCode("014729"), "北海道", "幌加内町", "ﾎｯｶｲﾄﾞｳ", "ﾎﾛｶﾅｲﾁｮｳ"),
    "014818": MunicipalityEntry(MunicipalityCode("014818"), "北海道", "増毛町", "ﾎｯｶｲﾄﾞｳ", "ﾏｼｹﾁｮｳ"),
    "014826": MunicipalityEntry(MunicipalityCode("014826"), "北海道", "小平町", "ﾎｯｶｲﾄﾞｳ", "ｵﾋﾞﾗﾁｮｳ"),
    "014834": MunicipalityEntry(MunicipalityCode("014834"), "北海道", "苫前町", "ﾎｯｶｲﾄﾞｳ", "ﾄﾏﾏｴﾁｮｳ"),
    "014842": MunicipalityEntry(MunicipalityCode("014842"), "北海道", "羽幌町", "ﾎｯｶｲﾄﾞｳ", "ﾊﾎﾞﾛﾁｮｳ"),
    "014851": MunicipalityEntry(MunicipalityCode("014851"), "北海道", "初山別村", "ﾎｯｶｲﾄﾞｳ", "ｼｮｻﾝﾍﾞﾂﾑﾗ"),
    "014869": MunicipalityEntry(MunicipalityCode("014869"), "北海道", "遠別町", "ﾎｯｶｲﾄﾞｳ", "ｴﾝﾍﾞﾂﾁｮｳ"),
    "014877": MunicipalityEntry(MunicipalityCode("014877"), "北海道", "天塩町", "ﾎｯｶｲﾄﾞｳ", "ﾃｼｵﾁｮｳ"),
    "015113": MunicipalityEntry(MunicipalityCode("015113"), "北海道", "猿払村", "ﾎｯｶｲﾄﾞｳ", "ｻﾙﾌﾂﾑﾗ"),
    "015121": MunicipalityEntry(MunicipalityCode("015121"), "北海道", "浜頓別町", "ﾎｯｶｲﾄﾞｳ", "ﾊﾏﾄﾝﾍﾞﾂﾁｮｳ"),
    "015130": MunicipalityEntry(MunicipalityCode("015130"), "北海道", "中頓別町", "ﾎｯｶｲﾄﾞｳ", "ﾅｶﾄﾝﾍﾞﾂﾁｮｳ"),
    "015148": MunicipalityEntry(MunicipalityCode("015148"), "北海道", "枝幸町", "ﾎｯｶｲﾄﾞｳ", "ｴｻｼﾁｮｳ"),
    "015164": MunicipalityEntry(MunicipalityCode("015164"), "北海道", "豊富町", "ﾎｯｶｲﾄﾞｳ", "ﾄﾖﾄﾐﾁｮｳ"),
    "015172": MunicipalityEntry(MunicipalityCode("015172"), "北海道", "礼文町", "ﾎｯｶｲﾄﾞｳ", "ﾚﾌﾞﾝﾁｮｳ"),
    "015181": MunicipalityEntry(MunicipalityCode("015181"), "北海道", "利尻町", "ﾎｯｶｲﾄﾞｳ", "ﾘｼﾘﾁｮｳ"),
    "015199": MunicipalityEntry(MunicipalityCode("015199"), "北海道", "利尻富士町", "ﾎｯｶｲﾄﾞｳ", "ﾘｼﾘﾌｼﾞﾁｮｳ"),
    "015202": MunicipalityEntry(MunicipalityCode("015202"), "北海道", "幌延町", "ﾎｯｶｲﾄﾞｳ", "ﾎﾛﾉﾍﾞﾁｮｳ"),
    "015431": MunicipalityEntry(MunicipalityCode("015431"), "北海道", "美幌町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾞﾎﾛﾁｮｳ"),
    "015440": MunicipalityEntry(MunicipalityCode("015440"), "北海道", "津別町", "ﾎｯｶｲﾄﾞｳ", "ﾂﾍﾞﾂﾁｮｳ"),
    "015458": MunicipalityEntry(MunicipalityCode("015458"), "北海道", "斜里町", "ﾎｯｶｲﾄﾞｳ", "ｼｬﾘﾁｮｳ"),
    "015466": MunicipalityEntry(MunicipalityCode("015466"), "北海道", "清里町", "ﾎｯｶｲﾄﾞｳ", "ｷﾖｻﾄﾁｮｳ"),
    "015474": MunicipalityEntry(MunicipalityCode("015474"), "北海道", "小清水町", "ﾎｯｶｲﾄﾞｳ", "ｺｼﾐｽﾞﾁｮｳ"),
    "015491": MunicipalityEntry(MunicipalityCode("015491"), "北海道", "訓子府町", "ﾎｯｶｲﾄﾞｳ", "ｸﾝﾈｯﾌﾟﾁｮｳ"),
    "015504": MunicipalityEntry(MunicipalityCode("015504"), "北海道", "置戸町", "ﾎｯｶｲﾄﾞｳ", "ｵｹﾄﾁｮｳ"),
    "015521": MunicipalityEntry(MunicipalityCode("015521"), "北海道", "佐呂間町", "ﾎｯｶｲﾄﾞｳ", "ｻﾛﾏﾁｮｳ"),
    "015555": MunicipalityEntry(MunicipalityCode("015555"), "北海道", "遠軽町", "ﾎｯｶｲﾄﾞｳ", "ｴﾝｶﾞﾙﾁｮｳ"),
    "015598": MunicipalityEntry(MunicipalityCode("015598"), "北海道", "湧別町", "ﾎｯｶｲﾄﾞｳ", "ﾕｳﾍﾞﾂﾁｮｳ"),
    "015601": MunicipalityEntry(MunicipalityCode("015601"), "北海道", "滝上町", "ﾎｯｶｲﾄﾞｳ", "ﾀｷﾉｳｴﾁｮｳ"),
    "015610": MunicipalityEntry(MunicipalityCode("015610"), "北海道", "興部町", "ﾎｯｶｲﾄﾞｳ", "ｵｺｯﾍﾟﾁｮｳ"),
    "015628": MunicipalityEntry(MunicipalityCode("015628"), "北海道", "西興部村", "ﾎｯｶｲﾄﾞｳ", "ﾆｼｵｺｯﾍﾟﾑﾗ"),
    "015636": MunicipalityEntry(MunicipalityCode("015636"), "北海道", "雄武町", "ﾎｯｶｲﾄﾞｳ", "ｵｳﾑﾁｮｳ"),
    "015644": MunicipalityEntry(MunicipalityCode("015644"), "北海道", "大空町", "ﾎｯｶｲﾄﾞｳ", "ｵｵｿﾞﾗﾁｮｳ"),
    "015717": MunicipalityEntry(MunicipalityCode("015717"), "北海道", "豊浦町", "ﾎｯｶｲﾄﾞｳ", "ﾄﾖｳﾗﾁｮｳ"),
    "015750": MunicipalityEntry(MunicipalityCode("015750"), "北海道", "壮瞥町", "ﾎｯｶｲﾄﾞｳ", "ｿｳﾍﾞﾂﾁｮｳ"),
    "015784": MunicipalityEntry(MunicipalityCode("015784"), "北海道", "白老町", "ﾎｯｶｲﾄﾞｳ", "ｼﾗｵｲﾁｮｳ"),
    "015814": MunicipalityEntry(MunicipalityCode("015814"), "北海道", "厚真町", "ﾎｯｶｲﾄﾞｳ", "ｱﾂﾏﾁｮｳ"),
    "015849": MunicipalityEntry(MunicipalityCode("015849"), "北海道", "洞爺湖町", "ﾎｯｶｲﾄﾞｳ", "ﾄｳﾔｺﾁｮｳ"),
    "015857": MunicipalityEntry(MunicipalityCode("015857"), "北海道", "安平町", "ﾎｯｶｲﾄﾞｳ", "ｱﾋﾞﾗﾁｮｳ"),
    "015865": MunicipalityEntry(MunicipalityCode("015865"), "北海道", "むかわ町", "ﾎｯｶｲﾄﾞｳ", "ﾑｶﾜﾁｮｳ"),
    "016012": MunicipalityEntry(MunicipalityCode("016012"), "北海道", "日高町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾀﾞｶﾁｮｳ"),
    "016021": MunicipalityEntry(MunicipalityCode("016021"), "北海道", "平取町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾞﾗﾄﾘﾁｮｳ"),
    "016047": MunicipalityEntry(MunicipalityCode("016047"), "北海道", "新冠町", "ﾎｯｶｲﾄﾞｳ", "ﾆｲｶｯﾌﾟﾁｮｳ"),
    "016071": MunicipalityEntry(MunicipalityCode("016071"), "北海道", "浦河町", "ﾎｯｶｲﾄﾞｳ", "ｳﾗｶﾜﾁｮｳ"),
    "016080": MunicipalityEntry(MunicipalityCode("016080"), "北海道", "様似町", "ﾎｯｶｲﾄﾞｳ", "ｻﾏﾆﾁｮｳ"),
    "016098": MunicipalityEntry(MunicipalityCode("016098"), "北海道", "えりも町", "ﾎｯｶｲﾄﾞｳ", "ｴﾘﾓﾁｮｳ"),
    "016101": MunicipalityEntry(MunicipalityCode("016101"), "北海道", "新ひだか町", "ﾎｯｶｲﾄﾞｳ", "ｼﾝﾋﾀﾞｶﾁｮｳ"),
    "016314": MunicipalityEntry(MunicipalityCode("016314"), "北海道", "音更町", "ﾎｯｶｲﾄﾞｳ", "ｵﾄﾌｹﾁｮｳ"),
    "016322": MunicipalityEntry(MunicipalityCode("016322"), "北海道", "士幌町", "ﾎｯｶｲﾄﾞｳ", "ｼﾎﾛﾁｮｳ"),
    "016331": MunicipalityEntry(MunicipalityCode("016331"), "北海道", "上士幌町", "ﾎｯｶｲﾄﾞｳ", "ｶﾐｼﾎﾛﾁｮｳ"),
    "016349": MunicipalityEntry(MunicipalityCode("016349"), "北海道", "鹿追町", "ﾎｯｶｲﾄﾞｳ", "ｼｶｵｲﾁｮｳ"),
    "016357": MunicipalityEntry(MunicipalityCode("016357"), "北海道", "新得町", "ﾎｯｶｲﾄﾞｳ", "ｼﾝﾄｸﾁｮｳ"),
    "016365": MunicipalityEntry(MunicipalityCode("016365"), "北海道", "清水町", "ﾎｯｶｲﾄﾞｳ", "ｼﾐｽﾞﾁｮｳ"),
    "016373": MunicipalityEntry(MunicipalityCode("016373"), "北海道", "芽室町", "ﾎｯｶｲﾄﾞｳ", "ﾒﾑﾛﾁｮｳ"),
    "016381": MunicipalityEntry(MunicipalityCode("016381"), "北海道", "中札内村", "ﾎｯｶｲﾄﾞｳ", "ﾅｶｻﾂﾅｲﾑﾗ"),
    "016390": MunicipalityEntry(MunicipalityCode("016390"), "北海道", "更別村", "ﾎｯｶｲﾄﾞｳ", "ｻﾗﾍﾞﾂﾑﾗ"),
    "016411": MunicipalityEntry(MunicipalityCode("016411"), "北海道", "大樹町", "ﾎｯｶｲﾄﾞｳ", "ﾀｲｷﾁｮｳ"),
    "016420": MunicipalityEntry(MunicipalityCode("016420"), "北海道", "広尾町", "ﾎｯｶｲﾄﾞｳ", "ﾋﾛｵﾁｮｳ"),
    "016438": MunicipalityEntry(MunicipalityCode("016438"), "北海道", "幕別町", "ﾎｯｶｲﾄﾞｳ", "ﾏｸﾍﾞﾂﾁｮｳ"),
    "016446": MunicipalityEntry(MunicipalityCode("016446"), "北海道", "池田町", "ﾎｯｶｲﾄﾞｳ", "ｲｹﾀﾞﾁｮｳ"),
    "016454": MunicipalityEntry(MunicipalityCode("016454"), "北海道", "豊頃町", "ﾎｯｶｲﾄﾞｳ", "ﾄﾖｺﾛﾁｮｳ"),
    "016462": MunicipalityEntry(MunicipalityCode("016462"), "北海道", "本別町", "ﾎｯｶｲﾄﾞｳ", "ﾎﾝﾍﾞﾂﾁｮｳ"),
    "016471": MunicipalityEntry(MunicipalityCode("016471"), "北海道", "足寄町", "ﾎｯｶｲﾄﾞｳ", "ｱｼｮﾛﾁｮｳ"),
    "016489": MunicipalityEntry(MunicipalityCode("016489"), "北海道", "陸別町", "ﾎｯｶｲﾄﾞｳ", "ﾘｸﾍﾞﾂﾁｮｳ"),
    "016497": MunicipalityEntry(MunicipalityCode("016497"), "北海道", "浦幌町", "ﾎｯｶｲﾄﾞｳ", "ｳﾗﾎﾛﾁｮｳ"),
    "016616": MunicipalityEntry(MunicipalityCode("016616"), "北海道", "釧路町", "ﾎｯｶｲﾄﾞｳ", "ｸｼﾛﾁｮｳ"),
    "016624": MunicipalityEntry(MunicipalityCode("016624"), "北海道", "厚岸町", "ﾎｯｶｲﾄﾞｳ", "ｱｯｹｼﾁｮｳ"),
    "016632": MunicipalityEntry(MunicipalityCode("016632"), "北海道", "浜中町", "ﾎｯｶｲﾄﾞｳ", "ﾊﾏﾅｶﾁｮｳ"),
    "016641": MunicipalityEntry(MunicipalityCode("016641"), "北海道", "標茶町", "ﾎｯｶｲﾄﾞｳ", "ｼﾍﾞﾁｬﾁｮｳ"),
    "016659": MunicipalityEntry(MunicipalityCode("016659"), "北海道", "弟子屈町", "ﾎｯｶｲﾄﾞｳ", "ﾃｼｶｶﾞﾁｮｳ"),
    "016675": MunicipalityEntry(MunicipalityCode("016675"), "北海道", "鶴居村", "ﾎｯｶｲﾄﾞｳ", "ﾂﾙｲﾑﾗ"),
    "016683": MunicipalityEntry(MunicipalityCode("016683"), "北海道", "白糠町", "ﾎｯｶｲﾄﾞｳ", "ｼﾗﾇｶﾁｮｳ"),
    "016918": MunicipalityEntry(MunicipalityCode("016918"), "北海道", "別海町", "ﾎｯｶｲﾄﾞｳ", "ﾍﾞﾂｶｲﾁｮｳ"),
    "016926": MunicipalityEntry(MunicipalityCode("016926"), "北海道", "中標津町", "ﾎｯｶｲﾄﾞｳ", "ﾅｶｼﾍﾞﾂﾁｮｳ"),
    "016934": MunicipalityEntry(MunicipalityCode("016934"), "北海道", "標津町", "ﾎｯｶｲﾄﾞｳ", "ｼﾍﾞﾂﾁｮｳ"),
    "016942": MunicipalityEntry(MunicipalityCode("016942"), "北海道", "羅臼町", "ﾎｯｶｲﾄﾞｳ", "ﾗｳｽﾁｮｳ"),
    "016951": MunicipalityEntry(MunicipalityCode("016951"), "北海道", "色丹村", "ﾎｯｶｲﾄﾞｳ", "ｼｺﾀﾝﾑﾗ"),
    "016969": MunicipalityEntry(MunicipalityCode("016969"), "北海道", "泊村", "ﾎｯｶｲﾄﾞｳ", "ﾄﾏﾘﾑﾗ"),
    "016977": MunicipalityEntry(MunicipalityCode("016977"), "北海道", "留夜別村", "ﾎｯｶｲﾄﾞｳ", "ﾙﾔﾍﾞﾂﾑﾗ"),
    "016985": MunicipalityEntry(MunicipalityCode("016985"), "北海道", "留別村", "ﾎｯｶｲﾄﾞｳ", "ﾙﾍﾞﾂﾑﾗ"),
    "016993": MunicipalityEntry(MunicipalityCode("016993"), "北海道", "紗那村", "ﾎｯｶｲﾄﾞｳ", "ｼｬﾅﾑﾗ"),
    "017001": MunicipalityEntry(MunicipalityCode("017001"), "北海道", "蘂取村", "ﾎｯｶｲﾄﾞｳ", "ｼﾍﾞﾄﾛﾑﾗ"),
    "020001": MunicipalityEntry(MunicipalityCode("020001"), "青森県", "", "ｱｵﾓﾘｹﾝ", ""),
    "022012": MunicipalityEntry(MunicipalityCode("022012"), "青森県", "青森市", "ｱｵﾓﾘｹﾝ", "ｱｵﾓﾘｼ"),
    "022021": MunicipalityEntry(MunicipalityCode("022021"), "青森県", "弘前市", "ｱｵﾓﾘｹﾝ", "ﾋﾛｻｷｼ"),
    "022039": MunicipalityEntry(MunicipalityCode("022039"), "青森県", "八戸市", "ｱｵﾓﾘｹﾝ", "ﾊﾁﾉﾍｼ"),
    "022047": MunicipalityEntry(MunicipalityCode("022047"), "青森県", "黒石市", "ｱｵﾓﾘｹﾝ", "ｸﾛｲｼｼ"),
    "022055": MunicipalityEntry(MunicipalityCode("022055"), "青森県", "五所川原市", "ｱｵﾓﾘｹﾝ", "ｺﾞｼｮｶﾞﾜﾗｼ"),
    "022063": MunicipalityEntry(MunicipalityCode("022063"), "青森県", "十和田市", "ｱｵﾓﾘｹﾝ", "ﾄﾜﾀﾞｼ"),
    "022071": MunicipalityEntry(MunicipalityCode("022071"), "青森県", "三沢市", "ｱｵﾓﾘｹﾝ", "ﾐｻﾜｼ"),
    "022080": MunicipalityEntry(MunicipalityCode("022080"), "青森県", "むつ市", "ｱｵﾓﾘｹﾝ", "ﾑﾂｼ"),
    "022098": MunicipalityEntry(MunicipalityCode("022098"), "青森県", "つがる市", "ｱｵﾓﾘｹﾝ", "ﾂｶﾞﾙｼ"),
    "022101": MunicipalityEntry(MunicipalityCode("022101"), "青森県", "平川市", "ｱｵﾓﾘｹﾝ", "ﾋﾗｶﾜｼ"),
    "023019": MunicipalityEntry(MunicipalityCode("023019"), "青森県", "平内町", "ｱｵﾓﾘｹﾝ", "ﾋﾗﾅｲﾏﾁ"),
    "023035": MunicipalityEntry(MunicipalityCode("023035"), "青森県", "今別町", "ｱｵﾓﾘｹﾝ", "ｲﾏﾍﾞﾂﾏﾁ"),
    "023043": MunicipalityEntry(MunicipalityCode("023043"), "青森県", "蓬田村", "ｱｵﾓﾘｹﾝ", "ﾖﾓｷﾞﾀﾑﾗ"),
    "023078": MunicipalityEntry(MunicipalityCode("023078"), "青森県", "外ヶ浜町", "ｱｵﾓﾘｹﾝ", "ｿﾄｶﾞﾊﾏﾏﾁ"),
    "023213": MunicipalityEntry(MunicipalityCode("023213"), "青森県", "鰺ヶ沢町", "ｱｵﾓﾘｹﾝ", "ｱｼﾞｶﾞｻﾜﾏﾁ"),
    "023230": MunicipalityEntry(MunicipalityCode("023230"), "青森県", "深浦町", "ｱｵﾓﾘｹﾝ", "ﾌｶｳﾗﾏﾁ"),
    "023434": MunicipalityEntry(MunicipalityCode("023434"), "青森県", "西目屋村", "ｱｵﾓﾘｹﾝ", "ﾆｼﾒﾔﾑﾗ"),
    "023612": MunicipalityEntry(MunicipalityCode("023612"), "青森県", "藤崎町", "ｱｵﾓﾘｹﾝ", "ﾌｼﾞｻｷﾏﾁ"),
    "023621": MunicipalityEntry(MunicipalityCode("023621"), "青森県", "大鰐町", "ｱｵﾓﾘｹﾝ", "ｵｵﾜﾆﾏﾁ"),
    "023671": MunicipalityEntry(MunicipalityCode("023671"), "青森県", "田舎館村", "ｱｵﾓﾘｹﾝ", "ｲﾅｶﾀﾞﾃﾑﾗ"),
    "023817": MunicipalityEntry(MunicipalityCode("023817"), "青森県", "板柳町", "ｱｵﾓﾘｹﾝ", "ｲﾀﾔﾅｷﾞﾏﾁ"),
    "023841": MunicipalityEntry(MunicipalityCode("023841"), "青森県", "鶴田町", "ｱｵﾓﾘｹﾝ", "ﾂﾙﾀﾏﾁ"),
    "023876": MunicipalityEntry(MunicipalityCode("023876"), "青森県", "中泊町", "ｱｵﾓﾘｹﾝ", "ﾅｶﾄﾞﾏﾘﾏﾁ"),
    "024015": MunicipalityEntry(MunicipalityCode("024015"), "青森県", "野辺地町", "ｱｵﾓﾘｹﾝ", "ﾉﾍｼﾞﾏﾁ"),
    "024023": MunicipalityEntry(MunicipalityCode("024023"), "青森県", "七戸町", "ｱｵﾓﾘｹﾝ", "ｼﾁﾉﾍﾏﾁ"),
    "024058": MunicipalityEntry(MunicipalityCode("024058"), "青森県", "六戸町", "ｱｵﾓﾘｹﾝ", "ﾛｸﾉﾍﾏﾁ"),
    "024066": MunicipalityEntry(MunicipalityCode("024066"), "青森県", "横浜町", "ｱｵﾓﾘｹﾝ", "ﾖｺﾊﾏﾏﾁ"),
    "024082": MunicipalityEntry(MunicipalityCode("024082"), "青森県", "東北町", "ｱｵﾓﾘｹﾝ", "ﾄｳﾎｸﾏﾁ"),
    "024112": MunicipalityEntry(MunicipalityCode("024112"), "青森県", "六ヶ所村", "ｱｵﾓﾘｹﾝ", "ﾛｯｶｼｮﾑﾗ"),
    "024121": MunicipalityEntry(MunicipalityCode("024121"), "青森県", "おいらせ町", "ｱｵﾓﾘｹﾝ", "ｵｲﾗｾﾁｮｳ"),
    "024236": MunicipalityEntry(MunicipalityCode("024236"), "青森県", "大間町", "ｱｵﾓﾘｹﾝ", "ｵｵﾏﾏﾁ"),
    "024244": MunicipalityEntry(MunicipalityCode("024244"), "青森県", "東通村", "ｱｵﾓﾘｹﾝ", "ﾋｶﾞｼﾄﾞｵﾘﾑﾗ"),
    "024252": MunicipalityEntry(MunicipalityCode("024252"), "青森県", "風間浦村", "ｱｵﾓﾘｹﾝ", "ｶｻﾞﾏｳﾗﾑﾗ"),
    "024261": MunicipalityEntry(MunicipalityCode("024261"), "青森県", "佐井村", "ｱｵﾓﾘｹﾝ", "ｻｲﾑﾗ"),
    "024414": MunicipalityEntry(MunicipalityCode("024414"), "青森県", "三戸町", "ｱｵﾓﾘｹﾝ", "ｻﾝﾉﾍﾏﾁ"),
    "024422": MunicipalityEntry(MunicipalityCode("024422"), "青森県", "五戸町", "ｱｵﾓﾘｹﾝ", "ｺﾞﾉﾍﾏﾁ"),
    "024431": MunicipalityEntry(MunicipalityCode("024431"), "青森県", "田子町", "ｱｵﾓﾘｹﾝ", "ﾀｯｺﾏﾁ"),
    "024457": MunicipalityEntry(MunicipalityCode("024457"), "青森県", "南部町", "ｱｵﾓﾘｹﾝ", "ﾅﾝﾌﾞﾁｮｳ"),
    "024465": MunicipalityEntry(MunicipalityCode("024465"), "青森県", "階上町", "ｱｵﾓﾘｹﾝ", "ﾊｼｶﾐﾁｮｳ"),
    "024503": MunicipalityEntry(MunicipalityCode("024503"), "青森県", "新郷村", "ｱｵﾓﾘｹﾝ", "ｼﾝｺﾞｳﾑﾗ"),
    "030007": MunicipalityEntry(MunicipalityCode("030007"), "岩手県", "", "ｲﾜﾃｹﾝ", ""),
    "032018": MunicipalityEntry(MunicipalityCode("032018"), "岩手県", "盛岡市", "ｲﾜﾃｹﾝ", "ﾓﾘｵｶｼ"),
    "032026": MunicipalityEntry(MunicipalityCode("032026"), "岩手県", "宮古市", "ｲﾜﾃｹﾝ", "ﾐﾔｺｼ"),
    "032034": MunicipalityEntry(MunicipalityCode("032034"), "岩手県", "大船渡市", "ｲﾜﾃｹﾝ", "ｵｵﾌﾅﾄｼ"),
    "032051": MunicipalityEntry(MunicipalityCode("032051"), "岩手県", "花巻市", "ｲﾜﾃｹﾝ", "ﾊﾅﾏｷｼ"),
    "032069": MunicipalityEntry(MunicipalityCode("032069"), "岩手県", "北上市", "ｲﾜﾃｹﾝ", "ｷﾀｶﾐｼ"),
    "032077": MunicipalityEntry(MunicipalityCode("032077"), "岩手県", "久慈市", "ｲﾜﾃｹﾝ", "ｸｼﾞｼ"),
    "032085": MunicipalityEntry(MunicipalityCode("032085"), "岩手県", "遠野市", "ｲﾜﾃｹﾝ", "ﾄｵﾉｼ"),
    "032093": MunicipalityEntry(MunicipalityCode("032093"), "岩手県", "一関市", "ｲﾜﾃｹﾝ", "ｲﾁﾉｾｷｼ"),
    "032107": MunicipalityEntry(MunicipalityCode("032107"), "岩手県", "陸前高田市", "ｲﾜﾃｹﾝ", "ﾘｸｾﾞﾝﾀｶﾀｼ"),
    "032115": MunicipalityEntry(MunicipalityCode("032115"), "岩手県", "釜石市", "ｲﾜﾃｹﾝ", "ｶﾏｲｼｼ"),
    "032131": MunicipalityEntry(MunicipalityCode("032131"), "岩手県", "二戸市", "ｲﾜﾃｹﾝ", "ﾆﾉﾍｼ"),
    "032140": MunicipalityEntry(MunicipalityCode("032140"), "岩手県", "八幡平市", "ｲﾜﾃｹﾝ", "ﾊﾁﾏﾝﾀｲｼ"),
    "032158": MunicipalityEntry(MunicipalityCode("032158"), "岩手県", "奥州市", "ｲﾜﾃｹﾝ", "ｵｳｼｭｳｼ"),
    "032166": MunicipalityEntry(MunicipalityCode("032166"), "岩手県", "滝沢市", "ｲﾜﾃｹﾝ", "ﾀｷｻﾞﾜｼ"),
    "033014": MunicipalityEntry(MunicipalityCode("033014"), "岩手県", "雫石町", "ｲﾜﾃｹﾝ", "ｼｽﾞｸｲｼﾁｮｳ"),
    "033022": MunicipalityEntry(MunicipalityCode("033022"), "岩手県", "葛巻町", "ｲﾜﾃｹﾝ", "ｸｽﾞﾏｷﾏﾁ"),
    "033031": MunicipalityEntry(MunicipalityCode("033031"), "岩手県", "岩手町", "ｲﾜﾃｹﾝ", "ｲﾜﾃﾏﾁ"),
    "033219": MunicipalityEntry(MunicipalityCode("033219"), "岩手県", "紫波町", "ｲﾜﾃｹﾝ", "ｼﾜﾁｮｳ"),
    "033227": MunicipalityEntry(MunicipalityCode("033227"), "岩手県", "矢巾町", "ｲﾜﾃｹﾝ", "ﾔﾊﾊﾞﾁｮｳ"),
    "033669": MunicipalityEntry(MunicipalityCode("033669"), "岩手県", "西和賀町", "ｲﾜﾃｹﾝ", "ﾆｼﾜｶﾞﾏﾁ"),
    "033812": MunicipalityEntry(MunicipalityCode("033812"), "岩手県", "金ケ崎町", "ｲﾜﾃｹﾝ", "ｶﾈｶﾞｻｷﾁｮｳ"),
    "034029": MunicipalityEntry(MunicipalityCode("034029"), "岩手県", "平泉町", "ｲﾜﾃｹﾝ", "ﾋﾗｲｽﾞﾐﾁｮｳ"),
    "034410": MunicipalityEntry(MunicipalityCode("034410"), "岩手県", "住田町", "ｲﾜﾃｹﾝ", "ｽﾐﾀﾁｮｳ"),
    "034614": MunicipalityEntry(MunicipalityCode("034614"), "岩手県", "大槌町", "ｲﾜﾃｹﾝ", "ｵｵﾂﾁﾁｮｳ"),
    "034827": MunicipalityEntry(MunicipalityCode("034827"), "岩手県", "山田町", "ｲﾜﾃｹﾝ", "ﾔﾏﾀﾞﾏﾁ"),
    "034835": MunicipalityEntry(MunicipalityCode("034835"), "岩手県", "岩泉町", "ｲﾜﾃｹﾝ", "ｲﾜｲｽﾞﾐﾁｮｳ"),
    "034843": MunicipalityEntry(MunicipalityCode("034843"), "岩手県", "田野畑村", "ｲﾜﾃｹﾝ", "ﾀﾉﾊﾀﾑﾗ"),
    "034851": MunicipalityEntry(MunicipalityCode("034851"), "岩手県", "普代村", "ｲﾜﾃｹﾝ", "ﾌﾀﾞｲﾑﾗ"),
    "035017": MunicipalityEntry(MunicipalityCode("035017"), "岩手県", "軽米町", "ｲﾜﾃｹﾝ", "ｶﾙﾏｲﾏﾁ"),
    "035033": MunicipalityEntry(MunicipalityCode("035033"), "岩手県", "野田村", "ｲﾜﾃｹﾝ", "ﾉﾀﾞﾑﾗ"),
    "035068": MunicipalityEntry(MunicipalityCode("035068"), "岩手県", "九戸村", "ｲﾜﾃｹﾝ", "ｸﾉﾍﾑﾗ"),
    "035076": MunicipalityEntry(MunicipalityCode("035076"), "岩手県", "洋野町", "ｲﾜﾃｹﾝ", "ﾋﾛﾉﾁｮｳ"),
    "035246": MunicipalityEntry(MunicipalityCode("035246"), "岩手県", "一戸町", "ｲﾜﾃｹﾝ", "ｲﾁﾉﾍﾏﾁ"),
    "040002": MunicipalityEntry(MunicipalityCode("040002"), "宮城県", "", "ﾐﾔｷﾞｹﾝ", ""),
    "041009": MunicipalityEntry(MunicipalityCode("041009"), "宮城県", "仙台市", "ﾐﾔｷﾞｹﾝ", "ｾﾝﾀﾞｲｼ"),
    "042021": MunicipalityEntry(MunicipalityCode("042021"), "宮城県", "石巻市", "ﾐﾔｷﾞｹﾝ", "ｲｼﾉﾏｷｼ"),
    "042030": MunicipalityEntry(MunicipalityCode("042030"), "宮城県", "塩竈市", "ﾐﾔｷﾞｹﾝ", "ｼｵｶﾞﾏｼ"),
    "042056": MunicipalityEntry(MunicipalityCode("042056"), "宮城県", "気仙沼市", "ﾐﾔｷﾞｹﾝ", "ｹｾﾝﾇﾏｼ"),
    "042064": MunicipalityEntry(MunicipalityCode("042064"), "宮城県", "白石市", "ﾐﾔｷﾞｹﾝ", "ｼﾛｲｼｼ"),
    "042072": MunicipalityEntry(MunicipalityCode("042072"), "宮城県", "名取市", "ﾐﾔｷﾞｹﾝ", "ﾅﾄﾘｼ"),
    "042081": MunicipalityEntry(MunicipalityCode("042081"), "宮城県", "角田市", "ﾐﾔｷﾞｹﾝ", "ｶｸﾀﾞｼ"),
    "042099": MunicipalityEntry(MunicipalityCode("042099"), "宮城県", "多賀城市", "ﾐﾔｷﾞｹﾝ", "ﾀｶﾞｼﾞｮｳｼ"),
    "042111": MunicipalityEntry(MunicipalityCode("042111"), "宮城県", "岩沼市", "ﾐﾔｷﾞｹﾝ", "ｲﾜﾇﾏｼ"),
    "042129": MunicipalityEntry(MunicipalityCode("042129"), "宮城県", "登米市", "ﾐﾔｷﾞｹﾝ", "ﾄﾒｼ"),
    "042137": MunicipalityEntry(MunicipalityCode("042137"), "宮城県", "栗原市", "ﾐﾔｷﾞｹﾝ", "ｸﾘﾊﾗｼ"),
    "042145": MunicipalityEntry(MunicipalityCode("042145"), "宮城県", "東松島市", "ﾐﾔｷﾞｹﾝ", "ﾋｶﾞｼﾏﾂｼﾏｼ"),
    "042153": MunicipalityEntry(MunicipalityCode("042153"), "宮城県", "大崎市", "ﾐﾔｷﾞｹﾝ", "ｵｵｻｷｼ"),
    "042161": MunicipalityEntry(MunicipalityCode("042161"), "宮城県", "富谷市", "ﾐﾔｷﾞｹﾝ", "ﾄﾐﾔｼ"),
    "043010": MunicipalityEntry(MunicipalityCode("043010"), "宮城県", "蔵王町", "ﾐﾔｷﾞｹﾝ", "ｻﾞｵｳﾏﾁ"),
    "043028": MunicipalityEntry(MunicipalityCode("043028"), "宮城県", "七ヶ宿町", "ﾐﾔｷﾞｹﾝ", "ｼﾁｶｼｭｸﾏﾁ"),
    "043214": MunicipalityEntry(MunicipalityCode("043214"), "宮城県", "大河原町", "ﾐﾔｷﾞｹﾝ", "ｵｵｶﾞﾜﾗﾏﾁ"),
    "043222": MunicipalityEntry(MunicipalityCode("043222"), "宮城県", "村田町", "ﾐﾔｷﾞｹﾝ", "ﾑﾗﾀﾏﾁ"),
    "043231": MunicipalityEntry(MunicipalityCode("043231"), "宮城県", "柴田町", "ﾐﾔｷﾞｹﾝ", "ｼﾊﾞﾀﾏﾁ"),
    "043249": MunicipalityEntry(MunicipalityCode("043249"), "宮城県", "川崎町", "ﾐﾔｷﾞｹﾝ", "ｶﾜｻｷﾏﾁ"),
    "043419": MunicipalityEntry(MunicipalityCode("043419"), "宮城県", "丸森町", "ﾐﾔｷﾞｹﾝ", "ﾏﾙﾓﾘﾏﾁ"),
    "043613": MunicipalityEntry(MunicipalityCode("043613"), "宮城県", "亘理町", "ﾐﾔｷﾞｹﾝ", "ﾜﾀﾘﾁｮｳ"),
    "043621": MunicipalityEntry(MunicipalityCode("043621"), "宮城県", "山元町", "ﾐﾔｷﾞｹﾝ", "ﾔﾏﾓﾄﾁｮｳ"),
    "044016": MunicipalityEntry(MunicipalityCode("044016"), "宮城県", "松島町", "ﾐﾔｷﾞｹﾝ", "ﾏﾂｼﾏﾏﾁ"),
    "044041": MunicipalityEntry(MunicipalityCode("044041"), "宮城県", "七ヶ浜町", "ﾐﾔｷﾞｹﾝ", "ｼﾁｶﾞﾊﾏﾏﾁ"),
    "044067": MunicipalityEntry(MunicipalityCode("044067"), "宮城県", "利府町", "ﾐﾔｷﾞｹﾝ", "ﾘﾌﾁｮｳ"),
    "044211": MunicipalityEntry(MunicipalityCode("044211"), "宮城県", "大和町", "ﾐﾔｷﾞｹﾝ", "ﾀｲﾜﾁｮｳ"),
    "044229": MunicipalityEntry(MunicipalityCode("044229"), "宮城県", "大郷町", "ﾐﾔｷﾞｹﾝ", "ｵｵｻﾄﾁｮｳ"),
    "044245": MunicipalityEntry(MunicipalityCode("044245"), "宮城県", "大衡村", "ﾐﾔｷﾞｹﾝ", "ｵｵﾋﾗﾑﾗ"),
    "044440": MunicipalityEntry(MunicipalityCode("044440"), "宮城県", "色麻町", "ﾐﾔｷﾞｹﾝ", "ｼｶﾏﾁｮｳ"),
    "044458": MunicipalityEntry(MunicipalityCode("044458"), "宮城県", "加美町", "ﾐﾔｷﾞｹﾝ", "ｶﾐﾏﾁ"),
    "045012": MunicipalityEntry(MunicipalityCode("045012"), "宮城県", "涌谷町", "ﾐﾔｷﾞｹﾝ", "ﾜｸﾔﾁｮｳ"),
    "045055": MunicipalityEntry(MunicipalityCode("045055"), "宮城県", "美里町", "ﾐﾔｷﾞｹﾝ", "ﾐｻﾄﾏﾁ"),
    "045811": MunicipalityEntry(MunicipalityCode("045811"), "宮城県", "女川町", "ﾐﾔｷﾞｹﾝ", "ｵﾅｶﾞﾜﾁｮｳ"),
    "046060": MunicipalityEntry(MunicipalityCode("046060"), "宮城県", "南三陸町", "ﾐﾔｷﾞｹﾝ", "ﾐﾅﾐｻﾝﾘｸﾁｮｳ"),
    "050008": MunicipalityEntry(MunicipalityCode("050008"), "秋田県", "", "ｱｷﾀｹﾝ", ""),
    "052019": MunicipalityEntry(MunicipalityCode("052019"), "秋田県", "秋田市", "ｱｷﾀｹﾝ", "ｱｷﾀｼ"),
    "052027": MunicipalityEntry(MunicipalityCode("052027"), "秋田県", "能代市", "ｱｷﾀｹﾝ", "ﾉｼﾛｼ"),
    "052035": MunicipalityEntry(MunicipalityCode("052035"), "秋田県", "横手市", "ｱｷﾀｹﾝ", "ﾖｺﾃｼ"),
    "052043": MunicipalityEntry(MunicipalityCode("052043"), "秋田県", "大館市", "ｱｷﾀｹﾝ", "ｵｵﾀﾞﾃｼ"),
    "052060": MunicipalityEntry(MunicipalityCode("052060"), "秋田県", "男鹿市", "ｱｷﾀｹﾝ", "ｵｶﾞｼ"),
    "052078": MunicipalityEntry(MunicipalityCode("052078"), "秋田県", "湯沢市", "ｱｷﾀｹﾝ", "ﾕｻﾞﾜｼ"),
    "052094": MunicipalityEntry(MunicipalityCode("052094"), "秋田県", "鹿角市", "ｱｷﾀｹﾝ", "ｶﾂﾞﾉｼ"),
    "052108": MunicipalityEntry(MunicipalityCode("052108"), "秋田県", "由利本荘市", "ｱｷﾀｹﾝ", "ﾕﾘﾎﾝｼﾞｮｳｼ"),
    "052116": MunicipalityEntry(MunicipalityCode("052116"), "秋田県", "潟上市", "ｱｷﾀｹﾝ", "ｶﾀｶﾞﾐｼ"),
    "052124": MunicipalityEntry(MunicipalityCode("052124"), "秋田県", "大仙市", "ｱｷﾀｹﾝ", "ﾀﾞｲｾﾝｼ"),
    "052132": MunicipalityEntry(MunicipalityCode("052132"), "秋田県", "北秋田市", "ｱｷﾀｹﾝ", "ｷﾀｱｷﾀｼ"),
    "052141": MunicipalityEntry(MunicipalityCode("052141"), "秋田県", "にかほ市", "ｱｷﾀｹﾝ", "ﾆｶﾎｼ"),
    "052159": MunicipalityEntry(MunicipalityCode("052159"), "秋田県", "仙北市", "ｱｷﾀｹﾝ", "ｾﾝﾎﾞｸｼ"),
    "053031": MunicipalityEntry(MunicipalityCode("053031"), "秋田県", "小坂町", "ｱｷﾀｹﾝ", "ｺｻｶﾏﾁ"),
    "053279": MunicipalityEntry(MunicipalityCode("053279"), "秋田県", "上小阿仁村", "ｱｷﾀｹﾝ", "ｶﾐｺｱﾆﾑﾗ"),
    "053465": MunicipalityEntry(MunicipalityCode("053465"), "秋田県", "藤里町", "ｱｷﾀｹﾝ", "ﾌｼﾞｻﾄﾏﾁ"),
    "053481": MunicipalityEntry(MunicipalityCode("053481"), "秋田県", "三種町", "ｱｷﾀｹﾝ", "ﾐﾀﾈﾁｮｳ"),
    "053490": MunicipalityEntry(MunicipalityCode("053490"), "秋田県", "八峰町", "ｱｷﾀｹﾝ", "ﾊｯﾎﾟｳﾁｮｳ"),
    "053619": MunicipalityEntry(MunicipalityCode("053619"), "秋田県", "五城目町", "ｱｷﾀｹﾝ", "ｺﾞｼﾞｮｳﾒﾏﾁ"),
    "053635": MunicipalityEntry(MunicipalityCode("053635"), "秋田県", "八郎潟町", "ｱｷﾀｹﾝ", "ﾊﾁﾛｳｶﾞﾀﾏﾁ"),
    "053660": MunicipalityEntry(MunicipalityCode("053660"), "秋田県", "井川町", "ｱｷﾀｹﾝ", "ｲｶﾜﾏﾁ"),
    "053686": MunicipalityEntry(MunicipalityCode("053686"), "秋田県", "大潟村", "ｱｷﾀｹﾝ", "ｵｵｶﾞﾀﾑﾗ"),
    "054348": MunicipalityEntry(MunicipalityCode("054348"), "秋田県", "美郷町", "ｱｷﾀｹﾝ", "ﾐｻﾄﾁｮｳ"),
    "054631": MunicipalityEntry(MunicipalityCode("054631"), "秋田県", "羽後町", "ｱｷﾀｹﾝ", "ｳｺﾞﾏﾁ"),
    "054640": MunicipalityEntry(MunicipalityCode("054640"), "秋田県", "東成瀬村", "ｱｷﾀｹﾝ", "ﾋｶﾞｼﾅﾙｾﾑﾗ"),
    "060003": MunicipalityEntry(MunicipalityCode("060003"), "山形県", "", "ﾔﾏｶﾞﾀｹﾝ", ""),
    "062014": MunicipalityEntry(MunicipalityCode("062014"), "山形県", "山形市", "ﾔﾏｶﾞﾀｹﾝ", "ﾔﾏｶﾞﾀｼ"),
    "062022": MunicipalityEntry(MunicipalityCode("062022"), "山形県", "米沢市", "ﾔﾏｶﾞﾀｹﾝ", "ﾖﾈｻﾞﾜｼ"),
    "062031": MunicipalityEntry(MunicipalityCode("062031"), "山形県", "鶴岡市", "ﾔﾏｶﾞﾀｹﾝ", "ﾂﾙｵｶｼ"),
    "062049": MunicipalityEntry(MunicipalityCode("062049"), "山形県", "酒田市", "ﾔﾏｶﾞﾀｹﾝ", "ｻｶﾀｼ"),
    "062057": MunicipalityEntry(MunicipalityCode("062057"), "山形県", "新庄市", "ﾔﾏｶﾞﾀｹﾝ", "ｼﾝｼﾞｮｳｼ"),
    "062065": MunicipalityEntry(MunicipalityCode("062065"), "山形県", "寒河江市", "ﾔﾏｶﾞﾀｹﾝ", "ｻｶﾞｴｼ"),
    "062073": MunicipalityEntry(MunicipalityCode("062073"), "山形県", "上山市", "ﾔﾏｶﾞﾀｹﾝ", "ｶﾐﾉﾔﾏｼ"),
    "062081": MunicipalityEntry(MunicipalityCode("062081"), "山形県", "村山市", "ﾔﾏｶﾞﾀｹﾝ", "ﾑﾗﾔﾏｼ"),
    "062090": MunicipalityEntry(MunicipalityCode("062090"), "山形県", "長井市", "ﾔﾏｶﾞﾀｹﾝ", "ﾅｶﾞｲｼ"),
    "062103": MunicipalityEntry(MunicipalityCode("062103"), "山形県", "天童市", "ﾔﾏｶﾞﾀｹﾝ", "ﾃﾝﾄﾞｳｼ"),
    "062111": MunicipalityEntry(MunicipalityCode("062111"), "山形県", "東根市", "ﾔﾏｶﾞﾀｹﾝ", "ﾋｶﾞｼﾈｼ"),
    "062120": MunicipalityEntry(MunicipalityCode("062120"), "山形県", "尾花沢市", "ﾔﾏｶﾞﾀｹﾝ", "ｵﾊﾞﾅｻﾞﾜｼ"),
    "062138": MunicipalityEntry(MunicipalityCode("062138"), "山形県", "南陽市", "ﾔﾏｶﾞﾀｹﾝ", "ﾅﾝﾖｳｼ"),
    "063011": MunicipalityEntry(MunicipalityCode("063011"), "山形県", "山辺町", "ﾔﾏｶﾞﾀｹﾝ", "ﾔﾏﾉﾍﾞﾏﾁ"),
    "063029": MunicipalityEntry(MunicipalityCode("063029"), "山形県", "中山町", "ﾔﾏｶﾞﾀｹﾝ", "ﾅｶﾔﾏﾏﾁ"),
    "063215": MunicipalityEntry(MunicipalityCode("063215"), "山形県", "河北町", "ﾔﾏｶﾞﾀｹﾝ", "ｶﾎｸﾁｮｳ"),
    "063223": MunicipalityEntry(MunicipalityCode("063223"), "山形県", "西川町", "ﾔﾏｶﾞﾀｹﾝ", "ﾆｼｶﾜﾏﾁ"),
    "063231": MunicipalityEntry(MunicipalityCode("063231"), "山形県", "朝日町", "ﾔﾏｶﾞﾀｹﾝ", "ｱｻﾋﾏﾁ"),
    "063240": MunicipalityEntry(MunicipalityCode("063240"), "山形県", "大江町", "ﾔﾏｶﾞﾀｹﾝ", "ｵｵｴﾏﾁ"),
    "063410": MunicipalityEntry(MunicipalityCode("063410"), "山形県", "大石田町", "ﾔﾏｶﾞﾀｹﾝ", "ｵｵｲｼﾀﾞﾏﾁ"),
    "063614": MunicipalityEntry(MunicipalityCode("063614"), "山形県", "金山町", "ﾔﾏｶﾞﾀｹﾝ", "ｶﾈﾔﾏﾏﾁ"),
    "063622": MunicipalityEntry(MunicipalityCode("063622"), "山形県", "最上町", "ﾔﾏｶﾞﾀｹﾝ", "ﾓｶﾞﾐﾏﾁ"),
    "063631": MunicipalityEntry(MunicipalityCode("063631"), "山形県", "舟形町", "ﾔﾏｶﾞﾀｹﾝ", "ﾌﾅｶﾞﾀﾏﾁ"),
    "063649": MunicipalityEntry(MunicipalityCode("063649"), "山形県", "真室川町", "ﾔﾏｶﾞﾀｹﾝ", "ﾏﾑﾛｶﾞﾜﾏﾁ"),
    "063657": MunicipalityEntry(MunicipalityCode("063657"), "山形県", "大蔵村", "ﾔﾏｶﾞﾀｹﾝ", "ｵｵｸﾗﾑﾗ"),
    "063665": MunicipalityEntry(MunicipalityCode("063665"), "山形県", "鮭川村", "ﾔﾏｶﾞﾀｹﾝ", "ｻｹｶﾞﾜﾑﾗ"),
    "063673": MunicipalityEntry(MunicipalityCode("063673"), "山形県", "戸沢村", "ﾔﾏｶﾞﾀｹﾝ", "ﾄｻﾞﾜﾑﾗ"),
    "063819": MunicipalityEntry(MunicipalityCode("063819"), "山形県", "高畠町", "ﾔﾏｶﾞﾀｹﾝ", "ﾀｶﾊﾀﾏﾁ"),
    "063827": MunicipalityEntry(MunicipalityCode("063827"), "山形県", "川西町", "ﾔﾏｶﾞﾀｹﾝ", "ｶﾜﾆｼﾏﾁ"),
    "064017": MunicipalityEntry(MunicipalityCode("064017"), "山形県", "小国町", "ﾔﾏｶﾞﾀｹﾝ", "ｵｸﾞﾆﾏﾁ"),
    "064025": MunicipalityEntry(MunicipalityCode("064025"), "山形県", "白鷹町", "ﾔﾏｶﾞﾀｹﾝ", "ｼﾗﾀｶﾏﾁ"),
    "064033": MunicipalityEntry(MunicipalityCode("064033"), "山形県", "飯豊町", "ﾔﾏｶﾞﾀｹﾝ", "ｲｲﾃﾞﾏﾁ"),
    "064262": MunicipalityEntry(MunicipalityCode("064262"), "山形県", "三川町", "ﾔﾏｶﾞﾀｹﾝ", "ﾐｶﾜﾏﾁ"),
    "064289": MunicipalityEntry(MunicipalityCode("064289"), "山形県", "庄内町", "ﾔﾏｶﾞﾀｹﾝ", "ｼﾖｳﾅｲﾏﾁ"),
    "064611": MunicipalityEntry(MunicipalityCode("064611"), "山形県", "遊佐町", "ﾔﾏｶﾞﾀｹﾝ", "ﾕｻﾞﾏﾁ"),
    "070009": MunicipalityEntry(MunicipalityCode("070009"), "福島県", "", "ﾌｸｼﾏｹﾝ", ""),
    "072010": MunicipalityEntry(MunicipalityCode("072010"), "福島県", "福島市", "ﾌｸｼﾏｹﾝ", "ﾌｸｼﾏｼ"),
    "072028": MunicipalityEntry(MunicipalityCode("072028"), "福島県", "会津若松市", "ﾌｸｼﾏｹﾝ", "ｱｲﾂﾞﾜｶﾏﾂｼ"),
    "072036": MunicipalityEntry(MunicipalityCode("072036"), "福島県", "郡山市", "ﾌｸｼﾏｹﾝ", "ｺｵﾘﾔﾏｼ"),
    "072044": MunicipalityEntry(MunicipalityCode("072044"), "福島県", "いわき市", "ﾌｸｼﾏｹﾝ", "ｲﾜｷｼ"),
    "072052": MunicipalityEntry(MunicipalityCode("072052"), "福島県", "白河市", "ﾌｸｼﾏｹﾝ", "ｼﾗｶﾜｼ"),
    "072079": MunicipalityEntry(MunicipalityCode("072079"), "福島県", "須賀川市", "ﾌｸｼﾏｹﾝ", "ｽｶｶﾞﾜｼ"),
    "072087": MunicipalityEntry(MunicipalityCode("072087"), "福島県", "喜多方市", "ﾌｸｼﾏｹﾝ", "ｷﾀｶﾀｼ"),
    "072095": MunicipalityEntry(MunicipalityCode("072095"), "福島県", "相馬市", "ﾌｸｼﾏｹﾝ", "ｿｳﾏｼ"),
    "072109": MunicipalityEntry(MunicipalityCode("072109"), "福島県", "二本松市", "ﾌｸｼﾏｹﾝ", "ﾆﾎﾝﾏﾂｼ"),
    "072117": MunicipalityEntry(MunicipalityCode("072117"), "福島県", "田村市", "ﾌｸｼﾏｹﾝ", "ﾀﾑﾗｼ"),
    "072125": MunicipalityEntry(MunicipalityCode("072125"), "福島県", "南相馬市", "ﾌｸｼﾏｹﾝ", "ﾐﾅﾐｿｳﾏｼ"),
    "072133": MunicipalityEntry(MunicipalityCode("072133"), "福島県", "伊達市", "ﾌｸｼﾏｹﾝ", "ﾀﾞﾃｼ"),
    "072141": MunicipalityEntry(MunicipalityCode("072141"), "福島県", "本宮市", "ﾌｸｼﾏｹﾝ", "ﾓﾄﾐﾔｼ"),
    "073016": MunicipalityEntry(MunicipalityCode("073016"), "福島県", "桑折町", "ﾌｸｼﾏｹﾝ", "ｺｵﾘﾏﾁ"),
    "073032": MunicipalityEntry(MunicipalityCode("073032"), "福島県", "国見町", "ﾌｸｼﾏｹﾝ", "ｸﾆﾐﾏﾁ"),
    "073083": MunicipalityEntry(MunicipalityCode("073083"), "福島県", "川俣町", "ﾌｸｼﾏｹﾝ", "ｶﾜﾏﾀﾏﾁ"),
    "073229": MunicipalityEntry(MunicipalityCode("073229"), "福島県", "大玉村", "ﾌｸｼﾏｹﾝ", "ｵｵﾀﾏﾑﾗ"),
    "073423": MunicipalityEntry(MunicipalityCode("073423"), "福島県", "鏡石町", "ﾌｸｼﾏｹﾝ", "ｶｶﾞﾐｲｼﾏﾁ"),
    "073440": MunicipalityEntry(MunicipalityCode("073440"), "福島県", "天栄村", "ﾌｸｼﾏｹﾝ", "ﾃﾝｴｲﾑﾗ"),
    "073628": MunicipalityEntry(MunicipalityCode("073628"), "福島県", "下郷町", "ﾌｸｼﾏｹﾝ", "ｼﾓｺﾞｳﾏﾁ"),
    "073644": MunicipalityEntry(MunicipalityCode("073644"), "福島県", "檜枝岐村", "ﾌｸｼﾏｹﾝ", "ﾋﾉｴﾏﾀﾑﾗ"),
    "073679": MunicipalityEntry(MunicipalityCode("073679"), "福島県", "只見町", "ﾌｸｼﾏｹﾝ", "ﾀﾀﾞﾐﾏﾁ"),
    "073687": MunicipalityEntry(MunicipalityCode("073687"), "福島県", "南会津町", "ﾌｸｼﾏｹﾝ", "ﾐﾅﾐｱｲﾂﾞﾏﾁ"),
    "074021": MunicipalityEntry(MunicipalityCode("074021"), "福島県", "北塩原村", "ﾌｸｼﾏｹﾝ", "ｷﾀｼｵﾊﾞﾗﾑﾗ"),
    "074055": MunicipalityEntry(MunicipalityCode("074055"), "福島県", "西会津町", "ﾌｸｼﾏｹﾝ", "ﾆｼｱｲﾂﾞﾏﾁ"),
    "074071": MunicipalityEntry(MunicipalityCode("074071"), "福島県", "磐梯町", "ﾌｸｼﾏｹﾝ", "ﾊﾞﾝﾀﾞｲﾏﾁ"),
    "074080": MunicipalityEntry(MunicipalityCode("074080"), "福島県", "猪苗代町", "ﾌｸｼﾏｹﾝ", "ｲﾅﾜｼﾛﾏﾁ"),
    "074217": MunicipalityEntry(MunicipalityCode("074217"), "福島県", "会津坂下町", "ﾌｸｼﾏｹﾝ", "ｱｲﾂﾞﾊﾞﾝｹﾞﾏﾁ"),
    "074225": MunicipalityEntry(MunicipalityCode("074225"), "福島県", "湯川村", "ﾌｸｼﾏｹﾝ", "ﾕｶﾞﾜﾑﾗ"),
    "074233": MunicipalityEntry(MunicipalityCode("074233"), "福島県", "柳津町", "ﾌｸｼﾏｹﾝ", "ﾔﾅｲﾂﾞﾏﾁ"),
    "074446": MunicipalityEntry(MunicipalityCode("074446"), "福島県", "三島町", "ﾌｸｼﾏｹﾝ", "ﾐｼﾏﾏﾁ"),
    "074454": MunicipalityEntry(MunicipalityCode("074454"), "福島県", "金山町", "ﾌｸｼﾏｹﾝ", "ｶﾈﾔﾏﾏﾁ"),
    "074462": MunicipalityEntry(MunicipalityCode("074462"), "福島県", "昭和村", "ﾌｸｼﾏｹﾝ", "ｼｮｳﾜﾑﾗ"),
    "074471": MunicipalityEntry(MunicipalityCode("074471"), "福島県", "会津美里町", "ﾌｸｼﾏｹﾝ", "ｱｲﾂﾞﾐｻﾄﾏﾁ"),
    "074616": MunicipalityEntry(MunicipalityCode("074616"), "福島県", "西郷村", "ﾌｸｼﾏｹﾝ", "ﾆｼｺﾞｳﾑﾗ"),
    "074641": MunicipalityEntry(MunicipalityCode("074641"), "福島県", "泉崎村", "ﾌｸｼﾏｹﾝ", "ｲｽﾞﾐｻﾞｷﾑﾗ"),
    "074659": MunicipalityEntry(MunicipalityCode("074659"), "福島県", "中島村", "ﾌｸｼﾏｹﾝ", "ﾅｶｼﾞﾏﾑﾗ"),
    "074667": MunicipalityEntry(MunicipalityCode("074667"), "福島県", "矢吹町", "ﾌｸｼﾏｹﾝ", "ﾔﾌﾞｷﾏﾁ"),
    "074811": MunicipalityEntry(MunicipalityCode("074811"), "福島県", "棚倉町", "ﾌｸｼﾏｹﾝ", "ﾀﾅｸﾞﾗﾏﾁ"),
    "074829": MunicipalityEntry(MunicipalityCode("074829"), "福島県", "矢祭町", "ﾌｸｼﾏｹﾝ", "ﾔﾏﾂﾘﾏﾁ"),
    "074837": MunicipalityEntry(MunicipalityCode("074837"), "福島県", "塙町", "ﾌｸｼﾏｹﾝ", "ﾊﾅﾜﾏﾁ"),
    "074845": MunicipalityEntry(MunicipalityCode("074845"), "福島県", "鮫川村", "ﾌｸｼﾏｹﾝ", "ｻﾒｶﾞﾜﾑﾗ"),
    "075019": MunicipalityEntry(MunicipalityCode("075019"), "福島県", "石川町", "ﾌｸｼﾏｹﾝ", "ｲｼｶﾜﾏﾁ"),
    "075027": MunicipalityEntry(MunicipalityCode("075027"), "福島県", "玉川村", "ﾌｸｼﾏｹﾝ", "ﾀﾏｶﾜﾑﾗ"),
    "075035": MunicipalityEntry(MunicipalityCode("075035"), "福島県", "平田村", "ﾌｸｼﾏｹﾝ", "ﾋﾗﾀﾑﾗ"),
    "075043": MunicipalityEntry(MunicipalityCode("075043"), "福島県", "浅川町", "ﾌｸｼﾏｹﾝ", "ｱｻｶﾜﾏﾁ"),
    "075051": MunicipalityEntry(MunicipalityCode("075051"), "福島県", "古殿町", "ﾌｸｼﾏｹﾝ", "ﾌﾙﾄﾞﾉﾏﾁ"),
    "075213": MunicipalityEntry(MunicipalityCode("075213"), "福島県", "三春町", "ﾌｸｼﾏｹﾝ", "ﾐﾊﾙﾏﾁ"),
    "075221": MunicipalityEntry(MunicipalityCode("075221"), "福島県", "小野町", "ﾌｸｼﾏｹﾝ", "ｵﾉﾏﾁ"),
    "075418": MunicipalityEntry(MunicipalityCode("075418"), "福島県", "広野町", "ﾌｸｼﾏｹﾝ", "ﾋﾛﾉﾏﾁ"),
    "075426": MunicipalityEntry(MunicipalityCode("075426"), "福島県", "楢葉町", "ﾌｸｼﾏｹﾝ", "ﾅﾗﾊﾏﾁ"),
    "075434": MunicipalityEntry(MunicipalityCode("075434"), "福島県", "富岡町", "ﾌｸｼﾏｹﾝ", "ﾄﾐｵｶﾏﾁ"),
    "075442": MunicipalityEntry(MunicipalityCode("075442"), "福島県", "川内村", "ﾌｸｼﾏｹﾝ", "ｶﾜｳﾁﾑﾗ"),
    "075451": MunicipalityEntry(MunicipalityCode("075451"), "福島県", "大熊町", "ﾌｸｼﾏｹﾝ", "ｵｵｸﾏﾏﾁ"),
    "075469": MunicipalityEntry(MunicipalityCode("075469"), "福島県", "双葉町", "ﾌｸｼﾏｹﾝ", "ﾌﾀﾊﾞﾏﾁ"),
    "075477": MunicipalityEntry(MunicipalityCode("075477"), "福島県", "浪江町", "ﾌｸｼﾏｹﾝ", "ﾅﾐｴﾏﾁ"),
    "075485": MunicipalityEntry(MunicipalityCode("075485"), "福島県", "葛尾村", "ﾌｸｼﾏｹﾝ", "ｶﾂﾗｵﾑﾗ"),
    "075612": MunicipalityEntry(MunicipalityCode("075612"), "福島県", "新地町", "ﾌｸｼﾏｹﾝ", "ｼﾝﾁﾏﾁ"),
    "075647": MunicipalityEntry(MunicipalityCode("075647"), "福島県", "飯舘村", "ﾌｸｼﾏｹﾝ", "ｲｲﾀﾃﾑﾗ"),
    "080004": MunicipalityEntry(MunicipalityCode("080004"), "茨城県", "", "ｲﾊﾞﾗｷｹﾝ", ""),
    "082015": MunicipalityEntry(MunicipalityCode("082015"), "茨城県", "水戸市", "ｲﾊﾞﾗｷｹﾝ", "ﾐﾄｼ"),
    "082023": MunicipalityEntry(MunicipalityCode("082023"), "茨城県", "日立市", "ｲﾊﾞﾗｷｹﾝ", "ﾋﾀﾁｼ"),
    "082031": MunicipalityEntry(MunicipalityCode("082031"), "茨城県", "土浦市", "ｲﾊﾞﾗｷｹﾝ", "ﾂﾁｳﾗｼ"),
    "082040": MunicipalityEntry(MunicipalityCode("082040"), "茨城県", "古河市", "ｲﾊﾞﾗｷｹﾝ", "ｺｶﾞｼ"),
    "082058": MunicipalityEntry(MunicipalityCode("082058"), "茨城県", "石岡市", "ｲﾊﾞﾗｷｹﾝ", "ｲｼｵｶｼ"),
    "082074": MunicipalityEntry(MunicipalityCode("082074"), "茨城県", "結城市", "ｲﾊﾞﾗｷｹﾝ", "ﾕｳｷｼ"),
    "082082": MunicipalityEntry(MunicipalityCode("082082"), "茨城県", "龍ケ崎市", "ｲﾊﾞﾗｷｹﾝ", "ﾘｭｳｶﾞｻｷｼ"),
    "082104": MunicipalityEntry(MunicipalityCode("082104"), "茨城県", "下妻市", "ｲﾊﾞﾗｷｹﾝ", "ｼﾓﾂﾏｼ"),
    "082112": MunicipalityEntry(MunicipalityCode("082112"), "茨城県", "常総市", "ｲﾊﾞﾗｷｹﾝ", "ｼﾞｮｳｿｳｼ"),
    "082121": MunicipalityEntry(MunicipalityCode("082121"), "茨城県", "常陸太田市", "ｲﾊﾞﾗｷｹﾝ", "ﾋﾀﾁｵｵﾀｼ"),
    "082147": MunicipalityEntry(MunicipalityCode("082147"), "茨城県", "高萩市", "ｲﾊﾞﾗｷｹﾝ", "ﾀｶﾊｷﾞｼ"),
    "082155": MunicipalityEntry(MunicipalityCode("082155"), "茨城県", "北茨城市", "ｲﾊﾞﾗｷｹﾝ", "ｷﾀｲﾊﾞﾗｷｼ"),
    "082163": MunicipalityEntry(MunicipalityCode("082163"), "茨城県", "笠間市", "ｲﾊﾞﾗｷｹﾝ", "ｶｻﾏｼ"),
    "082171": MunicipalityEntry(MunicipalityCode("082171"), "茨城県", "取手市", "ｲﾊﾞﾗｷｹﾝ", "ﾄﾘﾃﾞｼ"),
    "082198": MunicipalityEntry(MunicipalityCode("082198"), "茨城県", "牛久市", "ｲﾊﾞﾗｷｹﾝ", "ｳｼｸｼ"),
    "082201": MunicipalityEntry(MunicipalityCode("082201"), "茨城県", "つくば市", "ｲﾊﾞﾗｷｹﾝ", "ﾂｸﾊﾞｼ"),
    "082210": MunicipalityEntry(MunicipalityCode("082210"), "茨城県", "ひたちなか市", "ｲﾊﾞﾗｷｹﾝ", "ﾋﾀﾁﾅｶｼ"),
    "082228": MunicipalityEntry(MunicipalityCode("082228"), "茨城県", "鹿嶋市", "ｲﾊﾞﾗｷｹﾝ", "ｶｼﾏｼ"),
    "082236": MunicipalityEntry(MunicipalityCode("082236"), "茨城県", "潮来市", "ｲﾊﾞﾗｷｹﾝ", "ｲﾀｺｼ"),
    "082244": MunicipalityEntry(MunicipalityCode("082244"), "茨城県", "守谷市", "ｲﾊﾞﾗｷｹﾝ", "ﾓﾘﾔｼ"),
    "082252": MunicipalityEntry(MunicipalityCode("082252"), "茨城県", "常陸大宮市", "ｲﾊﾞﾗｷｹﾝ", "ﾋﾀﾁｵｵﾐﾔｼ"),
    "082261": MunicipalityEntry(MunicipalityCode("082261"), "茨城県", "那珂市", "ｲﾊﾞﾗｷｹﾝ", "ﾅｶｼ"),
    "082279": MunicipalityEntry(MunicipalityCode("082279"), "茨城県", "筑西市", "ｲﾊﾞﾗｷｹﾝ", "ﾁｸｾｲｼ"),
    "082287": MunicipalityEntry(MunicipalityCode("082287"), "茨城県", "坂東市", "ｲﾊﾞﾗｷｹﾝ", "ﾊﾞﾝﾄﾞｳｼ"),
    "082295": MunicipalityEntry(MunicipalityCode("082295"), "茨城県", "稲敷市", "ｲﾊﾞﾗｷｹﾝ", "ｲﾅｼｷｼ"),
    "082309": MunicipalityEntry(MunicipalityCode("082309"), "茨城県", "かすみがうら市", "ｲﾊﾞﾗｷｹﾝ", "ｶｽﾐｶﾞｳﾗｼ"),
    "082317": MunicipalityEntry(MunicipalityCode("082317"), "茨城県", "桜川市", "ｲﾊﾞﾗｷｹﾝ", "ｻｸﾗｶﾞﾜｼ"),
    "082325": MunicipalityEntry(MunicipalityCode("082325"), "茨城県", "神栖市", "ｲﾊﾞﾗｷｹﾝ", "ｶﾐｽｼ"),
    "082333": MunicipalityEntry(MunicipalityCode("082333"), "茨城県", "行方市", "ｲﾊﾞﾗｷｹﾝ", "ﾅﾒｶﾞﾀｼ"),
    "082341": MunicipalityEntry(MunicipalityCode("082341"), "茨城県", "鉾田市", "ｲﾊﾞﾗｷｹﾝ", "ﾎｺﾀｼ"),
    "082350": MunicipalityEntry(MunicipalityCode("082350"), "茨城県", "つくばみらい市", "ｲﾊﾞﾗｷｹﾝ", "ﾂｸﾊﾞﾐﾗｲｼ"),
    "082368": MunicipalityEntry(MunicipalityCode("082368"), "茨城県", "小美玉市", "ｲﾊﾞﾗｷｹﾝ", "ｵﾐﾀﾏｼ"),
    "083020": MunicipalityEntry(MunicipalityCode("083020"), "茨城県", "茨城町", "ｲﾊﾞﾗｷｹﾝ", "ｲﾊﾞﾗｷﾏﾁ"),
    "083097": MunicipalityEntry(MunicipalityCode("083097"), "茨城県", "大洗町", "ｲﾊﾞﾗｷｹﾝ", "ｵｵｱﾗｲﾏﾁ"),
    "083101": MunicipalityEntry(MunicipalityCode("083101"), "茨城県", "城里町", "ｲﾊﾞﾗｷｹﾝ", "ｼﾛｻﾄﾏﾁ"),
    "083411": MunicipalityEntry(MunicipalityCode("083411"), "茨城県", "東海村", "ｲﾊﾞﾗｷｹﾝ", "ﾄｳｶｲﾑﾗ"),
    "083640": MunicipalityEntry(MunicipalityCode("083640"), "茨城県", "大子町", "ｲﾊﾞﾗｷｹﾝ", "ﾀﾞｲｺﾞﾏﾁ"),
    "084425": MunicipalityEntry(MunicipalityCode("084425"), "茨城県", "美浦村", "ｲﾊﾞﾗｷｹﾝ", "ﾐﾎﾑﾗ"),
    "084433": MunicipalityEntry(MunicipalityCode("084433"), "茨城県", "阿見町", "ｲﾊﾞﾗｷｹﾝ", "ｱﾐﾏﾁ"),
    "084476": MunicipalityEntry(MunicipalityCode("084476"), "茨城県", "河内町", "ｲﾊﾞﾗｷｹﾝ", "ｶﾜﾁﾏﾁ"),
    "085219": MunicipalityEntry(MunicipalityCode("085219"), "茨城県", "八千代町", "ｲﾊﾞﾗｷｹﾝ", "ﾔﾁﾖﾏﾁ"),
    "085421": MunicipalityEntry(MunicipalityCode("085421"), "茨城県", "五霞町", "ｲﾊﾞﾗｷｹﾝ", "ｺﾞｶﾏﾁ"),
    "085464": MunicipalityEntry(MunicipalityCode("085464"), "茨城県", "境町", "ｲﾊﾞﾗｷｹﾝ", "ｻｶｲﾏﾁ"),
    "085642": MunicipalityEntry(MunicipalityCode("085642"), "茨城県", "利根町", "ｲﾊﾞﾗｷｹﾝ", "ﾄﾈﾏﾁ"),
    "090000": MunicipalityEntry(MunicipalityCode("090000"), "栃木県", "", "ﾄﾁｷﾞｹﾝ", ""),
    "092011": MunicipalityEntry(MunicipalityCode("092011"), "栃木県", "宇都宮市", "ﾄﾁｷﾞｹﾝ", "ｳﾂﾉﾐﾔｼ"),
    "092029": MunicipalityEntry(MunicipalityCode("092029"), "栃木県", "足利市", "ﾄﾁｷﾞｹﾝ", "ｱｼｶｶﾞｼ"),
    "092037": MunicipalityEntry(MunicipalityCode("092037"), "栃木県", "栃木市", "ﾄﾁｷﾞｹﾝ", "ﾄﾁｷﾞｼ"),
    "092045": MunicipalityEntry(MunicipalityCode("092045"), "栃木県", "佐野市", "ﾄﾁｷﾞｹﾝ", "ｻﾉｼ"),
    "092053": MunicipalityEntry(MunicipalityCode("092053"), "栃木県", "鹿沼市", "ﾄﾁｷﾞｹﾝ", "ｶﾇﾏｼ"),
    "092061": MunicipalityEntry(MunicipalityCode("092061"), "栃木県", "日光市", "ﾄﾁｷﾞｹﾝ", "ﾆｯｺｳｼ"),
    "092088": MunicipalityEntry(MunicipalityCode("092088"), "栃木県", "小山市", "ﾄﾁｷﾞｹﾝ", "ｵﾔﾏｼ"),
    "092096": MunicipalityEntry(MunicipalityCode("092096"), "栃木県", "真岡市", "ﾄﾁｷﾞｹﾝ", "ﾓｵｶｼ"),
    "092100": MunicipalityEntry(MunicipalityCode("092100"), "栃木県", "大田原市", "ﾄﾁｷﾞｹﾝ", "ｵｵﾀﾜﾗｼ"),
    "092118": MunicipalityEntry(MunicipalityCode("092118"), "栃木県", "矢板市", "ﾄﾁｷﾞｹﾝ", "ﾔｲﾀｼ"),
    "092134": MunicipalityEntry(MunicipalityCode("092134"), "栃木県", "那須塩原市", "ﾄﾁｷﾞｹﾝ", "ﾅｽｼｵﾊﾞﾗｼ"),
    "092142": MunicipalityEntry(MunicipalityCode("092142"), "栃木県", "さくら市", "ﾄﾁｷﾞｹﾝ", "ｻｸﾗｼ"),
    "092151": MunicipalityEntry(MunicipalityCode("092151"), "栃木県", "那須烏山市", "ﾄﾁｷﾞｹﾝ", "ﾅｽｶﾗｽﾔﾏｼ"),
    "092169": MunicipalityEntry(MunicipalityCode("092169"), "栃木県", "下野市", "ﾄﾁｷﾞｹﾝ", "ｼﾓﾂｹｼ"),
    "093017": MunicipalityEntry(MunicipalityCode("093017"), "栃木県", "上三川町", "ﾄﾁｷﾞｹﾝ", "ｶﾐﾉｶﾜﾏﾁ"),
    "093424": MunicipalityEntry(MunicipalityCode("093424"), "栃木県", "益子町", "ﾄﾁｷﾞｹﾝ", "ﾏｼｺﾏﾁ"),
    "093432": MunicipalityEntry(MunicipalityCode("093432"), "栃木県", "茂木町", "ﾄﾁｷﾞｹﾝ", "ﾓﾃｷﾞﾏﾁ"),
    "093441": MunicipalityEntry(MunicipalityCode("093441"), "栃木県", "市貝町", "ﾄﾁｷﾞｹﾝ", "ｲﾁｶｲﾏﾁ"),
    "093459": MunicipalityEntry(MunicipalityCode("093459"), "栃木県", "芳賀町", "ﾄﾁｷﾞｹﾝ", "ﾊｶﾞﾏﾁ"),
    "093611": MunicipalityEntry(MunicipalityCode("093611"), "栃木県", "壬生町", "ﾄﾁｷﾞｹﾝ", "ﾐﾌﾞﾏﾁ"),
    "093645": MunicipalityEntry(MunicipalityCode("093645"), "栃木県", "野木町", "ﾄﾁｷﾞｹﾝ", "ﾉｷﾞﾏﾁ"),
    "093840": MunicipalityEntry(MunicipalityCode("093840"), "栃木県", "塩谷町", "ﾄﾁｷﾞｹﾝ", "ｼｵﾔﾏﾁ"),
    "093866": MunicipalityEntry(MunicipalityCode("093866"), "栃木県", "高根沢町", "ﾄﾁｷﾞｹﾝ", "ﾀｶﾈｻﾞﾜﾏﾁ"),
    "094072": MunicipalityEntry(MunicipalityCode("094072"), "栃木県", "那須町", "ﾄﾁｷﾞｹﾝ", "ﾅｽﾏﾁ"),
    "094111": MunicipalityEntry(MunicipalityCode("094111"), "栃木県", "那珂川町", "ﾄﾁｷﾞｹﾝ", "ﾅｶｶﾞﾜﾏﾁ"),
    "100005": MunicipalityEntry(MunicipalityCode("100005"), "群馬県", "", "ｸﾞﾝﾏｹﾝ", ""),
    "102016": MunicipalityEntry(MunicipalityCode("102016"), "群馬県", "前橋市", "ｸﾞﾝﾏｹﾝ", "ﾏｴﾊﾞｼｼ"),
    "102024": MunicipalityEntry(MunicipalityCode("102024"), "群馬県", "高崎市", "ｸﾞﾝﾏｹﾝ", "ﾀｶｻｷｼ"),
    "102032": MunicipalityEntry(MunicipalityCode("102032"), "群馬県", "桐生市", "ｸﾞﾝﾏｹﾝ", "ｷﾘｭｳｼ"),
    "102041": MunicipalityEntry(MunicipalityCode("102041"), "群馬県", "伊勢崎市", "ｸﾞﾝﾏｹﾝ", "ｲｾｻｷｼ"),
    "102059": MunicipalityEntry(MunicipalityCode("102059"), "群馬県", "太田市", "ｸﾞﾝﾏｹﾝ", "ｵｵﾀｼ"),
    "102067": MunicipalityEntry(MunicipalityCode("102067"), "群馬県", "沼田市", "ｸﾞﾝﾏｹﾝ", "ﾇﾏﾀｼ"),
    "102075": MunicipalityEntry(MunicipalityCode("102075"), "群馬県", "館林市", "ｸﾞﾝﾏｹﾝ", "ﾀﾃﾊﾞﾔｼｼ"),
    "102083": MunicipalityEntry(MunicipalityCode("102083"), "群馬県", "渋川市", "ｸﾞﾝﾏｹﾝ", "ｼﾌﾞｶﾜｼ"),
    "102091": MunicipalityEntry(MunicipalityCode("102091"), "群馬県", "藤岡市", "ｸﾞﾝﾏｹﾝ", "ﾌｼﾞｵｶｼ"),
    "102105": MunicipalityEntry(MunicipalityCode("102105"), "群馬県", "富岡市", "ｸﾞﾝﾏｹﾝ", "ﾄﾐｵｶｼ"),
    "102113": MunicipalityEntry(MunicipalityCode("102113"), "群馬県", "安中市", "ｸﾞﾝﾏｹﾝ", "ｱﾝﾅｶｼ"),
    "102121": MunicipalityEntry(MunicipalityCode("102121"), "群馬県", "みどり市", "ｸﾞﾝﾏｹﾝ", "ﾐﾄﾞﾘｼ"),
    "103446": MunicipalityEntry(MunicipalityCode("103446"), "群馬県", "榛東村", "ｸﾞﾝﾏｹﾝ", "ｼﾝﾄｳﾑﾗ"),
    "103454": MunicipalityEntry(MunicipalityCode("103454"), "群馬県", "吉岡町", "ｸﾞﾝﾏｹﾝ", "ﾖｼｵｶﾏﾁ"),
    "103667": MunicipalityEntry(MunicipalityCode("103667"), "群馬県", "上野村", "ｸﾞﾝﾏｹﾝ", "ｳｴﾉﾑﾗ"),
    "103675": MunicipalityEntry(MunicipalityCode("103675"), "群馬県", "神流町", "ｸﾞﾝﾏｹﾝ", "ｶﾝﾅﾏﾁ"),
    "103829": MunicipalityEntry(MunicipalityCode("103829"), "群馬県", "下仁田町", "ｸﾞﾝﾏｹﾝ", "ｼﾓﾆﾀﾏﾁ"),
    "103837": MunicipalityEntry(MunicipalityCode("103837"), "群馬県", "南牧村", "ｸﾞﾝﾏｹﾝ", "ﾅﾝﾓｸﾑﾗ"),
    "103845": MunicipalityEntry(MunicipalityCode("103845"), "群馬県", "甘楽町", "ｸﾞﾝﾏｹﾝ", "ｶﾝﾗﾏﾁ"),
    "104213": MunicipalityEntry(MunicipalityCode("104213"), "群馬県", "中之条町", "ｸﾞﾝﾏｹﾝ", "ﾅｶﾉｼﾞﾖｳﾏﾁ"),
    "104248": MunicipalityEntry(MunicipalityCode("104248"), "群馬県", "長野原町", "ｸﾞﾝﾏｹﾝ", "ﾅｶﾞﾉﾊﾗﾏﾁ"),
    "104256": MunicipalityEntry(MunicipalityCode("104256"), "群馬県", "嬬恋村", "ｸﾞﾝﾏｹﾝ", "ﾂﾏｺﾞｲﾑﾗ"),
    "104264": MunicipalityEntry(MunicipalityCode("104264"), "群馬県", "草津町", "ｸﾞﾝﾏｹﾝ", "ｸｻﾂﾏﾁ"),
    "104281": MunicipalityEntry(MunicipalityCode("104281"), "群馬県", "高山村", "ｸﾞﾝﾏｹﾝ", "ﾀｶﾔﾏﾑﾗ"),
    "104299": MunicipalityEntry(MunicipalityCode("104299"), "群馬県", "東吾妻町", "ｸﾞﾝﾏｹﾝ", "ﾋｶﾞｼｱｶﾞﾂﾏﾏﾁ"),
    "104434": MunicipalityEntry(MunicipalityCode("104434"), "群馬県", "片品村", "ｸﾞﾝﾏｹﾝ", "ｶﾀｼﾅﾑﾗ"),
    "104442": MunicipalityEntry(MunicipalityCode("104442"), "群馬県", "川場村", "ｸﾞﾝﾏｹﾝ", "ｶﾜﾊﾞﾑﾗ"),
    "104485": MunicipalityEntry(MunicipalityCode("104485"), "群馬県", "昭和村", "ｸﾞﾝﾏｹﾝ", "ｼｮｳﾜﾑﾗ"),
    "104493": MunicipalityEntry(MunicipalityCode("104493"), "群馬県", "みなかみ町", "ｸﾞﾝﾏｹﾝ", "ﾐﾅｶﾐﾏﾁ"),
    "104647": MunicipalityEntry(MunicipalityCode("104647"), "群馬県", "玉村町", "ｸﾞﾝﾏｹﾝ", "ﾀﾏﾑﾗﾏﾁ"),
    "105210": MunicipalityEntry(MunicipalityCode("105210"), "群馬県", "板倉町", "ｸﾞﾝﾏｹﾝ", "ｲﾀｸﾗﾏﾁ"),
    "105228": MunicipalityEntry(MunicipalityCode("105228"), "群馬県", "明和町", "ｸﾞﾝﾏｹﾝ", "ﾒｲﾜﾏﾁ"),
    "105236": MunicipalityEntry(MunicipalityCode("105236"), "群馬県", "千代田町", "ｸﾞﾝﾏｹﾝ", "ﾁﾖﾀﾞﾏﾁ"),
    "105244": MunicipalityEntry(MunicipalityCode("105244"), "群馬県", "大泉町", "ｸﾞﾝﾏｹﾝ", "ｵｵｲｽﾞﾐﾏﾁ"),
    "105252": MunicipalityEntry(MunicipalityCode("105252"), "群馬県", "邑楽町", "ｸﾞﾝﾏｹﾝ", "ｵｳﾗﾏﾁ"),
    "110001": MunicipalityEntry(MunicipalityCode("110001"), "埼玉県", "", "ｻｲﾀﾏｹﾝ", ""),
    "111007": MunicipalityEntry(MunicipalityCode("111007"), "埼玉県", "さいたま市", "ｻｲﾀﾏｹﾝ", "ｻｲﾀﾏｼ"),
    "112011": MunicipalityEntry(MunicipalityCode("112011"), "埼玉県", "川越市", "ｻｲﾀﾏｹﾝ", "ｶﾜｺﾞｴｼ"),
    "112020": MunicipalityEntry(MunicipalityCode("112020"), "埼玉県", "熊谷市", "ｻｲﾀﾏｹﾝ", "ｸﾏｶﾞﾔｼ"),
    "112038": MunicipalityEntry(MunicipalityCode("112038"), "埼玉県", "川口市", "ｻｲﾀﾏｹﾝ", "ｶﾜｸﾞﾁｼ"),
    "112062": MunicipalityEntry(MunicipalityCode("112062"), "埼玉県", "行田市", "ｻｲﾀﾏｹﾝ", "ｷﾞﾖｳﾀﾞｼ"),
    "112071": MunicipalityEntry(MunicipalityCode("112071"), "埼玉県", "秩父市", "ｻｲﾀﾏｹﾝ", "ﾁﾁﾌﾞｼ"),
    "112089": MunicipalityEntry(MunicipalityCode("112089"), "埼玉県", "所沢市", "ｻｲﾀﾏｹﾝ", "ﾄｺﾛｻﾞﾜｼ"),
    "112097": MunicipalityEntry(MunicipalityCode("112097"), "埼玉県", "飯能市", "ｻｲﾀﾏｹﾝ", "ﾊﾝﾉｳｼ"),
    "112101": MunicipalityEntry(MunicipalityCode("112101"), "埼玉県", "加須市", "ｻｲﾀﾏｹﾝ", "ｶｿﾞｼ"),
    "112119": MunicipalityEntry(MunicipalityCode("112119"), "埼玉県", "本庄市", "ｻｲﾀﾏｹﾝ", "ﾎﾝｼﾞﾖｳｼ"),
    "112127": MunicipalityEntry(MunicipalityCode("112127"), "埼玉県", "東松山市", "ｻｲﾀﾏｹﾝ", "ﾋｶﾞｼﾏﾂﾔﾏｼ"),
    "112143": MunicipalityEntry(MunicipalityCode("112143"), "埼玉県", "春日部市", "ｻｲﾀﾏｹﾝ", "ｶｽｶﾍﾞｼ"),
    "112151": MunicipalityEntry(MunicipalityCode("112151"), "埼玉県", "狭山市", "ｻｲﾀﾏｹﾝ", "ｻﾔﾏｼ"),
    "112160": MunicipalityEntry(MunicipalityCode("112160"), "埼玉県", "羽生市", "ｻｲﾀﾏｹﾝ", "ﾊﾆﾕｳｼ"),
    "112178": MunicipalityEntry(MunicipalityCode("112178"), "埼玉県", "鴻巣市", "ｻｲﾀﾏｹﾝ", "ｺｳﾉｽｼ"),
    "112186": MunicipalityEntry(MunicipalityCode("112186"), "埼玉県", "深谷市", "ｻｲﾀﾏｹﾝ", "ﾌｶﾔｼ"),
    "112194": MunicipalityEntry(MunicipalityCode("112194"), "埼玉県", "上尾市", "ｻｲﾀﾏｹﾝ", "ｱｹﾞｵｼ"),
    "112216": MunicipalityEntry(MunicipalityCode("112216"), "埼玉県", "草加市", "ｻｲﾀﾏｹﾝ", "ｿｳｶｼ"),
    "112224": MunicipalityEntry(MunicipalityCode("112224"), "埼玉県", "越谷市", "ｻｲﾀﾏｹﾝ", "ｺｼｶﾞﾔｼ"),
    "112232": MunicipalityEntry(MunicipalityCode("112232"), "埼玉県", "蕨市", "ｻｲﾀﾏｹﾝ", "ﾜﾗﾋﾞｼ"),
    "112241": MunicipalityEntry(MunicipalityCode("112241"), "埼玉県", "戸田市", "ｻｲﾀﾏｹﾝ", "ﾄﾀﾞｼ"),
    "112259": MunicipalityEntry(MunicipalityCode("112259"), "埼玉県", "入間市", "ｻｲﾀﾏｹﾝ", "ｲﾙﾏｼ"),
    "112275": MunicipalityEntry(MunicipalityCode("112275"), "埼玉県", "朝霞市", "ｻｲﾀﾏｹﾝ", "ｱｻｶｼ"),
    "112283": MunicipalityEntry(MunicipalityCode("112283"), "埼玉県", "志木市", "ｻｲﾀﾏｹﾝ", "ｼｷｼ"),
    "112291": MunicipalityEntry(MunicipalityCode("112291"), "埼玉県", "和光市", "ｻｲﾀﾏｹﾝ", "ﾜｺｳｼ"),
    "112305": MunicipalityEntry(MunicipalityCode("112305"), "埼玉県", "新座市", "ｻｲﾀﾏｹﾝ", "ﾆｲｻﾞｼ"),
    "112313": MunicipalityEntry(MunicipalityCode("112313"), "埼玉県", "桶川市", "ｻｲﾀﾏｹﾝ", "ｵｹｶﾞﾜｼ"),
    "112321": MunicipalityEntry(MunicipalityCode("112321"), "埼玉県", "久喜市", "ｻｲﾀﾏｹﾝ", "ｸｷｼ"),
    "112330": MunicipalityEntry(MunicipalityCode("112330"), "埼玉県", "北本市", "ｻｲﾀﾏｹﾝ", "ｷﾀﾓﾄｼ"),
    "112348": MunicipalityEntry(MunicipalityCode("112348"), "埼玉県", "八潮市", "ｻｲﾀﾏｹﾝ", "ﾔｼｵｼ"),
    "112356": MunicipalityEntry(MunicipalityCode("112356"), "埼玉県", "富士見市", "ｻｲﾀﾏｹﾝ", "ﾌｼﾞﾐｼ"),
    "112372": MunicipalityEntry(MunicipalityCode("112372"), "埼玉県", "三郷市", "ｻｲﾀﾏｹﾝ", "ﾐｻﾄｼ"),
    "112381": MunicipalityEntry(MunicipalityCode("112381"), "埼玉県", "蓮田市", "ｻｲﾀﾏｹﾝ", "ﾊｽﾀﾞｼ"),
    "112399": MunicipalityEntry(MunicipalityCode("112399"), "埼玉県", "坂戸市", "ｻｲﾀﾏｹﾝ", "ｻｶﾄﾞｼ"),
    "112402": MunicipalityEntry(MunicipalityCode("112402"), "埼玉県", "幸手市", "ｻｲﾀﾏｹﾝ", "ｻｯﾃｼ"),
    "112411": MunicipalityEntry(MunicipalityCode("112411"), "埼玉県", "鶴ヶ島市", "ｻｲﾀﾏｹﾝ", "ﾂﾙｶﾞｼﾏｼ"),
    "112429": MunicipalityEntry(MunicipalityCode("112429"), "埼玉県", "日高市", "ｻｲﾀﾏｹﾝ", "ﾋﾀﾞｶｼ"),
    "112437": MunicipalityEntry(MunicipalityCode("112437"), "埼玉県", "吉川市", "ｻｲﾀﾏｹﾝ", "ﾖｼｶﾜｼ"),
    "112453": MunicipalityEntry(MunicipalityCode("112453"), "埼玉県", "ふじみ野市", "ｻｲﾀﾏｹﾝ", "ﾌｼﾞﾐﾉｼ"),
    "112461": MunicipalityEntry(MunicipalityCode("112461"), "埼玉県", "白岡市", "ｻｲﾀﾏｹﾝ", "ｼﾗｵｶｼ"),
    "113018": MunicipalityEntry(MunicipalityCode("113018"), "埼玉県", "伊奈町", "ｻｲﾀﾏｹﾝ", "ｲﾅﾏﾁ"),
    "113247": MunicipalityEntry(MunicipalityCode("113247"), "埼玉県", "三芳町", "ｻｲﾀﾏｹﾝ", "ﾐﾖｼﾏﾁ"),
    "113263": MunicipalityEntry(MunicipalityCode("113263"), "埼玉県", "毛呂山町", "ｻｲﾀﾏｹﾝ", "ﾓﾛﾔﾏﾏﾁ"),
    "113271": MunicipalityEntry(MunicipalityCode("113271"), "埼玉県", "越生町", "ｻｲﾀﾏｹﾝ", "ｵｺﾞｾﾏﾁ"),
    "113417": MunicipalityEntry(MunicipalityCode("113417"), "埼玉県", "滑川町", "ｻｲﾀﾏｹﾝ", "ﾅﾒｶﾞﾜﾏﾁ"),
    "113425": MunicipalityEntry(MunicipalityCode("113425"), "埼玉県", "嵐山町", "ｻｲﾀﾏｹﾝ", "ﾗﾝｻﾞﾝﾏﾁ"),
    "113433": MunicipalityEntry(MunicipalityCode("113433"), "埼玉県", "小川町", "ｻｲﾀﾏｹﾝ", "ｵｶﾞﾜﾏﾁ"),
    "113468": MunicipalityEntry(MunicipalityCode("113468"), "埼玉県", "川島町", "ｻｲﾀﾏｹﾝ", "ｶﾜｼﾞﾏﾏﾁ"),
    "113476": MunicipalityEntry(MunicipalityCode("113476"), "埼玉県", "吉見町", "ｻｲﾀﾏｹﾝ", "ﾖｼﾐﾏﾁ"),
    "113484": MunicipalityEntry(MunicipalityCode("113484"), "埼玉県", "鳩山町", "ｻｲﾀﾏｹﾝ", "ﾊﾄﾔﾏﾏﾁ"),
    "113492": MunicipalityEntry(MunicipalityCode("113492"), "埼玉県", "ときがわ町", "ｻｲﾀﾏｹﾝ", "ﾄｷｶﾞﾜﾏﾁ"),
    "113611": MunicipalityEntry(MunicipalityCode("113611"), "埼玉県", "横瀬町", "ｻｲﾀﾏｹﾝ", "ﾖｺｾﾞﾏﾁ"),
    "113620": MunicipalityEntry(MunicipalityCode("113620"), "埼玉県", "皆野町", "ｻｲﾀﾏｹﾝ", "ﾐﾅﾉﾏﾁ"),
    "113638": MunicipalityEntry(MunicipalityCode("113638"), "埼玉県", "長瀞町", "ｻｲﾀﾏｹﾝ", "ﾅｶﾞﾄﾛﾏﾁ"),
    "113654": MunicipalityEntry(MunicipalityCode("113654"), "埼玉県", "小鹿野町", "ｻｲﾀﾏｹﾝ", "ｵｶﾞﾉﾏﾁ"),
    "113697": MunicipalityEntry(MunicipalityCode("113697"), "埼玉県", "東秩父村", "ｻｲﾀﾏｹﾝ", "ﾋｶﾞｼﾁﾁﾌﾞﾑﾗ"),
    "113816": MunicipalityEntry(MunicipalityCode("113816"), "埼玉県", "美里町", "ｻｲﾀﾏｹﾝ", "ﾐｻﾄﾏﾁ"),
    "113832": MunicipalityEntry(MunicipalityCode("113832"), "埼玉県", "神川町", "ｻｲﾀﾏｹﾝ", "ｶﾐｶﾜﾏﾁ"),
    "113859": MunicipalityEntry(MunicipalityCode("113859"), "埼玉県", "上里町", "ｻｲﾀﾏｹﾝ", "ｶﾐｻﾄﾏﾁ"),
    "114081": MunicipalityEntry(MunicipalityCode("114081"), "埼玉県", "寄居町", "ｻｲﾀﾏｹﾝ", "ﾖﾘｲﾏﾁ"),
    "114421": MunicipalityEntry(MunicipalityCode("114421"), "埼玉県", "宮代町", "ｻｲﾀﾏｹﾝ", "ﾐﾔｼﾛﾏﾁ"),
    "114642": MunicipalityEntry(MunicipalityCode("114642"), "埼玉県", "杉戸町", "ｻｲﾀﾏｹﾝ", "ｽｷﾞﾄﾏﾁ"),
    "114651": MunicipalityEntry(MunicipalityCode("114651"), "埼玉県", "松伏町", "ｻｲﾀﾏｹﾝ", "ﾏﾂﾌﾞｼﾏﾁ"),
    "120006": MunicipalityEntry(MunicipalityCode("120006"), "千葉県", "", "ﾁﾊﾞｹﾝ", ""),
    "121002": MunicipalityEntry(MunicipalityCode("121002"), "千葉県", "千葉市", "ﾁﾊﾞｹﾝ", "ﾁﾊﾞｼ"),
    "122025": MunicipalityEntry(MunicipalityCode("122025"), "千葉県", "銚子市", "ﾁﾊﾞｹﾝ", "ﾁｮｳｼｼ"),
    "122033": MunicipalityEntry(MunicipalityCode("122033"), "千葉県", "市川市", "ﾁﾊﾞｹﾝ", "ｲﾁｶﾜｼ"),
    "122041": MunicipalityEntry(MunicipalityCode("122041"), "千葉県", "船橋市", "ﾁﾊﾞｹﾝ", "ﾌﾅﾊﾞｼｼ"),
    "122050": MunicipalityEntry(MunicipalityCode("122050"), "千葉県", "館山市", "ﾁﾊﾞｹﾝ", "ﾀﾃﾔﾏｼ"),
    "122068": MunicipalityEntry(MunicipalityCode("122068"), "千葉県", "木更津市", "ﾁﾊﾞｹﾝ", "ｷｻﾗﾂﾞｼ"),
    "122076": MunicipalityEntry(MunicipalityCode("122076"), "千葉県", "松戸市", "ﾁﾊﾞｹﾝ", "ﾏﾂﾄﾞｼ"),
    "122084": MunicipalityEntry(MunicipalityCode("122084"), "千葉県", "野田市", "ﾁﾊﾞｹﾝ", "ﾉﾀﾞｼ"),
    "122106": MunicipalityEntry(MunicipalityCode("122106"), "千葉県", "茂原市", "ﾁﾊﾞｹﾝ", "ﾓﾊﾞﾗｼ"),
    "122114": MunicipalityEntry(MunicipalityCode("122114"), "千葉県", "成田市", "ﾁﾊﾞｹﾝ", "ﾅﾘﾀｼ"),
    "122122": MunicipalityEntry(MunicipalityCode("122122"), "千葉県", "佐倉市", "ﾁﾊﾞｹﾝ", "ｻｸﾗｼ"),
    "122131": MunicipalityEntry(MunicipalityCode("122131"), "千葉県", "東金市", "ﾁﾊﾞｹﾝ", "ﾄｳｶﾞﾈｼ"),
    "122157": MunicipalityEntry(MunicipalityCode("122157"), "千葉県", "旭市", "ﾁﾊﾞｹﾝ", "ｱｻﾋｼ"),
    "122165": MunicipalityEntry(MunicipalityCode("122165"), "千葉県", "習志野市", "ﾁﾊﾞｹﾝ", "ﾅﾗｼﾉｼ"),
    "122173": MunicipalityEntry(MunicipalityCode("122173"), "千葉県", "柏市", "ﾁﾊﾞｹﾝ", "ｶｼﾜｼ"),
    "122181": MunicipalityEntry(MunicipalityCode("122181"), "千葉県", "勝浦市", "ﾁﾊﾞｹﾝ", "ｶﾂｳﾗｼ"),
    "122190": MunicipalityEntry(MunicipalityCode("122190"), "千葉県", "市原市", "ﾁﾊﾞｹﾝ", "ｲﾁﾊﾗｼ"),
    "122203": MunicipalityEntry(MunicipalityCode("122203"), "千葉県", "流山市", "ﾁﾊﾞｹﾝ", "ﾅｶﾞﾚﾔﾏｼ"),
    "122211": MunicipalityEntry(MunicipalityCode("122211"), "千葉県", "八千代市", "ﾁﾊﾞｹﾝ", "ﾔﾁﾖｼ"),
    "122220": MunicipalityEntry(MunicipalityCode("122220"), "千葉県", "我孫子市", "ﾁﾊﾞｹﾝ", "ｱﾋﾞｺｼ"),
    "122238": MunicipalityEntry(MunicipalityCode("122238"), "千葉県", "鴨川市", "ﾁﾊﾞｹﾝ", "ｶﾓｶﾞﾜｼ"),
    "122246": MunicipalityEntry(MunicipalityCode("122246"), "千葉県", "鎌ケ谷市", "ﾁﾊﾞｹﾝ", "ｶﾏｶﾞﾔｼ"),
    "122254": MunicipalityEntry(MunicipalityCode("122254"), "千葉県", "君津市", "ﾁﾊﾞｹﾝ", "ｷﾐﾂｼ"),
    "122262": MunicipalityEntry(MunicipalityCode("122262"), "千葉県", "富津市", "ﾁﾊﾞｹﾝ", "ﾌｯﾂｼ"),
    "122271": MunicipalityEntry(MunicipalityCode("122271"), "千葉県", "浦安市", "ﾁﾊﾞｹﾝ", "ｳﾗﾔｽｼ"),
    "122289": MunicipalityEntry(MunicipalityCode("122289"), "千葉県", "四街道市", "ﾁﾊﾞｹﾝ", "ﾖﾂｶｲﾄﾞｳｼ"),
    "122297": MunicipalityEntry(MunicipalityCode("122297"), "千葉県", "袖ケ浦市", "ﾁﾊﾞｹﾝ", "ｿﾃﾞｶﾞｳﾗｼ"),
    "122301": MunicipalityEntry(MunicipalityCode("122301"), "千葉県", "八街市", "ﾁﾊﾞｹﾝ", "ﾔﾁﾏﾀｼ"),
    "122319": MunicipalityEntry(MunicipalityCode("122319"), "千葉県", "印西市", "ﾁﾊﾞｹﾝ", "ｲﾝｻﾞｲｼ"),
    "122327": MunicipalityEntry(MunicipalityCode("122327"), "千葉県", "白井市", "ﾁﾊﾞｹﾝ", "ｼﾛｲｼ"),
    "122335": MunicipalityEntry(MunicipalityCode("122335"), "千葉県", "富里市", "ﾁﾊﾞｹﾝ", "ﾄﾐｻﾄｼ"),
    "122343": MunicipalityEntry(MunicipalityCode("122343"), "千葉県", "南房総市", "ﾁﾊﾞｹﾝ", "ﾐﾅﾐﾎﾞｳｿｳｼ"),
    "122351": MunicipalityEntry(MunicipalityCode("122351"), "千葉県", "匝瑳市", "ﾁﾊﾞｹﾝ", "ｿｳｻｼ"),
    "122360": MunicipalityEntry(MunicipalityCode("122360"), "千葉県", "香取市", "ﾁﾊﾞｹﾝ", "ｶﾄﾘｼ"),
    "122378": MunicipalityEntry(MunicipalityCode("122378"), "千葉県", "山武市", "ﾁﾊﾞｹﾝ", "ｻﾝﾑｼ"),
    "122386": MunicipalityEntry(MunicipalityCode("122386"), "千葉県", "いすみ市", "ﾁﾊﾞｹﾝ", "ｲｽﾐｼ"),
    "122394": MunicipalityEntry(MunicipalityCode("122394"), "千葉県", "大網白里市", "ﾁﾊﾞｹﾝ", "ｵｵｱﾐｼﾗｻﾄｼ"),
    "123226": MunicipalityEntry(MunicipalityCode("123226"), "千葉県", "酒々井町", "ﾁﾊﾞｹﾝ", "ｼｽｲﾏﾁ"),
    "123293": MunicipalityEntry(MunicipalityCode("123293"), "千葉県", "栄町", "ﾁﾊﾞｹﾝ", "ｻｶｴﾏﾁ"),
    "123421": MunicipalityEntry(MunicipalityCode("123421"), "千葉県", "神崎町", "ﾁﾊﾞｹﾝ", "ｺｳｻﾞｷﾏﾁ"),
    "123471": MunicipalityEntry(MunicipalityCode("123471"), "千葉県", "多古町", "ﾁﾊﾞｹﾝ", "ﾀｺﾏﾁ"),
    "123498": MunicipalityEntry(MunicipalityCode("123498"), "千葉県", "東庄町", "ﾁﾊﾞｹﾝ", "ﾄｳﾉｼｮｳﾏﾁ"),
    "124036": MunicipalityEntry(MunicipalityCode("124036"), "千葉県", "九十九里町", "ﾁﾊﾞｹﾝ", "ｸｼﾞﾕｳｸﾘﾏﾁ"),
    "124095": MunicipalityEntry(MunicipalityCode("124095"), "千葉県", "芝山町", "ﾁﾊﾞｹﾝ", "ｼﾊﾞﾔﾏﾏﾁ"),
    "124109": MunicipalityEntry(MunicipalityCode("124109"), "千葉県", "横芝光町", "ﾁﾊﾞｹﾝ", "ﾖｺｼﾊﾞﾋｶﾘﾏﾁ"),
    "124214": MunicipalityEntry(MunicipalityCode("124214"), "千葉県", "一宮町", "ﾁﾊﾞｹﾝ", "ｲﾁﾉﾐﾔﾏﾁ"),
    "124222": MunicipalityEntry(MunicipalityCode("124222"), "千葉県", "睦沢町", "ﾁﾊﾞｹﾝ", "ﾑﾂｻﾞﾜﾏﾁ"),
    "124231": MunicipalityEntry(MunicipalityCode("124231"), "千葉県", "長生村", "ﾁﾊﾞｹﾝ", "ﾁｮｳｾｲﾑﾗ"),
    "124249": MunicipalityEntry(MunicipalityCode("124249"), "千葉県", "白子町", "ﾁﾊﾞｹﾝ", "ｼﾗｺﾏﾁ"),
    "124265": MunicipalityEntry(MunicipalityCode("124265"), "千葉県", "長柄町", "ﾁﾊﾞｹﾝ", "ﾅｶﾞﾗﾏﾁ"),
    "124273": MunicipalityEntry(MunicipalityCode("124273"), "千葉県", "長南町", "ﾁﾊﾞｹﾝ", "ﾁｮｳﾅﾝﾏﾁ"),
    "124419": MunicipalityEntry(MunicipalityCode("124419"), "千葉県", "大多喜町", "ﾁﾊﾞｹﾝ", "ｵｵﾀｷﾏﾁ"),
    "124435": MunicipalityEntry(MunicipalityCode("124435"), "千葉県", "御宿町", "ﾁﾊﾞｹﾝ", "ｵﾝｼﾞﾕｸﾏﾁ"),
    "124630": MunicipalityEntry(MunicipalityCode("124630"), "千葉県", "鋸南町", "ﾁﾊﾞｹﾝ", "ｷﾖﾅﾝﾏﾁ"),
    "130001": MunicipalityEntry(MunicipalityCode("130001"), "東京都", "", "ﾄｳｷｮｳﾄ", ""),
    "131016": MunicipalityEntry(MunicipalityCode("131016"), "東京都", "千代田区", "ﾄｳｷｮｳﾄ", "ﾁﾖﾀﾞｸ"),
    "131024": MunicipalityEntry(MunicipalityCode("131024"), "東京都", "中央区", "ﾄｳｷｮｳﾄ", "ﾁｭｳｵｳｸ"),
    "131032": MunicipalityEntry(MunicipalityCode("131032"), "東京都", "港区", "ﾄｳｷｮｳﾄ", "ﾐﾅﾄｸ"),
    "131041": MunicipalityEntry(MunicipalityCode("131041"), "東京都", "新宿区", "ﾄｳｷｮｳﾄ", "ｼﾝｼﾞｭｸｸ"),
    "131059": MunicipalityEntry(MunicipalityCode("131059"), "東京都", "文京区", "ﾄｳｷｮｳﾄ", "ﾌﾞﾝｷｮｳｸ"),
    "131067": MunicipalityEntry(MunicipalityCode("131067"), "東京都", "台東区", "ﾄｳｷｮｳﾄ", "ﾀｲﾄｳｸ"),
    "131075": MunicipalityEntry(MunicipalityCode("131075"), "東京都", "墨田区", "ﾄｳｷｮｳﾄ", "ｽﾐﾀﾞｸ"),
    "131083": MunicipalityEntry(MunicipalityCode("131083"), "東京都", "江東区", "ﾄｳｷｮｳﾄ", "ｺｳﾄｳｸ"),
    "131091": MunicipalityEntry(MunicipalityCode("131091"), "東京都", "品川区", "ﾄｳｷｮｳﾄ", "ｼﾅｶﾞﾜｸ"),
    "131105": MunicipalityEntry(MunicipalityCode("131105"), "東京都", "目黒区", "ﾄｳｷｮｳﾄ", "ﾒｸﾞﾛｸ"),
    "131113": MunicipalityEntry(MunicipalityCode("131113"), "東京都", "大田区", "ﾄｳｷｮｳﾄ", "ｵｵﾀｸ"),
    "131121": MunicipalityEntry(MunicipalityCode("131121"), "東京都", "世田谷区", "ﾄｳｷｮｳﾄ", "ｾﾀｶﾞﾔｸ"),
    "131130": MunicipalityEntry(MunicipalityCode("131130"), "東京都", "渋谷区", "ﾄｳｷｮｳﾄ", "ｼﾌﾞﾔｸ"),
    "131148": MunicipalityEntry(MunicipalityCode("131148"), "東京都", "中野区", "ﾄｳｷｮｳﾄ", "ﾅｶﾉｸ"),
    "131156": MunicipalityEntry(MunicipalityCode("131156"), "東京都", "杉並区", "ﾄｳｷｮｳﾄ", "ｽｷﾞﾅﾐｸ"),
    "131164": MunicipalityEntry(MunicipalityCode("131164"), "東京都", "豊島区", "ﾄｳｷｮｳﾄ", "ﾄｼﾏｸ"),
    "131172": MunicipalityEntry(MunicipalityCode("131172"), "東京都", "北区", "ﾄｳｷｮｳﾄ", "ｷﾀｸ"),
    "131181": MunicipalityEntry(MunicipalityCode("131181"), "東京都", "荒川区", "ﾄｳｷｮｳﾄ", "ｱﾗｶﾜｸ"),
    "131199": MunicipalityEntry(MunicipalityCode("131199"), "東京都", "板橋区", "ﾄｳｷｮｳﾄ", "ｲﾀﾊﾞｼｸ"),
    "131202": MunicipalityEntry(MunicipalityCode("131202"), "東京都", "練馬区", "ﾄｳｷｮｳﾄ", "ﾈﾘﾏｸ"),
    "131211": MunicipalityEntry(MunicipalityCode("131211"), "東京都", "足立区", "ﾄｳｷｮｳﾄ", "ｱﾀﾞﾁｸ"),
    "131229": MunicipalityEntry(MunicipalityCode("131229"), "東京都", "葛飾区", "ﾄｳｷｮｳﾄ", "ｶﾂｼｶｸ"),
    "131237": MunicipalityEntry(MunicipalityCode("131237"), "東京都", "江戸川区", "ﾄｳｷｮｳﾄ", "ｴﾄﾞｶﾞﾜｸ"),
    "132012": MunicipalityEntry(MunicipalityCode("132012"), "東京都", "八王子市", "ﾄｳｷｮｳﾄ", "ﾊﾁｵｳｼﾞｼ"),
    "132021": MunicipalityEntry(MunicipalityCode("132021"), "東京都", "立川市", "ﾄｳｷｮｳﾄ", "ﾀﾁｶﾜｼ"),
    "132039": MunicipalityEntry(MunicipalityCode("132039"), "東京都", "武蔵野市", "ﾄｳｷｮｳﾄ", "ﾑｻｼﾉｼ"),
    "132047": MunicipalityEntry(MunicipalityCode("132047"), "東京都", "三鷹市", "ﾄｳｷｮｳﾄ", "ﾐﾀｶｼ"),
    "132055": MunicipalityEntry(MunicipalityCode("132055"), "東京都", "青梅市", "ﾄｳｷｮｳﾄ", "ｵｳﾒｼ"),
    "132063": MunicipalityEntry(MunicipalityCode("132063"), "東京都", "府中市", "ﾄｳｷｮｳﾄ", "ﾌﾁｭｳｼ"),
    "132071": MunicipalityEntry(MunicipalityCode("132071"), "東京都", "昭島市", "ﾄｳｷｮｳﾄ", "ｱｷｼﾏｼ"),
    "132080": MunicipalityEntry(MunicipalityCode("132080"), "東京都", "調布市", "ﾄｳｷｮｳﾄ", "ﾁｮｳﾌｼ"),
    "132098": MunicipalityEntry(MunicipalityCode("132098"), "東京都", "町田市", "ﾄｳｷｮｳﾄ", "ﾏﾁﾀﾞｼ"),
    "132101": MunicipalityEntry(MunicipalityCode("132101"), "東京都", "小金井市", "ﾄｳｷｮｳﾄ", "ｺｶﾞﾈｲｼ"),
    "132110": MunicipalityEntry(MunicipalityCode("132110"), "東京都", "小平市", "ﾄｳｷｮｳﾄ", "ｺﾀﾞｲﾗｼ"),
    "132128": MunicipalityEntry(MunicipalityCode("132128"), "東京都", "日野市", "ﾄｳｷｮｳﾄ", "ﾋﾉｼ"),
    "132136": MunicipalityEntry(MunicipalityCode("132136"), "東京都", "東村山市", "ﾄｳｷｮｳﾄ", "ﾋｶﾞｼﾑﾗﾔﾏｼ"),
    "132144": MunicipalityEntry(MunicipalityCode("132144"), "東京都", "国分寺市", "ﾄｳｷｮｳﾄ", "ｺｸﾌﾞﾝｼﾞｼ"),
    "132152": MunicipalityEntry(MunicipalityCode("132152"), "東京都", "国立市", "ﾄｳｷｮｳﾄ", "ｸﾆﾀﾁｼ"),
    "132187": MunicipalityEntry(MunicipalityCode("132187"), "東京都", "福生市", "ﾄｳｷｮｳﾄ", "ﾌｯｻｼ"),
    "132195": MunicipalityEntry(MunicipalityCode("132195"), "東京都", "狛江市", "ﾄｳｷｮｳﾄ", "ｺﾏｴｼ"),
    "132209": MunicipalityEntry(MunicipalityCode("132209"), "東京都", "東大和市", "ﾄｳｷｮｳﾄ", "ﾋｶﾞｼﾔﾏﾄｼ"),
    "132217": MunicipalityEntry(MunicipalityCode("132217"), "東京都", "清瀬市", "ﾄｳｷｮｳﾄ", "ｷﾖｾｼ"),
    "132225": MunicipalityEntry(MunicipalityCode("132225"), "東京都", "東久留米市", "ﾄｳｷｮｳﾄ", "ﾋｶﾞｼｸﾙﾒｼ"),
    "132233": MunicipalityEntry(MunicipalityCode("132233"), "東京都", "武蔵村山市", "ﾄｳｷｮｳﾄ", "ﾑｻｼﾑﾗﾔﾏｼ"),
    "132241": MunicipalityEntry(MunicipalityCode("132241"), "東京都", "多摩市", "ﾄｳｷｮｳﾄ", "ﾀﾏｼ"),
    "132250": MunicipalityEntry(MunicipalityCode("132250"), "東京都", "稲城市", "ﾄｳｷｮｳﾄ", "ｲﾅｷﾞｼ"),
    "132276": MunicipalityEntry(MunicipalityCode("132276"), "東京都", "羽村市", "ﾄｳｷｮｳﾄ", "ﾊﾑﾗｼ"),
    "132284": MunicipalityEntry(MunicipalityCode("132284"), "東京都", "あきる野市", "ﾄｳｷｮｳﾄ", "ｱｷﾙﾉｼ"),
    "132292": MunicipalityEntry(MunicipalityCode("132292"), "東京都", "西東京市", "ﾄｳｷｮｳﾄ", "ﾆｼﾄｳｷｮｳｼ"),
    "133035": MunicipalityEntry(MunicipalityCode("133035"), "東京都", "瑞穂町", "ﾄｳｷｮｳﾄ", "ﾐｽﾞﾎﾏﾁ"),
    "133051": MunicipalityEntry(MunicipalityCode("133051"), "東京都", "日の出町", "ﾄｳｷｮｳﾄ", "ﾋﾉﾃﾞﾏﾁ"),
    "133078": MunicipalityEntry(MunicipalityCode("133078"), "東京都", "檜原村", "ﾄｳｷｮｳﾄ", "ﾋﾉﾊﾗﾑﾗ"),
    "133086": MunicipalityEntry(MunicipalityCode("133086"), "東京都", "奥多摩町", "ﾄｳｷｮｳﾄ", "ｵｸﾀﾏﾏﾁ"),
    "133612": MunicipalityEntry(MunicipalityCode("133612"), "東京都", "大島町", "ﾄｳｷｮｳﾄ", "ｵｵｼﾏﾏﾁ"),
    "133621": MunicipalityEntry(MunicipalityCode("133621"), "東京都", "利島村", "ﾄｳｷｮｳﾄ", "ﾄｼﾏﾑﾗ"),
    "133639": MunicipalityEntry(MunicipalityCode("133639"), "東京都", "新島村", "ﾄｳｷｮｳﾄ", "ﾆｲｼﾞﾏﾑﾗ"),
    "133647": MunicipalityEntry(MunicipalityCode("133647"), "東京都", "神津島村", "ﾄｳｷｮｳﾄ", "ｺｳﾂﾞｼﾏﾑﾗ"),
    "133817": MunicipalityEntry(MunicipalityCode("133817"), "東京都", "三宅村", "ﾄｳｷｮｳﾄ", "ﾐﾔｹﾑﾗ"),
    "133825": MunicipalityEntry(MunicipalityCode("133825"), "東京都", "御蔵島村", "ﾄｳｷｮｳﾄ", "ﾐｸﾗｼﾞﾏﾑﾗ"),
    "134015": MunicipalityEntry(MunicipalityCode("134015"), "東京都", "八丈町", "ﾄｳｷｮｳﾄ", "ﾊﾁｼﾞｮｳﾏﾁ"),
    "134023": MunicipalityEntry(MunicipalityCode("134023"), "東京都", "青ヶ島村", "ﾄｳｷｮｳﾄ", "ｱｵｶﾞｼﾏﾑﾗ"),
    "134210": MunicipalityEntry(MunicipalityCode("134210"), "東京都", "小笠原村", "ﾄｳｷｮｳﾄ", "ｵｶﾞｻﾜﾗﾑﾗ"),
    "140007": MunicipalityEntry(MunicipalityCode("140007"), "神奈川県", "", "ｶﾅｶﾞﾜｹﾝ", ""),
    "141003": MunicipalityEntry(MunicipalityCode("141003"), "神奈川県", "横浜市", "ｶﾅｶﾞﾜｹﾝ", "ﾖｺﾊﾏｼ"),
    "141305": MunicipalityEntry(MunicipalityCode("141305"), "神奈川県", "川崎市", "ｶﾅｶﾞﾜｹﾝ", "ｶﾜｻｷｼ"),
    "141500": MunicipalityEntry(MunicipalityCode("141500"), "神奈川県", "相模原市", "ｶﾅｶﾞﾜｹﾝ", "ｻｶﾞﾐﾊﾗｼ"),
    "142018": MunicipalityEntry(MunicipalityCode("142018"), "神奈川県", "横須賀市", "ｶﾅｶﾞﾜｹﾝ", "ﾖｺｽｶｼ"),
    "142034": MunicipalityEntry(MunicipalityCode("142034"), "神奈川県", "平塚市", "ｶﾅｶﾞﾜｹﾝ", "ﾋﾗﾂｶｼ"),
    "142042": MunicipalityEntry(MunicipalityCode("142042"), "神奈川県", "鎌倉市", "ｶﾅｶﾞﾜｹﾝ", "ｶﾏｸﾗｼ"),
    "142051": MunicipalityEntry(MunicipalityCode("142051"), "神奈川県", "藤沢市", "ｶﾅｶﾞﾜｹﾝ", "ﾌｼﾞｻﾜｼ"),
    "142069": MunicipalityEntry(MunicipalityCode("142069"), "神奈川県", "小田原市", "ｶﾅｶﾞﾜｹﾝ", "ｵﾀﾞﾜﾗｼ"),
    "142077": MunicipalityEntry(MunicipalityCode("142077"), "神奈川県", "茅ヶ崎市", "ｶﾅｶﾞﾜｹﾝ", "ﾁｶﾞｻｷｼ"),
    "142085": MunicipalityEntry(MunicipalityCode("142085"), "神奈川県", "逗子市", "ｶﾅｶﾞﾜｹﾝ", "ｽﾞｼｼ"),
    "142107": MunicipalityEntry(MunicipalityCode("142107"), "神奈川県", "三浦市", "ｶﾅｶﾞﾜｹﾝ", "ﾐｳﾗｼ"),
    "142115": MunicipalityEntry(MunicipalityCode("142115"), "神奈川県", "秦野市", "ｶﾅｶﾞﾜｹﾝ", "ﾊﾀﾞﾉｼ"),
    "142123": MunicipalityEntry(MunicipalityCode("142123"), "神奈川県", "厚木市", "ｶﾅｶﾞﾜｹﾝ", "ｱﾂｷﾞｼ"),
    "142131": MunicipalityEntry(MunicipalityCode("142131"), "神奈川県", "大和市", "ｶﾅｶﾞﾜｹﾝ", "ﾔﾏﾄｼ"),
    "142140": MunicipalityEntry(MunicipalityCode("142140"), "神奈川県", "伊勢原市", "ｶﾅｶﾞﾜｹﾝ", "ｲｾﾊﾗｼ"),
    "142158": MunicipalityEntry(MunicipalityCode("142158"), "神奈川県", "海老名市", "ｶﾅｶﾞﾜｹﾝ", "ｴﾋﾞﾅｼ"),
    "142166": MunicipalityEntry(MunicipalityCode("142166"), "神奈川県", "座間市", "ｶﾅｶﾞﾜｹﾝ", "ｻﾞﾏｼ"),
    "142174": MunicipalityEntry(MunicipalityCode("142174"), "神奈川県", "南足柄市", "ｶﾅｶﾞﾜｹﾝ", "ﾐﾅﾐｱｼｶﾞﾗｼ"),
    "142182": MunicipalityEntry(MunicipalityCode("142182"), "神奈川県", "綾瀬市", "ｶﾅｶﾞﾜｹﾝ", "ｱﾔｾｼ"),
    "143014": MunicipalityEntry(MunicipalityCode("143014"), "神奈川県", "葉山町", "ｶﾅｶﾞﾜｹﾝ", "ﾊﾔﾏﾏﾁ"),
    "143219": MunicipalityEntry(MunicipalityCode("143219"), "神奈川県", "寒川町", "ｶﾅｶﾞﾜｹﾝ", "ｻﾑｶﾜﾏﾁ"),
    "143413": MunicipalityEntry(MunicipalityCode("143413"), "神奈川県", "大磯町", "ｶﾅｶﾞﾜｹﾝ", "ｵｵｲｿﾏﾁ"),
    "143421": MunicipalityEntry(MunicipalityCode("143421"), "神奈川県", "二宮町", "ｶﾅｶﾞﾜｹﾝ", "ﾆﾉﾐﾔﾏﾁ"),
    "143618": MunicipalityEntry(MunicipalityCode("143618"), "神奈川県", "中井町", "ｶﾅｶﾞﾜｹﾝ", "ﾅｶｲﾏﾁ"),
    "143626": MunicipalityEntry(MunicipalityCode("143626"), "神奈川県", "大井町", "ｶﾅｶﾞﾜｹﾝ", "ｵｵｲﾏﾁ"),
    "143634": MunicipalityEntry(MunicipalityCode("143634"), "神奈川県", "松田町", "ｶﾅｶﾞﾜｹﾝ", "ﾏﾂﾀﾞﾏﾁ"),
    "143642": MunicipalityEntry(MunicipalityCode("143642"), "神奈川県", "山北町", "ｶﾅｶﾞﾜｹﾝ", "ﾔﾏｷﾀﾏﾁ"),
    "143669": MunicipalityEntry(MunicipalityCode("143669"), "神奈川県", "開成町", "ｶﾅｶﾞﾜｹﾝ", "ｶｲｾｲﾏﾁ"),
    "143821": MunicipalityEntry(MunicipalityCode("143821"), "神奈川県", "箱根町", "ｶﾅｶﾞﾜｹﾝ", "ﾊｺﾈﾏﾁ"),
    "143839": MunicipalityEntry(MunicipalityCode("143839"), "神奈川県", "真鶴町", "ｶﾅｶﾞﾜｹﾝ", "ﾏﾅﾂﾞﾙﾏﾁ"),
    "143847": MunicipalityEntry(MunicipalityCode("143847"), "神奈川県", "湯河原町", "ｶﾅｶﾞﾜｹﾝ", "ﾕｶﾞﾜﾗﾏﾁ"),
    "144011": MunicipalityEntry(MunicipalityCode("144011"), "神奈川県", "愛川町", "ｶﾅｶﾞﾜｹﾝ", "ｱｲｶﾜﾏﾁ"),
    "144029": MunicipalityEntry(MunicipalityCode("144029"), "神奈川県", "清川村", "ｶﾅｶﾞﾜｹﾝ", "ｷﾖｶﾜﾑﾗ"),
    "150002": MunicipalityEntry(MunicipalityCode("150002"), "新潟県", "", "ﾆｲｶﾞﾀｹﾝ", ""),
    "151009": MunicipalityEntry(MunicipalityCode("151009"), "新潟県", "新潟市", "ﾆｲｶﾞﾀｹﾝ", "ﾆｲｶﾞﾀｼ"),
    "152021": MunicipalityEntry(MunicipalityCode("152021"), "新潟県", "長岡市", "ﾆｲｶﾞﾀｹﾝ", "ﾅｶﾞｵｶｼ"),
    "152048": MunicipalityEntry(MunicipalityCode("152048"), "新潟県", "三条市", "ﾆｲｶﾞﾀｹﾝ", "ｻﾝｼﾞｮｳｼ"),
    "152056": MunicipalityEntry(MunicipalityCode("152056"), "新潟県", "柏崎市", "ﾆｲｶﾞﾀｹﾝ", "ｶｼﾜｻﾞｷｼ"),
    "152064": MunicipalityEntry(MunicipalityCode("152064"), "新潟県", "新発田市", "ﾆｲｶﾞﾀｹﾝ", "ｼﾊﾞﾀｼ"),
    "152081": MunicipalityEntry(MunicipalityCode("152081"), "新潟県", "小千谷市", "ﾆｲｶﾞﾀｹﾝ", "ｵﾁﾞﾔｼ"),
    "152099": MunicipalityEntry(MunicipalityCode("152099"), "新潟県", "加茂市", "ﾆｲｶﾞﾀｹﾝ", "ｶﾓｼ"),
    "152102": MunicipalityEntry(MunicipalityCode("152102"), "新潟県", "十日町市", "ﾆｲｶﾞﾀｹﾝ", "ﾄｵｶﾏﾁｼ"),
    "152111": MunicipalityEntry(MunicipalityCode("152111"), "新潟県", "見附市", "ﾆｲｶﾞﾀｹﾝ", "ﾐﾂｹｼ"),
    "152129": MunicipalityEntry(MunicipalityCode("152129"), "新潟県", "村上市", "ﾆｲｶﾞﾀｹﾝ", "ﾑﾗｶﾐｼ"),
    "152137": MunicipalityEntry(MunicipalityCode("152137"), "新潟県", "燕市", "ﾆｲｶﾞﾀｹﾝ", "ﾂﾊﾞﾒｼ"),
    "152161": MunicipalityEntry(MunicipalityCode("152161"), "新潟県", "糸魚川市", "ﾆｲｶﾞﾀｹﾝ", "ｲﾄｲｶﾞﾜｼ"),
    "152170": MunicipalityEntry(MunicipalityCode("152170"), "新潟県", "妙高市", "ﾆｲｶﾞﾀｹﾝ", "ﾐｮｳｺｳｼ"),
    "152188": MunicipalityEntry(MunicipalityCode("152188"), "新潟県", "五泉市", "ﾆｲｶﾞﾀｹﾝ", "ｺﾞｾﾝｼ"),
    "152226": MunicipalityEntry(MunicipalityCode("152226"), "新潟県", "上越市", "ﾆｲｶﾞﾀｹﾝ", "ｼﾞｮｳｴﾂｼ"),
    "152234": MunicipalityEntry(MunicipalityCode("152234"), "新潟県", "阿賀野市", "ﾆｲｶﾞﾀｹﾝ", "ｱｶﾞﾉｼ"),
    "152242": MunicipalityEntry(MunicipalityCode("152242"), "新潟県", "佐渡市", "ﾆｲｶﾞﾀｹﾝ", "ｻﾄﾞｼ"),
    "152251": MunicipalityEntry(MunicipalityCode("152251"), "新潟県", "魚沼市", "ﾆｲｶﾞﾀｹﾝ", "ｳｵﾇﾏｼ"),
    "152269": MunicipalityEntry(MunicipalityCode("152269"), "新潟県", "南魚沼市", "ﾆｲｶﾞﾀｹﾝ", "ﾐﾅﾐｳｵﾇﾏｼ"),
    "152277": MunicipalityEntry(MunicipalityCode("152277"), "新潟県", "胎内市", "ﾆｲｶﾞﾀｹﾝ", "ﾀｲﾅｲｼ"),
    "153079": MunicipalityEntry(MunicipalityCode("153079"), "新潟県", "聖籠町", "ﾆｲｶﾞﾀｹﾝ", "ｾｲﾛｳﾏﾁ"),
    "153427": MunicipalityEntry(MunicipalityCode("153427"), "新潟県", "弥彦村", "ﾆｲｶﾞﾀｹﾝ", "ﾔﾋｺﾑﾗ"),
    "153613": MunicipalityEntry(MunicipalityCode("153613"), "新潟県", "田上町", "ﾆｲｶﾞﾀｹﾝ", "ﾀｶﾞﾐﾏﾁ"),
    "153851": MunicipalityEntry(MunicipalityCode("153851"), "新潟県", "阿賀町", "ﾆｲｶﾞﾀｹﾝ", "ｱｶﾞﾏﾁ"),
    "154059": MunicipalityEntry(MunicipalityCode("154059"), "新潟県", "出雲崎町", "ﾆｲｶﾞﾀｹﾝ", "ｲｽﾞﾓｻﾞｷﾏﾁ"),
    "154610": MunicipalityEntry(MunicipalityCode("154610"), "新潟県", "湯沢町", "ﾆｲｶﾞﾀｹﾝ", "ﾕｻﾞﾜﾏﾁ"),
    "154822": MunicipalityEntry(MunicipalityCode("154822"), "新潟県", "津南町", "ﾆｲｶﾞﾀｹﾝ", "ﾂﾅﾝﾏﾁ"),
    "155047": MunicipalityEntry(MunicipalityCode("155047"), "新潟県", "刈羽村", "ﾆｲｶﾞﾀｹﾝ", "ｶﾘﾜﾑﾗ"),
    "155811": MunicipalityEntry(MunicipalityCode("155811"), "新潟県", "関川村", "ﾆｲｶﾞﾀｹﾝ", "ｾｷｶﾜﾑﾗ"),
    "155861": MunicipalityEntry(MunicipalityCode("155861"), "新潟県", "粟島浦村", "ﾆｲｶﾞﾀｹﾝ", "ｱﾜｼﾏｳﾗﾑﾗ"),
    "160008": MunicipalityEntry(MunicipalityCode("160008"), "富山県", "", "ﾄﾔﾏｹﾝ", ""),
    "162019": MunicipalityEntry(MunicipalityCode("162019"), "富山県", "富山市", "ﾄﾔﾏｹﾝ", "ﾄﾔﾏｼ"),
    "162027": MunicipalityEntry(MunicipalityCode("162027"), "富山県", "高岡市", "ﾄﾔﾏｹﾝ", "ﾀｶｵｶｼ"),
    "162043": MunicipalityEntry(MunicipalityCode("162043"), "富山県", "魚津市", "ﾄﾔﾏｹﾝ", "ｳｵﾂﾞｼ"),
    "162051": MunicipalityEntry(MunicipalityCode("162051"), "富山県", "氷見市", "ﾄﾔﾏｹﾝ", "ﾋﾐｼ"),
    "162060": MunicipalityEntry(MunicipalityCode("162060"), "富山県", "滑川市", "ﾄﾔﾏｹﾝ", "ﾅﾒﾘｶﾜｼ"),
    "162078": MunicipalityEntry(MunicipalityCode("162078"), "富山県", "黒部市", "ﾄﾔﾏｹﾝ", "ｸﾛﾍﾞｼ"),
    "162086": MunicipalityEntry(MunicipalityCode("162086"), "富山県", "砺波市", "ﾄﾔﾏｹﾝ", "ﾄﾅﾐｼ"),
    "162094": MunicipalityEntry(MunicipalityCode("162094"), "富山県", "小矢部市", "ﾄﾔﾏｹﾝ", "ｵﾔﾍﾞｼ"),
    "162108": MunicipalityEntry(MunicipalityCode("162108"), "富山県", "南砺市", "ﾄﾔﾏｹﾝ", "ﾅﾝﾄｼ"),
    "162116": MunicipalityEntry(MunicipalityCode("162116"), "富山県", "射水市", "ﾄﾔﾏｹﾝ", "ｲﾐｽﾞｼ"),
    "163210": MunicipalityEntry(MunicipalityCode("163210"), "富山県", "舟橋村", "ﾄﾔﾏｹﾝ", "ﾌﾅﾊｼﾑﾗ"),
    "163228": MunicipalityEntry(MunicipalityCode("163228"), "富山県", "上市町", "ﾄﾔﾏｹﾝ", "ｶﾐｲﾁﾏﾁ"),
    "163236": MunicipalityEntry(MunicipalityCode("163236"), "富山県", "立山町", "ﾄﾔﾏｹﾝ", "ﾀﾃﾔﾏﾏﾁ"),
    "163422": MunicipalityEntry(MunicipalityCode("163422"), "富山県", "入善町", "ﾄﾔﾏｹﾝ", "ﾆｭｳｾﾞﾝﾏﾁ"),
    "163431": MunicipalityEntry(MunicipalityCode("163431"), "富山県", "朝日町", "ﾄﾔﾏｹﾝ", "ｱｻﾋﾏﾁ"),
    "170003": MunicipalityEntry(MunicipalityCode("170003"), "石川県", "", "ｲｼｶﾜｹﾝ", ""),
    "172014": MunicipalityEntry(MunicipalityCode("172014"), "石川県", "金沢市", "ｲｼｶﾜｹﾝ", "ｶﾅｻﾞﾜｼ"),
    "172022": MunicipalityEntry(MunicipalityCode("172022"), "石川県", "七尾市", "ｲｼｶﾜｹﾝ", "ﾅﾅｵｼ"),
    "172031": MunicipalityEntry(MunicipalityCode("172031"), "石川県", "小松市", "ｲｼｶﾜｹﾝ", "ｺﾏﾂｼ"),
    "172049": MunicipalityEntry(MunicipalityCode("172049"), "石川県", "輪島市", "ｲｼｶﾜｹﾝ", "ﾜｼﾞﾏｼ"),
    "172057": MunicipalityEntry(MunicipalityCode("172057"), "石川県", "珠洲市", "ｲｼｶﾜｹﾝ", "ｽｽﾞｼ"),
    "172065": MunicipalityEntry(MunicipalityCode("172065"), "石川県", "加賀市", "ｲｼｶﾜｹﾝ", "ｶｶﾞｼ"),
    "172073": MunicipalityEntry(MunicipalityCode("172073"), "石川県", "羽咋市", "ｲｼｶﾜｹﾝ", "ﾊｸｲｼ"),
    "172090": MunicipalityEntry(MunicipalityCode("172090"), "石川県", "かほく市", "ｲｼｶﾜｹﾝ", "ｶﾎｸｼ"),
    "172103": MunicipalityEntry(MunicipalityCode("172103"), "石川県", "白山市", "ｲｼｶﾜｹﾝ", "ﾊｸｻﾝｼ"),
    "172111": MunicipalityEntry(MunicipalityCode("172111"), "石川県", "能美市", "ｲｼｶﾜｹﾝ", "ﾉﾐｼ"),
    "172120": MunicipalityEntry(MunicipalityCode("172120"), "石川県", "野々市市", "ｲｼｶﾜｹﾝ", "ﾉﾉｲﾁｼ"),
    "173240": MunicipalityEntry(MunicipalityCode("173240"), "石川県", "川北町", "ｲｼｶﾜｹﾝ", "ｶﾜｷﾀﾏﾁ"),
    "173614": MunicipalityEntry(MunicipalityCode("173614"), "石川県", "津幡町", "ｲｼｶﾜｹﾝ", "ﾂﾊﾞﾀﾏﾁ"),
    "173657": MunicipalityEntry(MunicipalityCode("173657"), "石川県", "内灘町", "ｲｼｶﾜｹﾝ", "ｳﾁﾅﾀﾞﾏﾁ"),
    "173843": MunicipalityEntry(MunicipalityCode("173843"), "石川県", "志賀町", "ｲｼｶﾜｹﾝ", "ｼｶﾏﾁ"),
    "173860": MunicipalityEntry(MunicipalityCode("173860"), "石川県", "宝達志水町", "ｲｼｶﾜｹﾝ", "ﾎｳﾀﾞﾂｼﾐｽﾞﾁｮｳ"),
    "174076": MunicipalityEntry(MunicipalityCode("174076"), "石川県", "中能登町", "ｲｼｶﾜｹﾝ", "ﾅｶﾉﾄﾏﾁ"),
    "174611": MunicipalityEntry(MunicipalityCode("174611"), "石川県", "穴水町", "ｲｼｶﾜｹﾝ", "ｱﾅﾐｽﾞﾏﾁ"),
    "174637": MunicipalityEntry(MunicipalityCode("174637"), "石川県", "能登町", "ｲｼｶﾜｹﾝ", "ﾉﾄﾁｮｳ"),
    "180009": MunicipalityEntry(MunicipalityCode("180009"), "福井県", "", "ﾌｸｲｹﾝ", ""),
    "182010": MunicipalityEntry(MunicipalityCode("182010"), "福井県", "福井市", "ﾌｸｲｹﾝ", "ﾌｸｲｼ"),
    "182028": MunicipalityEntry(MunicipalityCode("182028"), "福井県", "敦賀市", "ﾌｸｲｹﾝ", "ﾂﾙｶﾞｼ"),
    "182044": MunicipalityEntry(MunicipalityCode("182044"), "福井県", "小浜市", "ﾌｸｲｹﾝ", "ｵﾊﾞﾏｼ"),
    "182052": MunicipalityEntry(MunicipalityCode("182052"), "福井県", "大野市", "ﾌｸｲｹﾝ", "ｵｵﾉｼ"),
    "182061": MunicipalityEntry(MunicipalityCode("182061"), "福井県", "勝山市", "ﾌｸｲｹﾝ", "ｶﾂﾔﾏｼ"),
    "182079": MunicipalityEntry(MunicipalityCode("182079"), "福井県", "鯖江市", "ﾌｸｲｹﾝ", "ｻﾊﾞｴｼ"),
    "182087": MunicipalityEntry(MunicipalityCode("182087"), "福井県", "あわら市", "ﾌｸｲｹﾝ", "ｱﾜﾗｼ"),
    "182095": MunicipalityEntry(MunicipalityCode("182095"), "福井県", "越前市", "ﾌｸｲｹﾝ", "ｴﾁｾﾞﾝｼ"),
    "182109": MunicipalityEntry(MunicipalityCode("182109"), "福井県", "坂井市", "ﾌｸｲｹﾝ", "ｻｶｲｼ"),
    "183229": MunicipalityEntry(MunicipalityCode("183229"), "福井県", "永平寺町", "ﾌｸｲｹﾝ", "ｴｲﾍｲｼﾞﾁｮｳ"),
    "183822": MunicipalityEntry(MunicipalityCode("183822"), "福井県", "池田町", "ﾌｸｲｹﾝ", "ｲｹﾀﾞﾁｮｳ"),
    "184047": MunicipalityEntry(MunicipalityCode("184047"), "福井県", "南越前町", "ﾌｸｲｹﾝ", "ﾐﾅﾐｴﾁｾﾞﾝﾁｮｳ"),
    "184233": MunicipalityEntry(MunicipalityCode("184233"), "福井県", "越前町", "ﾌｸｲｹﾝ", "ｴﾁｾﾞﾝﾁｮｳ"),
    "184420": MunicipalityEntry(MunicipalityCode("184420"), "福井県", "美浜町", "ﾌｸｲｹﾝ", "ﾐﾊﾏﾁｮｳ"),
    "184811": MunicipalityEntry(MunicipalityCode("184811"), "福井県", "高浜町", "ﾌｸｲｹﾝ", "ﾀｶﾊﾏﾁｮｳ"),
    "184837": MunicipalityEntry(MunicipalityCode("184837"), "福井県", "おおい町", "ﾌｸｲｹﾝ", "ｵｵｲﾁｮｳ"),
    "185019": MunicipalityEntry(MunicipalityCode("185019"), "福井県", "若狭町", "ﾌｸｲｹﾝ", "ﾜｶｻﾁｮｳ"),
    "190004": MunicipalityEntry(MunicipalityCode("190004"), "山梨県", "", "ﾔﾏﾅｼｹﾝ", ""),
    "192015": MunicipalityEntry(MunicipalityCode("192015"), "山梨県", "甲府市", "ﾔﾏﾅｼｹﾝ", "ｺｳﾌｼ"),
    "192023": MunicipalityEntry(MunicipalityCode("192023"), "山梨県", "富士吉田市", "ﾔﾏﾅｼｹﾝ", "ﾌｼﾞﾖｼﾀﾞｼ"),
    "192040": MunicipalityEntry(MunicipalityCode("192040"), "山梨県", "都留市", "ﾔﾏﾅｼｹﾝ", "ﾂﾙｼ"),
    "192058": MunicipalityEntry(MunicipalityCode("192058"), "山梨県", "山梨市", "ﾔﾏﾅｼｹﾝ", "ﾔﾏﾅｼｼ"),
    "192066": MunicipalityEntry(MunicipalityCode("192066"), "山梨県", "大月市", "ﾔﾏﾅｼｹﾝ", "ｵｵﾂｷｼ"),
    "192074": MunicipalityEntry(MunicipalityCode("192074"), "山梨県", "韮崎市", "ﾔﾏﾅｼｹﾝ", "ﾆﾗｻｷｼ"),
    "192082": MunicipalityEntry(MunicipalityCode("192082"), "山梨県", "南アルプス市", "ﾔﾏﾅｼｹﾝ", "ﾐﾅﾐｱﾙﾌﾟｽｼ"),
    "192091": MunicipalityEntry(MunicipalityCode("192091"), "山梨県", "北杜市", "ﾔﾏﾅｼｹﾝ", "ﾎｸﾄｼ"),
    "192104": MunicipalityEntry(MunicipalityCode("192104"), "山梨県", "甲斐市", "ﾔﾏﾅｼｹﾝ", "ｶｲｼ"),
    "192112": MunicipalityEntry(MunicipalityCode("192112"), "山梨県", "笛吹市", "ﾔﾏﾅｼｹﾝ", "ﾌｴﾌｷｼ"),
    "192121": MunicipalityEntry(MunicipalityCode("192121"), "山梨県", "上野原市", "ﾔﾏﾅｼｹﾝ", "ｳｴﾉﾊﾗｼ"),
    "192139": MunicipalityEntry(MunicipalityCode("192139"), "山梨県", "甲州市", "ﾔﾏﾅｼｹﾝ", "ｺｳｼｭｳｼ"),
    "192147": MunicipalityEntry(MunicipalityCode("192147"), "山梨県", "中央市", "ﾔﾏﾅｼｹﾝ", "ﾁｭｳｵｳｼ"),
    "193461": MunicipalityEntry(MunicipalityCode("193461"), "山梨県", "市川三郷町", "ﾔﾏﾅｼｹﾝ", "ｲﾁｶﾜﾐｻﾄﾁｮｳ"),
    "193640": MunicipalityEntry(MunicipalityCode("193640"), "山梨県", "早川町", "ﾔﾏﾅｼｹﾝ", "ﾊﾔｶﾜﾁｮｳ"),
    "193658": MunicipalityEntry(MunicipalityCode("193658"), "山梨県", "身延町", "ﾔﾏﾅｼｹﾝ", "ﾐﾉﾌﾞﾁｮｳ"),
    "193666": MunicipalityEntry(MunicipalityCode("193666"), "山梨県", "南部町", "ﾔﾏﾅｼｹﾝ", "ﾅﾝﾌﾞﾁｮｳ"),
    "193682": MunicipalityEntry(MunicipalityCode("193682"), "山梨県", "富士川町", "ﾔﾏﾅｼｹﾝ", "ﾌｼﾞｶﾜﾁｮｳ"),
    "193844": MunicipalityEntry(MunicipalityCode("193844"), "山梨県", "昭和町", "ﾔﾏﾅｼｹﾝ", "ｼｮｳﾜﾁｮｳ"),
    "194221": MunicipalityEntry(MunicipalityCode("194221"), "山梨県", "道志村", "ﾔﾏﾅｼｹﾝ", "ﾄﾞｳｼﾑﾗ"),
    "194239": MunicipalityEntry(MunicipalityCode("194239"), "山梨県", "西桂町", "ﾔﾏﾅｼｹﾝ", "ﾆｼｶﾂﾗﾁｮｳ"),
    "194247": MunicipalityEntry(MunicipalityCode("194247"), "山梨県", "忍野村", "ﾔﾏﾅｼｹﾝ", "ｵｼﾉﾑﾗ"),
    "194255": MunicipalityEntry(MunicipalityCode("194255"), "山梨県", "山中湖村", "ﾔﾏﾅｼｹﾝ", "ﾔﾏﾅｶｺﾑﾗ"),
    "194298": MunicipalityEntry(MunicipalityCode("194298"), "山梨県", "鳴沢村", "ﾔﾏﾅｼｹﾝ", "ﾅﾙｻﾜﾑﾗ"),
    "194301": MunicipalityEntry(MunicipalityCode("194301"), "山梨県", "富士河口湖町", "ﾔﾏﾅｼｹﾝ", "ﾌｼﾞｶﾜｸﾞﾁｺﾏﾁ"),
    "194425": MunicipalityEntry(MunicipalityCode("194425"), "山梨県", "小菅村", "ﾔﾏﾅｼｹﾝ", "ｺｽｹﾞﾑﾗ"),
    "194433": MunicipalityEntry(MunicipalityCode("194433"), "山梨県", "丹波山村", "ﾔﾏﾅｼｹﾝ", "ﾀﾊﾞﾔﾏﾑﾗ"),
    "200000": MunicipalityEntry(MunicipalityCode("200000"), "長野県", "", "ﾅｶﾞﾉｹﾝ", ""),
    "202011": MunicipalityEntry(MunicipalityCode("202011"), "長野県", "長野市", "ﾅｶﾞﾉｹﾝ", "ﾅｶﾞﾉｼ"),
    "202029": MunicipalityEntry(MunicipalityCode("202029"), "長野県", "松本市", "ﾅｶﾞﾉｹﾝ", "ﾏﾂﾓﾄｼ"),
    "202037": MunicipalityEntry(MunicipalityCode("202037"), "長野県", "上田市", "ﾅｶﾞﾉｹﾝ", "ｳｴﾀﾞｼ"),
    "202045": MunicipalityEntry(MunicipalityCode("202045"), "長野県", "岡谷市", "ﾅｶﾞﾉｹﾝ", "ｵｶﾔｼ"),
    "202053": MunicipalityEntry(MunicipalityCode("202053"), "長野県", "飯田市", "ﾅｶﾞﾉｹﾝ", "ｲｲﾀﾞｼ"),
    "202061": MunicipalityEntry(MunicipalityCode("202061"), "長野県", "諏訪市", "ﾅｶﾞﾉｹﾝ", "ｽﾜｼ"),
    "202070": MunicipalityEntry(MunicipalityCode("202070"), "長野県", "須坂市", "ﾅｶﾞﾉｹﾝ", "ｽｻﾞｶｼ"),
    "202088": MunicipalityEntry(MunicipalityCode("202088"), "長野県", "小諸市", "ﾅｶﾞﾉｹﾝ", "ｺﾓﾛｼ"),
    "202096": MunicipalityEntry(MunicipalityCode("202096"), "長野県", "伊那市", "ﾅｶﾞﾉｹﾝ", "ｲﾅｼ"),
    "202100": MunicipalityEntry(MunicipalityCode("202100"), "長野県", "駒ヶ根市", "ﾅｶﾞﾉｹﾝ", "ｺﾏｶﾞﾈｼ"),
    "202118": MunicipalityEntry(MunicipalityCode("202118"), "長野県", "中野市", "ﾅｶﾞﾉｹﾝ", "ﾅｶﾉｼ"),
    "202126": MunicipalityEntry(MunicipalityCode("202126"), "長野県", "大町市", "ﾅｶﾞﾉｹﾝ", "ｵｵﾏﾁｼ"),
    "202134": MunicipalityEntry(MunicipalityCode("202134"), "長野県", "飯山市", "ﾅｶﾞﾉｹﾝ", "ｲｲﾔﾏｼ"),
    "202142": MunicipalityEntry(MunicipalityCode("202142"), "長野県", "茅野市", "ﾅｶﾞﾉｹﾝ", "ﾁﾉｼ"),
    "202151": MunicipalityEntry(MunicipalityCode("202151"), "長野県", "塩尻市", "ﾅｶﾞﾉｹﾝ", "ｼｵｼﾞﾘｼ"),
    "202177": MunicipalityEntry(MunicipalityCode("202177"), "長野県", "佐久市", "ﾅｶﾞﾉｹﾝ", "ｻｸｼ"),
    "202185": MunicipalityEntry(MunicipalityCode("202185"), "長野県", "千曲市", "ﾅｶﾞﾉｹﾝ", "ﾁｸﾏｼ"),
    "202193": MunicipalityEntry(MunicipalityCode("202193"), "長野県", "東御市", "ﾅｶﾞﾉｹﾝ", "ﾄｳﾐｼ"),
    "202207": MunicipalityEntry(MunicipalityCode("202207"), "長野県", "安曇野市", "ﾅｶﾞﾉｹﾝ", "ｱﾂﾞﾐﾉｼ"),
    "203033": MunicipalityEntry(MunicipalityCode("203033"), "長野県", "小海町", "ﾅｶﾞﾉｹﾝ", "ｺｳﾐﾏﾁ"),
    "203041": MunicipalityEntry(MunicipalityCode("203041"), "長野県", "川上村", "ﾅｶﾞﾉｹﾝ", "ｶﾜｶﾐﾑﾗ"),
    "203050": MunicipalityEntry(MunicipalityCode("203050"), "長野県", "南牧村", "ﾅｶﾞﾉｹﾝ", "ﾐﾅﾐﾏｷﾑﾗ"),
    "203068": MunicipalityEntry(MunicipalityCode("203068"), "長野県", "南相木村", "ﾅｶﾞﾉｹﾝ", "ﾐﾅﾐｱｲｷﾑﾗ"),
    "203076": MunicipalityEntry(MunicipalityCode("203076"), "長野県", "北相木村", "ﾅｶﾞﾉｹﾝ", "ｷﾀｱｲｷﾑﾗ"),
    "203092": MunicipalityEntry(MunicipalityCode("203092"), "長野県", "佐久穂町", "ﾅｶﾞﾉｹﾝ", "ｻｸﾎﾏﾁ"),
    "203211": MunicipalityEntry(MunicipalityCode("203211"), "長野県", "軽井沢町", "ﾅｶﾞﾉｹﾝ", "ｶﾙｲｻﾞﾜﾏﾁ"),
    "203238": MunicipalityEntry(MunicipalityCode("203238"), "長野県", "御代田町", "ﾅｶﾞﾉｹﾝ", "ﾐﾖﾀﾏﾁ"),
    "203246": MunicipalityEntry(MunicipalityCode("203246"), "長野県", "立科町", "ﾅｶﾞﾉｹﾝ", "ﾀﾃｼﾅﾏﾁ"),
    "203491": MunicipalityEntry(MunicipalityCode("203491"), "長野県", "青木村", "ﾅｶﾞﾉｹﾝ", "ｱｵｷﾑﾗ"),
    "203505": MunicipalityEntry(MunicipalityCode("203505"), "長野県", "長和町", "ﾅｶﾞﾉｹﾝ", "ﾅｶﾞﾜﾏﾁ"),
    "203611": MunicipalityEntry(MunicipalityCode("203611"), "長野県", "下諏訪町", "ﾅｶﾞﾉｹﾝ", "ｼﾓｽﾜﾏﾁ"),
    "203629": MunicipalityEntry(MunicipalityCode("203629"), "長野県", "富士見町", "ﾅｶﾞﾉｹﾝ", "ﾌｼﾞﾐﾏﾁ"),
    "203637": MunicipalityEntry(MunicipalityCode("203637"), "長野県", "原村", "ﾅｶﾞﾉｹﾝ", "ﾊﾗﾑﾗ"),
    "203823": MunicipalityEntry(MunicipalityCode("203823"), "長野県", "辰野町", "ﾅｶﾞﾉｹﾝ", "ﾀﾂﾉﾏﾁ"),
    "203831": MunicipalityEntry(MunicipalityCode("203831"), "長野県", "箕輪町", "ﾅｶﾞﾉｹﾝ", "ﾐﾉﾜﾏﾁ"),
    "203840": MunicipalityEntry(MunicipalityCode("203840"), "長野県", "飯島町", "ﾅｶﾞﾉｹﾝ", "ｲｲｼﾞﾏﾏﾁ"),
    "203858": MunicipalityEntry(MunicipalityCode("203858"), "長野県", "南箕輪村", "ﾅｶﾞﾉｹﾝ", "ﾐﾅﾐﾐﾉﾜﾑﾗ"),
    "203866": MunicipalityEntry(MunicipalityCode("203866"), "長野県", "中川村", "ﾅｶﾞﾉｹﾝ", "ﾅｶｶﾞﾜﾑﾗ"),
    "203882": MunicipalityEntry(MunicipalityCode("203882"), "長野県", "宮田村", "ﾅｶﾞﾉｹﾝ", "ﾐﾔﾀﾞﾑﾗ"),
    "204021": MunicipalityEntry(MunicipalityCode("204021"), "長野県", "松川町", "ﾅｶﾞﾉｹﾝ", "ﾏﾂｶﾜﾏﾁ"),
    "204030": MunicipalityEntry(MunicipalityCode("204030"), "長野県", "高森町", "ﾅｶﾞﾉｹﾝ", "ﾀｶﾓﾘﾏﾁ"),
    "204048": MunicipalityEntry(MunicipalityCode("204048"), "長野県", "阿南町", "ﾅｶﾞﾉｹﾝ", "ｱﾅﾝﾁｮｳ"),
    "204072": MunicipalityEntry(MunicipalityCode("204072"), "長野県", "阿智村", "ﾅｶﾞﾉｹﾝ", "ｱﾁﾑﾗ"),
    "204099": MunicipalityEntry(MunicipalityCode("204099"), "長野県", "平谷村", "ﾅｶﾞﾉｹﾝ", "ﾋﾗﾔﾑﾗ"),
    "204102": MunicipalityEntry(MunicipalityCode("204102"), "長野県", "根羽村", "ﾅｶﾞﾉｹﾝ", "ﾈﾊﾞﾑﾗ"),
    "204111": MunicipalityEntry(MunicipalityCode("204111"), "長野県", "下條村", "ﾅｶﾞﾉｹﾝ", "ｼﾓｼﾞｮｳﾑﾗ"),
    "204129": MunicipalityEntry(MunicipalityCode("204129"), "長野県", "売木村", "ﾅｶﾞﾉｹﾝ", "ｳﾙｷﾞﾑﾗ"),
    "204137": MunicipalityEntry(MunicipalityCode("204137"), "長野県", "天龍村", "ﾅｶﾞﾉｹﾝ", "ﾃﾝﾘｭｳﾑﾗ"),
    "204145": MunicipalityEntry(MunicipalityCode("204145"), "長野県", "泰阜村", "ﾅｶﾞﾉｹﾝ", "ﾔｽｵｶﾑﾗ"),
    "204153": MunicipalityEntry(MunicipalityCode("204153"), "長野県", "喬木村", "ﾅｶﾞﾉｹﾝ", "ﾀｶｷﾞﾑﾗ"),
    "204161": MunicipalityEntry(MunicipalityCode("204161"), "長野県", "豊丘村", "ﾅｶﾞﾉｹﾝ", "ﾄﾖｵｶﾑﾗ"),
    "204170": MunicipalityEntry(MunicipalityCode("204170"), "長野県", "大鹿村", "ﾅｶﾞﾉｹﾝ", "ｵｵｼｶﾑﾗ"),
    "204226": MunicipalityEntry(MunicipalityCode("204226"), "長野県", "上松町", "ﾅｶﾞﾉｹﾝ", "ｱｹﾞﾏﾂﾏﾁ"),
    "204234": MunicipalityEntry(MunicipalityCode("204234"), "長野県", "南木曽町", "ﾅｶﾞﾉｹﾝ", "ﾅｷﾞｿﾏﾁ"),
    "204251": MunicipalityEntry(MunicipalityCode("204251"), "長野県", "木祖村", "ﾅｶﾞﾉｹﾝ", "ｷｿﾑﾗ"),
    "204293": MunicipalityEntry(MunicipalityCode("204293"), "長野県", "王滝村", "ﾅｶﾞﾉｹﾝ", "ｵｳﾀｷﾑﾗ"),
    "204307": MunicipalityEntry(MunicipalityCode("204307"), "長野県", "大桑村", "ﾅｶﾞﾉｹﾝ", "ｵｵｸﾜﾑﾗ"),
    "204323": MunicipalityEntry(MunicipalityCode("204323"), "長野県", "木曽町", "ﾅｶﾞﾉｹﾝ", "ｷｿﾏﾁ"),
    "204463": MunicipalityEntry(MunicipalityCode("204463"), "長野県", "麻績村", "ﾅｶﾞﾉｹﾝ", "ｵﾐﾑﾗ"),
    "204480": MunicipalityEntry(MunicipalityCode("204480"), "長野県", "生坂村", "ﾅｶﾞﾉｹﾝ", "ｲｸｻｶﾑﾗ"),
    "204501": MunicipalityEntry(MunicipalityCode("204501"), "長野県", "山形村", "ﾅｶﾞﾉｹﾝ", "ﾔﾏｶﾞﾀﾑﾗ"),
    "204510": MunicipalityEntry(MunicipalityCode("204510"), "長野県", "朝日村", "ﾅｶﾞﾉｹﾝ", "ｱｻﾋﾑﾗ"),
    "204528": MunicipalityEntry(MunicipalityCode("204528"), "長野県", "筑北村", "ﾅｶﾞﾉｹﾝ", "ﾁｸﾎｸﾑﾗ"),
    "204811": MunicipalityEntry(MunicipalityCode("204811"), "長野県", "池田町", "ﾅｶﾞﾉｹﾝ", "ｲｹﾀﾞﾏﾁ"),
    "204820": MunicipalityEntry(MunicipalityCode("204820"), "長野県", "松川村", "ﾅｶﾞﾉｹﾝ", "ﾏﾂｶﾜﾑﾗ"),
    "204854": MunicipalityEntry(MunicipalityCode("204854"), "長野県", "白馬村", "ﾅｶﾞﾉｹﾝ", "ﾊｸﾊﾞﾑﾗ"),
    "204862": MunicipalityEntry(MunicipalityCode("204862"), "長野県", "小谷村", "ﾅｶﾞﾉｹﾝ", "ｵﾀﾘﾑﾗ"),
    "205214": MunicipalityEntry(MunicipalityCode("205214"), "長野県", "坂城町", "ﾅｶﾞﾉｹﾝ", "ｻｶｷﾏﾁ"),
    "205419": MunicipalityEntry(MunicipalityCode("205419"), "長野県", "小布施町", "ﾅｶﾞﾉｹﾝ", "ｵﾌﾞｾﾏﾁ"),
    "205435": MunicipalityEntry(MunicipalityCode("205435"), "長野県", "高山村", "ﾅｶﾞﾉｹﾝ", "ﾀｶﾔﾏﾑﾗ"),
    "205613": MunicipalityEntry(MunicipalityCode("205613"), "長野県", "山ノ内町", "ﾅｶﾞﾉｹﾝ", "ﾔﾏﾉｳﾁﾏﾁ"),
    "205621": MunicipalityEntry(MunicipalityCode("205621"), "長野県", "木島平村", "ﾅｶﾞﾉｹﾝ", "ｷｼﾞﾏﾀﾞｲﾗﾑﾗ"),
    "205630": MunicipalityEntry(MunicipalityCode("205630"), "長野県", "野沢温泉村", "ﾅｶﾞﾉｹﾝ", "ﾉｻﾞﾜｵﾝｾﾝﾑﾗ"),
    "205834": MunicipalityEntry(MunicipalityCode("205834"), "長野県", "信濃町", "ﾅｶﾞﾉｹﾝ", "ｼﾅﾉﾏﾁ"),
    "205885": MunicipalityEntry(MunicipalityCode("205885"), "長野県", "小川村", "ﾅｶﾞﾉｹﾝ", "ｵｶﾞﾜﾑﾗ"),
    "205907": MunicipalityEntry(MunicipalityCode("205907"), "長野県", "飯綱町", "ﾅｶﾞﾉｹﾝ", "ｲｲﾂﾞﾅﾏﾁ"),
    "206024": MunicipalityEntry(MunicipalityCode("206024"), "長野県", "栄村", "ﾅｶﾞﾉｹﾝ", "ｻｶｴﾑﾗ"),
    "210005": MunicipalityEntry(MunicipalityCode("210005"), "岐阜県", "", "ｷﾞﾌｹﾝ", ""),
    "212016": MunicipalityEntry(MunicipalityCode("212016"), "岐阜県", "岐阜市", "ｷﾞﾌｹﾝ", "ｷﾞﾌｼ"),
    "212024": MunicipalityEntry(MunicipalityCode("212024"), "岐阜県", "大垣市", "ｷﾞﾌｹﾝ", "ｵｵｶﾞｷｼ"),
    "212032": MunicipalityEntry(MunicipalityCode("212032"), "岐阜県", "高山市", "ｷﾞﾌｹﾝ", "ﾀｶﾔﾏｼ"),
    "212041": MunicipalityEntry(MunicipalityCode("212041"), "岐阜県", "多治見市", "ｷﾞﾌｹﾝ", "ﾀｼﾞﾐｼ"),
    "212059": MunicipalityEntry(MunicipalityCode("212059"), "岐阜県", "関市", "ｷﾞﾌｹﾝ", "ｾｷｼ"),
    "212067": MunicipalityEntry(MunicipalityCode("212067"), "岐阜県", "中津川市", "ｷﾞﾌｹﾝ", "ﾅｶﾂｶﾞﾜｼ"),
    "212075": MunicipalityEntry(MunicipalityCode("212075"), "岐阜県", "美濃市", "ｷﾞﾌｹﾝ", "ﾐﾉｼ"),
    "212083": MunicipalityEntry(MunicipalityCode("212083"), "岐阜県", "瑞浪市", "ｷﾞﾌｹﾝ", "ﾐｽﾞﾅﾐｼ"),
    "212091": MunicipalityEntry(MunicipalityCode("212091"), "岐阜県", "羽島市", "ｷﾞﾌｹﾝ", "ﾊｼﾏｼ"),
    "212105": MunicipalityEntry(MunicipalityCode("212105"), "岐阜県", "恵那市", "ｷﾞﾌｹﾝ", "ｴﾅｼ"),
    "212113": MunicipalityEntry(MunicipalityCode("212113"), "岐阜県", "美濃加茂市", "ｷﾞﾌｹﾝ", "ﾐﾉｶﾓｼ"),
    "212121": MunicipalityEntry(MunicipalityCode("212121"), "岐阜県", "土岐市", "ｷﾞﾌｹﾝ", "ﾄｷｼ"),
    "212130": MunicipalityEntry(MunicipalityCode("212130"), "岐阜県", "各務原市", "ｷﾞﾌｹﾝ", "ｶｶﾐｶﾞﾊﾗｼ"),
    "212148": MunicipalityEntry(MunicipalityCode("212148"), "岐阜県", "可児市", "ｷﾞﾌｹﾝ", "ｶﾆｼ"),
    "212156": MunicipalityEntry(MunicipalityCode("212156"), "岐阜県", "山県市", "ｷﾞﾌｹﾝ", "ﾔﾏｶﾞﾀｼ"),
    "212164": MunicipalityEntry(MunicipalityCode("212164"), "岐阜県", "瑞穂市", "ｷﾞﾌｹﾝ", "ﾐｽﾞﾎｼ"),
    "212172": MunicipalityEntry(MunicipalityCode("212172"), "岐阜県", "飛騨市", "ｷﾞﾌｹﾝ", "ﾋﾀﾞｼ"),
    "212181": MunicipalityEntry(MunicipalityCode("212181"), "岐阜県", "本巣市", "ｷﾞﾌｹﾝ", "ﾓﾄｽｼ"),
    "212199": MunicipalityEntry(MunicipalityCode("212199"), "岐阜県", "郡上市", "ｷﾞﾌｹﾝ", "ｸﾞｼﾞｮｳｼ"),
    "212202": MunicipalityEntry(MunicipalityCode("212202"), "岐阜県", "下呂市", "ｷﾞﾌｹﾝ", "ｹﾞﾛｼ"),
    "212211": MunicipalityEntry(MunicipalityCode("212211"), "岐阜県", "海津市", "ｷﾞﾌｹﾝ", "ｶｲﾂﾞｼ"),
    "213021": MunicipalityEntry(MunicipalityCode("213021"), "岐阜県", "岐南町", "ｷﾞﾌｹﾝ", "ｷﾞﾅﾝﾁｮｳ"),
    "213039": MunicipalityEntry(MunicipalityCode("213039"), "岐阜県", "笠松町", "ｷﾞﾌｹﾝ", "ｶｻﾏﾂﾁｮｳ"),
    "213411": MunicipalityEntry(MunicipalityCode("213411"), "岐阜県", "養老町", "ｷﾞﾌｹﾝ", "ﾖｳﾛｳﾁｮｳ"),
    "213616": MunicipalityEntry(MunicipalityCode("213616"), "岐阜県", "垂井町", "ｷﾞﾌｹﾝ", "ﾀﾙｲﾁｮｳ"),
    "213624": MunicipalityEntry(MunicipalityCode("213624"), "岐阜県", "関ケ原町", "ｷﾞﾌｹﾝ", "ｾｷｶﾞﾊﾗﾁｮｳ"),
    "213811": MunicipalityEntry(MunicipalityCode("213811"), "岐阜県", "神戸町", "ｷﾞﾌｹﾝ", "ｺﾞｳﾄﾞﾁｮｳ"),
    "213829": MunicipalityEntry(MunicipalityCode("213829"), "岐阜県", "輪之内町", "ｷﾞﾌｹﾝ", "ﾜﾉｳﾁﾁｮｳ"),
    "213837": MunicipalityEntry(MunicipalityCode("213837"), "岐阜県", "安八町", "ｷﾞﾌｹﾝ", "ｱﾝﾊﾟﾁﾁｮｳ"),
    "214019": MunicipalityEntry(MunicipalityCode("214019"), "岐阜県", "揖斐川町", "ｷﾞﾌｹﾝ", "ｲﾋﾞｶﾞﾜﾁｮｳ"),
    "214035": MunicipalityEntry(MunicipalityCode("214035"), "岐阜県", "大野町", "ｷﾞﾌｹﾝ", "ｵｵﾉﾁｮｳ"),
    "214043": MunicipalityEntry(MunicipalityCode("214043"), "岐阜県", "池田町", "ｷﾞﾌｹﾝ", "ｲｹﾀﾞﾁｮｳ"),
    "214213": MunicipalityEntry(MunicipalityCode("214213"), "岐阜県", "北方町", "ｷﾞﾌｹﾝ", "ｷﾀｶﾞﾀﾁｮｳ"),
    "215015": MunicipalityEntry(MunicipalityCode("215015"), "岐阜県", "坂祝町", "ｷﾞﾌｹﾝ", "ｻｶﾎｷﾞﾁｮｳ"),
    "215023": MunicipalityEntry(MunicipalityCode("215023"), "岐阜県", "富加町", "ｷﾞﾌｹﾝ", "ﾄﾐｶﾁｮｳ"),
    "215031": MunicipalityEntry(MunicipalityCode("215031"), "岐阜県", "川辺町", "ｷﾞﾌｹﾝ", "ｶﾜﾍﾞﾁｮｳ"),
    "215040": MunicipalityEntry(MunicipalityCode("215040"), "岐阜県", "七宗町", "ｷﾞﾌｹﾝ", "ﾋﾁｿｳﾁｮｳ"),
    "215058": MunicipalityEntry(MunicipalityCode("215058"), "岐阜県", "八百津町", "ｷﾞﾌｹﾝ", "ﾔｵﾂﾁｮｳ"),
    "215066": MunicipalityEntry(MunicipalityCode("215066"), "岐阜県", "白川町", "ｷﾞﾌｹﾝ", "ｼﾗｶﾜﾁｮｳ"),
    "215074": MunicipalityEntry(MunicipalityCode("215074"), "岐阜県", "東白川村", "ｷﾞﾌｹﾝ", "ﾋｶﾞｼｼﾗｶﾜﾑﾗ"),
    "215210": MunicipalityEntry(MunicipalityCode("215210"), "岐阜県", "御嵩町", "ｷﾞﾌｹﾝ", "ﾐﾀｹﾁｮｳ"),
    "216046": MunicipalityEntry(MunicipalityCode("216046"), "岐阜県", "白川村", "ｷﾞﾌｹﾝ", "ｼﾗｶﾜﾑﾗ"),
    "220001": MunicipalityEntry(MunicipalityCode("220001"), "静岡県", "", "ｼｽﾞｵｶｹﾝ", ""),
    "221007": MunicipalityEntry(MunicipalityCode("221007"), "静岡県", "静岡市", "ｼｽﾞｵｶｹﾝ", "ｼｽﾞｵｶｼ"),
    "221309": MunicipalityEntry(MunicipalityCode("221309"), "静岡県", "浜松市", "ｼｽﾞｵｶｹﾝ", "ﾊﾏﾏﾂｼ"),
    "222038": MunicipalityEntry(MunicipalityCode("222038"), "静岡県", "沼津市", "ｼｽﾞｵｶｹﾝ", "ﾇﾏﾂﾞｼ"),
    "222054": MunicipalityEntry(MunicipalityCode("222054"), "静岡県", "熱海市", "ｼｽﾞｵｶｹﾝ", "ｱﾀﾐｼ"),
    "222062": MunicipalityEntry(MunicipalityCode("222062"), "静岡県", "三島市", "ｼｽﾞｵｶｹﾝ", "ﾐｼﾏｼ"),
    "222071": MunicipalityEntry(MunicipalityCode("222071"), "静岡県", "富士宮市", "ｼｽﾞｵｶｹﾝ", "ﾌｼﾞﾉﾐﾔｼ"),
    "222089": MunicipalityEntry(MunicipalityCode("222089"), "静岡県", "伊東市", "ｼｽﾞｵｶｹﾝ", "ｲﾄｳｼ"),
    "222097": MunicipalityEntry(MunicipalityCode("222097"), "静岡県", "島田市", "ｼｽﾞｵｶｹﾝ", "ｼﾏﾀﾞｼ"),
    "222101": MunicipalityEntry(MunicipalityCode("222101"), "静岡県", "富士市", "ｼｽﾞｵｶｹﾝ", "ﾌｼﾞｼ"),
    "222119": MunicipalityEntry(MunicipalityCode("222119"), "静岡県", "磐田市", "ｼｽﾞｵｶｹﾝ", "ｲﾜﾀｼ"),
    "222127": MunicipalityEntry(MunicipalityCode("222127"), "静岡県", "焼津市", "ｼｽﾞｵｶｹﾝ", "ﾔｲﾂﾞｼ"),
    "222135": MunicipalityEntry(MunicipalityCode("222135"), "静岡県", "掛川市", "ｼｽﾞｵｶｹﾝ", "ｶｹｶﾞﾜｼ"),
    "222143": MunicipalityEntry(MunicipalityCode("222143"), "静岡県", "藤枝市", "ｼｽﾞｵｶｹﾝ", "ﾌｼﾞｴﾀﾞｼ"),
    "222151": MunicipalityEntry(MunicipalityCode("222151"), "静岡県", "御殿場市", "ｼｽﾞｵｶｹﾝ", "ｺﾞﾃﾝﾊﾞｼ"),
    "222160": MunicipalityEntry(MunicipalityCode("222160"), "静岡県", "袋井市", "ｼｽﾞｵｶｹﾝ", "ﾌｸﾛｲｼ"),
    "222194": MunicipalityEntry(MunicipalityCode("222194"), "静岡県", "下田市", "ｼｽﾞｵｶｹﾝ", "ｼﾓﾀﾞｼ"),
    "222208": MunicipalityEntry(MunicipalityCode("222208"), "静岡県", "裾野市", "ｼｽﾞｵｶｹﾝ", "ｽｿﾉｼ"),
    "222216": MunicipalityEntry(MunicipalityCode("222216"), "静岡県", "湖西市", "ｼｽﾞｵｶｹﾝ", "ｺｻｲｼ"),
    "222224": MunicipalityEntry(MunicipalityCode("222224"), "静岡県", "伊豆市", "ｼｽﾞｵｶｹﾝ", "ｲｽﾞｼ"),
    "222232": MunicipalityEntry(MunicipalityCode("222232"), "静岡県", "御前崎市", "ｼｽﾞｵｶｹﾝ", "ｵﾏｴｻﾞｷｼ"),
    "222241": MunicipalityEntry(MunicipalityCode("222241"), "静岡県", "菊川市", "ｼｽﾞｵｶｹﾝ", "ｷｸｶﾞﾜｼ"),
    "222259": MunicipalityEntry(MunicipalityCode("222259"), "静岡県", "伊豆の国市", "ｼｽﾞｵｶｹﾝ", "ｲｽﾞﾉｸﾆｼ"),
    "222267": MunicipalityEntry(MunicipalityCode("222267"), "静岡県", "牧之原市", "ｼｽﾞｵｶｹﾝ", "ﾏｷﾉﾊﾗｼ"),
    "223018": MunicipalityEntry(MunicipalityCode("223018"), "静岡県", "東伊豆町", "ｼｽﾞｵｶｹﾝ", "ﾋｶﾞｼｲｽﾞﾁｮｳ"),
    "223026": MunicipalityEntry(MunicipalityCode("223026"), "静岡県", "河津町", "ｼｽﾞｵｶｹﾝ", "ｶﾜﾂﾞﾁｮｳ"),
    "223042": MunicipalityEntry(MunicipalityCode("223042"), "静岡県", "南伊豆町", "ｼｽﾞｵｶｹﾝ", "ﾐﾅﾐｲｽﾞﾁｮｳ"),
    "223051": MunicipalityEntry(MunicipalityCode("223051"), "静岡県", "松崎町", "ｼｽﾞｵｶｹﾝ", "ﾏﾂｻﾞｷﾁｮｳ"),
    "223069": MunicipalityEntry(MunicipalityCode("223069"), "静岡県", "西伊豆町", "ｼｽﾞｵｶｹﾝ", "ﾆｼｲｽﾞﾁｮｳ"),
    "223255": MunicipalityEntry(MunicipalityCode("223255"), "静岡県", "函南町", "ｼｽﾞｵｶｹﾝ", "ｶﾝﾅﾐﾁｮｳ"),
    "223417": MunicipalityEntry(MunicipalityCode("223417"), "静岡県", "清水町", "ｼｽﾞｵｶｹﾝ", "ｼﾐｽﾞﾁｮｳ"),
    "223425": MunicipalityEntry(MunicipalityCode("223425"), "静岡県", "長泉町", "ｼｽﾞｵｶｹﾝ", "ﾅｶﾞｲｽﾞﾐﾁｮｳ"),
    "223441": MunicipalityEntry(MunicipalityCode("223441"), "静岡県", "小山町", "ｼｽﾞｵｶｹﾝ", "ｵﾔﾏﾁｮｳ"),
    "224243": MunicipalityEntry(MunicipalityCode("224243"), "静岡県", "吉田町", "ｼｽﾞｵｶｹﾝ", "ﾖｼﾀﾞﾁｮｳ"),
    "224294": MunicipalityEntry(MunicipalityCode("224294"), "静岡県", "川根本町", "ｼｽﾞｵｶｹﾝ", "ｶﾜﾈﾎﾝﾁｮｳ"),
    "224618": MunicipalityEntry(MunicipalityCode("224618"), "静岡県", "森町", "ｼｽﾞｵｶｹﾝ", "ﾓﾘﾏﾁ"),
    "230006": MunicipalityEntry(MunicipalityCode("230006"), "愛知県", "", "ｱｲﾁｹﾝ", ""),
    "231002": MunicipalityEntry(MunicipalityCode("231002"), "愛知県", "名古屋市", "ｱｲﾁｹﾝ", "ﾅｺﾞﾔｼ"),
    "232017": MunicipalityEntry(MunicipalityCode("232017"), "愛知県", "豊橋市", "ｱｲﾁｹﾝ", "ﾄﾖﾊｼｼ"),
    "232025": MunicipalityEntry(MunicipalityCode("232025"), "愛知県", "岡崎市", "ｱｲﾁｹﾝ", "ｵｶｻﾞｷｼ"),
    "232033": MunicipalityEntry(MunicipalityCode("232033"), "愛知県", "一宮市", "ｱｲﾁｹﾝ", "ｲﾁﾉﾐﾔｼ"),
    "232041": MunicipalityEntry(MunicipalityCode("232041"), "愛知県", "瀬戸市", "ｱｲﾁｹﾝ", "ｾﾄｼ"),
    "232050": MunicipalityEntry(MunicipalityCode("232050"), "愛知県", "半田市", "ｱｲﾁｹﾝ", "ﾊﾝﾀﾞｼ"),
    "232068": MunicipalityEntry(MunicipalityCode("232068"), "愛知県", "春日井市", "ｱｲﾁｹﾝ", "ｶｽｶﾞｲｼ"),
    "232076": MunicipalityEntry(MunicipalityCode("232076"), "愛知県", "豊川市", "ｱｲﾁｹﾝ", "ﾄﾖｶﾜｼ"),
    "232084": MunicipalityEntry(MunicipalityCode("232084"), "愛知県", "津島市", "ｱｲﾁｹﾝ", "ﾂｼﾏｼ"),
    "232092": MunicipalityEntry(MunicipalityCode("232092"), "愛知県", "碧南市", "ｱｲﾁｹﾝ", "ﾍｷﾅﾝｼ"),
    "232106": MunicipalityEntry(MunicipalityCode("232106"), "愛知県", "刈谷市", "ｱｲﾁｹﾝ", "ｶﾘﾔｼ"),
    "232114": MunicipalityEntry(MunicipalityCode("232114"), "愛知県", "豊田市", "ｱｲﾁｹﾝ", "ﾄﾖﾀｼ"),
    "232122": MunicipalityEntry(MunicipalityCode("232122"), "愛知県", "安城市", "ｱｲﾁｹﾝ", "ｱﾝｼﾞｮｳｼ"),
    "232131": MunicipalityEntry(MunicipalityCode("232131"), "愛知県", "西尾市", "ｱｲﾁｹﾝ", "ﾆｼｵｼ"),
    "232149": MunicipalityEntry(MunicipalityCode("232149"), "愛知県", "蒲郡市", "ｱｲﾁｹﾝ", "ｶﾞﾏｺﾞｵﾘｼ"),
    "232157": MunicipalityEntry(MunicipalityCode("232157"), "愛知県", "犬山市", "ｱｲﾁｹﾝ", "ｲﾇﾔﾏｼ"),
    "232165": MunicipalityEntry(MunicipalityCode("232165"), "愛知県", "常滑市", "ｱｲﾁｹﾝ", "ﾄｺﾅﾒｼ"),
    "232173": MunicipalityEntry(MunicipalityCode("232173"), "愛知県", "江南市", "ｱｲﾁｹﾝ", "ｺｳﾅﾝｼ"),
    "232190": MunicipalityEntry(MunicipalityCode("232190"), "愛知県", "小牧市", "ｱｲﾁｹﾝ", "ｺﾏｷｼ"),
    "232203": MunicipalityEntry(MunicipalityCode("232203"), "愛知県", "稲沢市", "ｱｲﾁｹﾝ", "ｲﾅｻﾞﾜｼ"),
    "232211": MunicipalityEntry(MunicipalityCode("232211"), "愛知県", "新城市", "ｱｲﾁｹﾝ", "ｼﾝｼﾛｼ"),
    "232220": MunicipalityEntry(MunicipalityCode("232220"), "愛知県", "東海市", "ｱｲﾁｹﾝ", "ﾄｳｶｲｼ"),
    "232238": MunicipalityEntry(MunicipalityCode("232238"), "愛知県", "大府市", "ｱｲﾁｹﾝ", "ｵｵﾌﾞｼ"),
    "232246": MunicipalityEntry(MunicipalityCode("232246"), "愛知県", "知多市", "ｱｲﾁｹﾝ", "ﾁﾀｼ"),
    "232254": MunicipalityEntry(MunicipalityCode("232254"), "愛知県", "知立市", "ｱｲﾁｹﾝ", "ﾁﾘｭｳｼ"),
    "232262": MunicipalityEntry(MunicipalityCode("232262"), "愛知県", "尾張旭市", "ｱｲﾁｹﾝ", "ｵﾜﾘｱｻﾋｼ"),
    "232271": MunicipalityEntry(MunicipalityCode("232271"), "愛知県", "高浜市", "ｱｲﾁｹﾝ", "ﾀｶﾊﾏｼ"),
    "232289": MunicipalityEntry(MunicipalityCode("232289"), "愛知県", "岩倉市", "ｱｲﾁｹﾝ", "ｲﾜｸﾗｼ"),
    "232297": MunicipalityEntry(MunicipalityCode("232297"), "愛知県", "豊明市", "ｱｲﾁｹﾝ", "ﾄﾖｱｹｼ"),
    "232301": MunicipalityEntry(MunicipalityCode("232301"), "愛知県", "日進市", "ｱｲﾁｹﾝ", "ﾆｯｼﾝｼ"),
    "232319": MunicipalityEntry(MunicipalityCode("232319"), "愛知県", "田原市", "ｱｲﾁｹﾝ", "ﾀﾊﾗｼ"),
    "232327": MunicipalityEntry(MunicipalityCode("232327"), "愛知県", "愛西市", "ｱｲﾁｹﾝ", "ｱｲｻｲｼ"),
    "232335": MunicipalityEntry(MunicipalityCode("232335"), "愛知県", "清須市", "ｱｲﾁｹﾝ", "ｷﾖｽｼ"),
    "232343": MunicipalityEntry(MunicipalityCode("232343"), "愛知県", "北名古屋市", "ｱｲﾁｹﾝ", "ｷﾀﾅｺﾞﾔｼ"),
    "232351": MunicipalityEntry(MunicipalityCode("232351"), "愛知県", "弥富市", "ｱｲﾁｹﾝ", "ﾔﾄﾐｼ"),
    "232360": MunicipalityEntry(MunicipalityCode("232360"), "愛知県", "みよし市", "ｱｲﾁｹﾝ", "ﾐﾖｼｼ"),
    "232378": MunicipalityEntry(MunicipalityCode("232378"), "愛知県", "あま市", "ｱｲﾁｹﾝ", "ｱﾏｼ"),
    "232386": MunicipalityEntry(MunicipalityCode("232386"), "愛知県", "長久手市", "ｱｲﾁｹﾝ", "ﾅｶﾞｸﾃｼ"),
    "233021": MunicipalityEntry(MunicipalityCode("233021"), "愛知県", "東郷町", "ｱｲﾁｹﾝ", "ﾄｳｺﾞｳﾁｮｳ"),
    "233421": MunicipalityEntry(MunicipalityCode("233421"), "愛知県", "豊山町", "ｱｲﾁｹﾝ", "ﾄﾖﾔﾏﾁｮｳ"),
    "233617": MunicipalityEntry(MunicipalityCode("233617"), "愛知県", "大口町", "ｱｲﾁｹﾝ", "ｵｵｸﾞﾁﾁｮｳ"),
    "233625": MunicipalityEntry(MunicipalityCode("233625"), "愛知県", "扶桑町", "ｱｲﾁｹﾝ", "ﾌｿｳﾁｮｳ"),
    "234249": MunicipalityEntry(MunicipalityCode("234249"), "愛知県", "大治町", "ｱｲﾁｹﾝ", "ｵｵﾊﾙﾁｮｳ"),
    "234257": MunicipalityEntry(MunicipalityCode("234257"), "愛知県", "蟹江町", "ｱｲﾁｹﾝ", "ｶﾆｴﾁｮｳ"),
    "234273": MunicipalityEntry(MunicipalityCode("234273"), "愛知県", "飛島村", "ｱｲﾁｹﾝ", "ﾄﾋﾞｼﾏﾑﾗ"),
    "234419": MunicipalityEntry(MunicipalityCode("234419"), "愛知県", "阿久比町", "ｱｲﾁｹﾝ", "ｱｸﾞｲﾁｮｳ"),
    "234427": MunicipalityEntry(MunicipalityCode("234427"), "愛知県", "東浦町", "ｱｲﾁｹﾝ", "ﾋｶﾞｼｳﾗﾁｮｳ"),
    "234451": MunicipalityEntry(MunicipalityCode("234451"), "愛知県", "南知多町", "ｱｲﾁｹﾝ", "ﾐﾅﾐﾁﾀﾁｮｳ"),
    "234460": MunicipalityEntry(MunicipalityCode("234460"), "愛知県", "美浜町", "ｱｲﾁｹﾝ", "ﾐﾊﾏﾁｮｳ"),
    "234478": MunicipalityEntry(MunicipalityCode("234478"), "愛知県", "武豊町", "ｱｲﾁｹﾝ", "ﾀｹﾄﾖﾁｮｳ"),
    "235016": MunicipalityEntry(MunicipalityCode("235016"), "愛知県", "幸田町", "ｱｲﾁｹﾝ", "ｺｳﾀﾁｮｳ"),
    "235610": MunicipalityEntry(MunicipalityCode("235610"), "愛知県", "設楽町", "ｱｲﾁｹﾝ", "ｼﾀﾗﾁｮｳ"),
    "235628": MunicipalityEntry(MunicipalityCode("235628"), "愛知県", "東栄町", "ｱｲﾁｹﾝ", "ﾄｳｴｲﾁｮｳ"),
    "235636": MunicipalityEntry(MunicipalityCode("235636"), "愛知県", "豊根村", "ｱｲﾁｹﾝ", "ﾄﾖﾈﾑﾗ"),
    "240001": MunicipalityEntry(MunicipalityCode("240001"), "三重県", "", "ﾐｴｹﾝ", ""),
    "242012": MunicipalityEntry(MunicipalityCode("242012"), "三重県", "津市", "ﾐｴｹﾝ", "ﾂｼ"),
    "242021": MunicipalityEntry(MunicipalityCode("242021"), "三重県", "四日市市", "ﾐｴｹﾝ", "ﾖｯｶｲﾁｼ"),
    "242039": MunicipalityEntry(MunicipalityCode("242039"), "三重県", "伊勢市", "ﾐｴｹﾝ", "ｲｾｼ"),
    "242047": MunicipalityEntry(MunicipalityCode("242047"), "三重県", "松阪市", "ﾐｴｹﾝ", "ﾏﾂｻｶｼ"),
    "242055": MunicipalityEntry(MunicipalityCode("242055"), "三重県", "桑名市", "ﾐｴｹﾝ", "ｸﾜﾅｼ"),
    "242071": MunicipalityEntry(MunicipalityCode("242071"), "三重県", "鈴鹿市", "ﾐｴｹﾝ", "ｽｽﾞｶｼ"),
    "242080": MunicipalityEntry(MunicipalityCode("242080"), "三重県", "名張市", "ﾐｴｹﾝ", "ﾅﾊﾞﾘｼ"),
    "242098": MunicipalityEntry(MunicipalityCode("242098"), "三重県", "尾鷲市", "ﾐｴｹﾝ", "ｵﾜｾｼ"),
    "242101": MunicipalityEntry(MunicipalityCode("242101"), "三重県", "亀山市", "ﾐｴｹﾝ", "ｶﾒﾔﾏｼ"),
    "242110": MunicipalityEntry(MunicipalityCode("242110"), "三重県", "鳥羽市", "ﾐｴｹﾝ", "ﾄﾊﾞｼ"),
    "242128": MunicipalityEntry(MunicipalityCode("242128"), "三重県", "熊野市", "ﾐｴｹﾝ", "ｸﾏﾉｼ"),
    "242144": MunicipalityEntry(MunicipalityCode("242144"), "三重県", "いなべ市", "ﾐｴｹﾝ", "ｲﾅﾍﾞｼ"),
    "242152": MunicipalityEntry(MunicipalityCode("242152"), "三重県", "志摩市", "ﾐｴｹﾝ", "ｼﾏｼ"),
    "242161": MunicipalityEntry(MunicipalityCode("242161"), "三重県", "伊賀市", "ﾐｴｹﾝ", "ｲｶﾞｼ"),
    "243035": MunicipalityEntry(MunicipalityCode("243035"), "三重県", "木曽岬町", "ﾐｴｹﾝ", "ｷｿｻｷﾁｮｳ"),
    "243248": MunicipalityEntry(MunicipalityCode("243248"), "三重県", "東員町", "ﾐｴｹﾝ", "ﾄｳｲﾝﾁｮｳ"),
    "243418": MunicipalityEntry(MunicipalityCode("243418"), "三重県", "菰野町", "ﾐｴｹﾝ", "ｺﾓﾉﾁｮｳ"),
    "243434": MunicipalityEntry(MunicipalityCode("243434"), "三重県", "朝日町", "ﾐｴｹﾝ", "ｱｻﾋﾁｮｳ"),
    "243442": MunicipalityEntry(MunicipalityCode("243442"), "三重県", "川越町", "ﾐｴｹﾝ", "ｶﾜｺﾞｴﾁｮｳ"),
    "244414": MunicipalityEntry(MunicipalityCode("244414"), "三重県", "多気町", "ﾐｴｹﾝ", "ﾀｷﾁｮｳ"),
    "244422": MunicipalityEntry(MunicipalityCode("244422"), "三重県", "明和町", "ﾐｴｹﾝ", "ﾒｲﾜﾁｮｳ"),
    "244431": MunicipalityEntry(MunicipalityCode("244431"), "三重県", "大台町", "ﾐｴｹﾝ", "ｵｵﾀﾞｲﾁｮｳ"),
    "244619": MunicipalityEntry(MunicipalityCode("244619"), "三重県", "玉城町", "ﾐｴｹﾝ", "ﾀﾏｷﾁｮｳ"),
    "244708": MunicipalityEntry(MunicipalityCode("244708"), "三重県", "度会町", "ﾐｴｹﾝ", "ﾜﾀﾗｲﾁｮｳ"),
    "244716": MunicipalityEntry(MunicipalityCode("244716"), "三重県", "大紀町", "ﾐｴｹﾝ", "ﾀｲｷﾁｮｳ"),
    "244724": MunicipalityEntry(MunicipalityCode("244724"), "三重県", "南伊勢町", "ﾐｴｹﾝ", "ﾐﾅﾐｲｾﾁｮｳ"),
    "245437": MunicipalityEntry(MunicipalityCode("245437"), "三重県", "紀北町", "ﾐｴｹﾝ", "ｷﾎｸﾁｮｳ"),
    "245615": MunicipalityEntry(MunicipalityCode("245615"), "三重県", "御浜町", "ﾐｴｹﾝ", "ﾐﾊﾏﾁｮｳ"),
    "245623": MunicipalityEntry(MunicipalityCode("245623"), "三重県", "紀宝町", "ﾐｴｹﾝ", "ｷﾎｳﾁｮｳ"),
    "250007": MunicipalityEntry(MunicipalityCode("250007"), "滋賀県", "", "ｼｶﾞｹﾝ", ""),
    "252018": MunicipalityEntry(MunicipalityCode("252018"), "滋賀県", "大津市", "ｼｶﾞｹﾝ", "ｵｵﾂｼ"),
    "252026": MunicipalityEntry(MunicipalityCode("252026"), "滋賀県", "彦根市", "ｼｶﾞｹﾝ", "ﾋｺﾈｼ"),
    "252034": MunicipalityEntry(MunicipalityCode("252034"), "滋賀県", "長浜市", "ｼｶﾞｹﾝ", "ﾅｶﾞﾊﾏｼ"),
    "252042": MunicipalityEntry(MunicipalityCode("252042"), "滋賀県", "近江八幡市", "ｼｶﾞｹﾝ", "ｵｳﾐﾊﾁﾏﾝｼ"),
    "252069": MunicipalityEntry(MunicipalityCode("252069"), "滋賀県", "草津市", "ｼｶﾞｹﾝ", "ｸｻﾂｼ"),
    "252077": MunicipalityEntry(MunicipalityCode("252077"), "滋賀県", "守山市", "ｼｶﾞｹﾝ", "ﾓﾘﾔﾏｼ"),
    "252085": MunicipalityEntry(MunicipalityCode("252085"), "滋賀県", "栗東市", "ｼｶﾞｹﾝ", "ﾘｯﾄｳｼ"),
    "252093": MunicipalityEntry(MunicipalityCode("252093"), "滋賀県", "甲賀市", "ｼｶﾞｹﾝ", "ｺｳｶｼ"),
    "252107": MunicipalityEntry(MunicipalityCode("252107"), "滋賀県", "野洲市", "ｼｶﾞｹﾝ", "ﾔｽｼ"),
    "252115": MunicipalityEntry(MunicipalityCode("252115"), "滋賀県", "湖南市", "ｼｶﾞｹﾝ", "ｺﾅﾝｼ"),
    "252123": MunicipalityEntry(MunicipalityCode("252123"), "滋賀県", "高島市", "ｼｶﾞｹﾝ", "ﾀｶｼﾏｼ"),
    "252131": MunicipalityEntry(MunicipalityCode("252131"), "滋賀県", "東近江市", "ｼｶﾞｹﾝ", "ﾋｶﾞｼｵｳﾐｼ"),
    "252140": MunicipalityEntry(MunicipalityCode("252140"), "滋賀県", "米原市", "ｼｶﾞｹﾝ", "ﾏｲﾊﾞﾗｼ"),
    "253839": MunicipalityEntry(MunicipalityCode("253839"), "滋賀県", "日野町", "ｼｶﾞｹﾝ", "ﾋﾉﾁｮｳ"),
    "253847": MunicipalityEntry(MunicipalityCode("253847"), "滋賀県", "竜王町", "ｼｶﾞｹﾝ", "ﾘﾕｳｵｳﾁｮｳ"),
    "254258": MunicipalityEntry(MunicipalityCode("254258"), "滋賀県", "愛荘町", "ｼｶﾞｹﾝ", "ｱｲｼｮｳﾁｮｳ"),
    "254410": MunicipalityEntry(MunicipalityCode("254410"), "滋賀県", "豊郷町", "ｼｶﾞｹﾝ", "ﾄﾖｻﾄﾁｮｳ"),
    "254428": MunicipalityEntry(MunicipalityCode("254428"), "滋賀県", "甲良町", "ｼｶﾞｹﾝ", "ｺｳﾗﾁｮｳ"),
    "254436": MunicipalityEntry(MunicipalityCode("254436"), "滋賀県", "多賀町", "ｼｶﾞｹﾝ", "ﾀｶﾞﾁｮｳ"),
    "260002": MunicipalityEntry(MunicipalityCode("260002"), "京都府", "", "ｷｮｳﾄﾌ", ""),
    "261009": MunicipalityEntry(MunicipalityCode("261009"), "京都府", "京都市", "ｷｮｳﾄﾌ", "ｷｮｳﾄｼ"),
    "262013": MunicipalityEntry(MunicipalityCode("262013"), "京都府", "福知山市", "ｷｮｳﾄﾌ", "ﾌｸﾁﾔﾏｼ"),
    "262021": MunicipalityEntry(MunicipalityCode("262021"), "京都府", "舞鶴市", "ｷｮｳﾄﾌ", "ﾏｲﾂﾞﾙｼ"),
    "262030": MunicipalityEntry(MunicipalityCode("262030"), "京都府", "綾部市", "ｷｮｳﾄﾌ", "ｱﾔﾍﾞｼ"),
    "262048": MunicipalityEntry(MunicipalityCode("262048"), "京都府", "宇治市", "ｷｮｳﾄﾌ", "ｳｼﾞｼ"),
    "262056": MunicipalityEntry(MunicipalityCode("262056"), "京都府", "宮津市", "ｷｮｳﾄﾌ", "ﾐﾔﾂﾞｼ"),
    "262064": MunicipalityEntry(MunicipalityCode("262064"), "京都府", "亀岡市", "ｷｮｳﾄﾌ", "ｶﾒｵｶｼ"),
    "262072": MunicipalityEntry(MunicipalityCode("262072"), "京都府", "城陽市", "ｷｮｳﾄﾌ", "ｼﾞｮｳﾖｳｼ"),
    "262081": MunicipalityEntry(MunicipalityCode("262081"), "京都府", "向日市", "ｷｮｳﾄﾌ", "ﾑｺｳｼ"),
    "262099": MunicipalityEntry(MunicipalityCode("262099"), "京都府", "長岡京市", "ｷｮｳﾄﾌ", "ﾅｶﾞｵｶｷｮｳｼ"),
    "262102": MunicipalityEntry(MunicipalityCode("262102"), "京都府", "八幡市", "ｷｮｳﾄﾌ", "ﾔﾜﾀｼ"),
    "262111": MunicipalityEntry(MunicipalityCode("262111"), "京都府", "京田辺市", "ｷｮｳﾄﾌ", "ｷｮｳﾀﾅﾍﾞｼ"),
    "262129": MunicipalityEntry(MunicipalityCode("262129"), "京都府", "京丹後市", "ｷｮｳﾄﾌ", "ｷｮｳﾀﾝｺﾞｼ"),
    "262137": MunicipalityEntry(MunicipalityCode("262137"), "京都府", "南丹市", "ｷｮｳﾄﾌ", "ﾅﾝﾀﾝｼ"),
    "262145": MunicipalityEntry(MunicipalityCode("262145"), "京都府", "木津川市", "ｷｮｳﾄﾌ", "ｷﾂﾞｶﾞﾜｼ"),
    "263036": MunicipalityEntry(MunicipalityCode("263036"), "京都府", "大山崎町", "ｷｮｳﾄﾌ", "ｵｵﾔﾏｻﾞｷﾁｮｳ"),
    "263222": MunicipalityEntry(MunicipalityCode("263222"), "京都府", "久御山町", "ｷｮｳﾄﾌ", "ｸﾐﾔﾏﾁｮｳ"),
    "263435": MunicipalityEntry(MunicipalityCode("263435"), "京都府", "井手町", "ｷｮｳﾄﾌ", "ｲﾃﾞﾁｮｳ"),
    "263443": MunicipalityEntry(MunicipalityCode("263443"), "京都府", "宇治田原町", "ｷｮｳﾄﾌ", "ｳｼﾞﾀﾜﾗﾁｮｳ"),
    "263648": MunicipalityEntry(MunicipalityCode("263648"), "京都府", "笠置町", "ｷｮｳﾄﾌ", "ｶｻｷﾞﾁｮｳ"),
    "263656": MunicipalityEntry(MunicipalityCode("263656"), "京都府", "和束町", "ｷｮｳﾄﾌ", "ﾜﾂﾞｶﾁｮｳ"),
    "263664": MunicipalityEntry(MunicipalityCode("263664"), "京都府", "精華町", "ｷｮｳﾄﾌ", "ｾｲｶﾁｮｳ"),
    "263672": MunicipalityEntry(MunicipalityCode("263672"), "京都府", "南山城村", "ｷｮｳﾄﾌ", "ﾐﾅﾐﾔﾏｼﾛﾑﾗ"),
    "264075": MunicipalityEntry(MunicipalityCode("264075"), "京都府", "京丹波町", "ｷｮｳﾄﾌ", "ｷｮｳﾀﾝﾊﾞﾁｮｳ"),
    "264636": MunicipalityEntry(MunicipalityCode("264636"), "京都府", "伊根町", "ｷｮｳﾄﾌ", "ｲﾈﾁｮｳ"),
    "264652": MunicipalityEntry(MunicipalityCode("264652"), "京都府", "与謝野町", "ｷｮｳﾄﾌ", "ﾖｻﾉﾁｮｳ"),
    "270008": MunicipalityEntry(MunicipalityCode("270008"), "大阪府", "", "ｵｵｻｶﾌ", ""),
    "271004": MunicipalityEntry(MunicipalityCode("271004"), "大阪府", "大阪市", "ｵｵｻｶﾌ", "ｵｵｻｶｼ"),
    "271403": MunicipalityEntry(MunicipalityCode("271403"), "大阪府", "堺市", "ｵｵｻｶﾌ", "ｻｶｲｼ"),
    "272027": MunicipalityEntry(MunicipalityCode("272027"), "大阪府", "岸和田市", "ｵｵｻｶﾌ", "ｷｼﾜﾀﾞｼ"),
    "272035": MunicipalityEntry(MunicipalityCode("272035"), "大阪府", "豊中市", "ｵｵｻｶﾌ", "ﾄﾖﾅｶｼ"),
    "272043": MunicipalityEntry(MunicipalityCode("272043"), "大阪府", "池田市", "ｵｵｻｶﾌ", "ｲｹﾀﾞｼ"),
    "272051": MunicipalityEntry(MunicipalityCode("272051"), "大阪府", "吹田市", "ｵｵｻｶﾌ", "ｽｲﾀｼ"),
    "272060": MunicipalityEntry(MunicipalityCode("272060"), "大阪府", "泉大津市", "ｵｵｻｶﾌ", "ｲｽﾞﾐｵｵﾂｼ"),
    "272078": MunicipalityEntry(MunicipalityCode("272078"), "大阪府", "高槻市", "ｵｵｻｶﾌ", "ﾀｶﾂｷｼ"),
    "272086": MunicipalityEntry(MunicipalityCode("272086"), "大阪府", "貝塚市", "ｵｵｻｶﾌ", "ｶｲﾂﾞｶｼ"),
    "272094": MunicipalityEntry(MunicipalityCode("272094"), "大阪府", "守口市", "ｵｵｻｶﾌ", "ﾓﾘｸﾞﾁｼ"),
    "272108": MunicipalityEntry(MunicipalityCode("272108"), "大阪府", "枚方市", "ｵｵｻｶﾌ", "ﾋﾗｶﾀｼ"),
    "272116": MunicipalityEntry(MunicipalityCode("272116"), "大阪府", "茨木市", "ｵｵｻｶﾌ", "ｲﾊﾞﾗｷｼ"),
    "272124": MunicipalityEntry(MunicipalityCode("272124"), "大阪府", "八尾市", "ｵｵｻｶﾌ", "ﾔｵｼ"),
    "272132": MunicipalityEntry(MunicipalityCode("272132"), "大阪府", "泉佐野市", "ｵｵｻｶﾌ", "ｲｽﾞﾐｻﾉｼ"),
    "272141": MunicipalityEntry(MunicipalityCode("272141"), "大阪府", "富田林市", "ｵｵｻｶﾌ", "ﾄﾝﾀﾞﾊﾞﾔｼｼ"),
    "272159": MunicipalityEntry(MunicipalityCode("272159"), "大阪府", "寝屋川市", "ｵｵｻｶﾌ", "ﾈﾔｶﾞﾜｼ"),
    "272167": MunicipalityEntry(MunicipalityCode("272167"), "大阪府", "河内長野市", "ｵｵｻｶﾌ", "ｶﾜﾁﾅｶﾞﾉｼ"),
    "272175": MunicipalityEntry(MunicipalityCode("272175"), "大阪府", "松原市", "ｵｵｻｶﾌ", "ﾏﾂﾊﾞﾗｼ"),
    "272183": MunicipalityEntry(MunicipalityCode("272183"), "大阪府", "大東市", "ｵｵｻｶﾌ", "ﾀﾞｲﾄｳｼ"),
    "272191": MunicipalityEntry(MunicipalityCode("272191"), "大阪府", "和泉市", "ｵｵｻｶﾌ", "ｲｽﾞﾐｼ"),
    "272205": MunicipalityEntry(MunicipalityCode("272205"), "大阪府", "箕面市", "ｵｵｻｶﾌ", "ﾐﾉｵｼ"),
    "272213": MunicipalityEntry(MunicipalityCode("272213"), "大阪府", "柏原市", "ｵｵｻｶﾌ", "ｶｼﾜﾗｼ"),
    "272221": MunicipalityEntry(MunicipalityCode("272221"), "大阪府", "羽曳野市", "ｵｵｻｶﾌ", "ﾊﾋﾞｷﾉｼ"),
    "272230": MunicipalityEntry(MunicipalityCode("272230"), "大阪府", "門真市", "ｵｵｻｶﾌ", "ｶﾄﾞﾏｼ"),
    "272248": MunicipalityEntry(MunicipalityCode("272248"), "大阪府", "摂津市", "ｵｵｻｶﾌ", "ｾｯﾂｼ"),
    "272256": MunicipalityEntry(MunicipalityCode("272256"), "大阪府", "高石市", "ｵｵｻｶﾌ", "ﾀｶｲｼｼ"),
    "272264": MunicipalityEntry(MunicipalityCode("272264"), "大阪府", "藤井寺市", "ｵｵｻｶﾌ", "ﾌｼﾞｲﾃﾞﾗｼ"),
    "272272": MunicipalityEntry(MunicipalityCode("272272"), "大阪府", "東大阪市", "ｵｵｻｶﾌ", "ﾋｶﾞｼｵｵｻｶｼ"),
    "272281": MunicipalityEntry(MunicipalityCode("272281"), "大阪府", "泉南市", "ｵｵｻｶﾌ", "ｾﾝﾅﾝｼ"),
    "272299": MunicipalityEntry(MunicipalityCode("272299"), "大阪府", "四條畷市", "ｵｵｻｶﾌ", "ｼｼﾞﾖｳﾅﾜﾃｼ"),
    "272302": MunicipalityEntry(MunicipalityCode("272302"), "大阪府", "交野市", "ｵｵｻｶﾌ", "ｶﾀﾉｼ"),
    "272311": MunicipalityEntry(MunicipalityCode("272311"), "大阪府", "大阪狭山市", "ｵｵｻｶﾌ", "ｵｵｻｶｻﾔﾏｼ"),
    "272329": MunicipalityEntry(MunicipalityCode("272329"), "大阪府", "阪南市", "ｵｵｻｶﾌ", "ﾊﾝﾅﾝｼ"),
    "273015": MunicipalityEntry(MunicipalityCode("273015"), "大阪府", "島本町", "ｵｵｻｶﾌ", "ｼﾏﾓﾄﾁｮｳ"),
    "273210": MunicipalityEntry(MunicipalityCode("273210"), "大阪府", "豊能町", "ｵｵｻｶﾌ", "ﾄﾖﾉﾁｮｳ"),
    "273228": MunicipalityEntry(MunicipalityCode("273228"), "大阪府", "能勢町", "ｵｵｻｶﾌ", "ﾉｾﾁｮｳ"),
    "273414": MunicipalityEntry(MunicipalityCode("273414"), "大阪府", "忠岡町", "ｵｵｻｶﾌ", "ﾀﾀﾞｵｶﾁｮｳ"),
    "273619": MunicipalityEntry(MunicipalityCode("273619"), "大阪府", "熊取町", "ｵｵｻｶﾌ", "ｸﾏﾄﾘﾁｮｳ"),
    "273627": MunicipalityEntry(MunicipalityCode("273627"), "大阪府", "田尻町", "ｵｵｻｶﾌ", "ﾀｼﾞﾘﾁｮｳ"),
    "273660": MunicipalityEntry(MunicipalityCode("273660"), "大阪府", "岬町", "ｵｵｻｶﾌ", "ﾐｻｷﾁｮｳ"),
    "273813": MunicipalityEntry(MunicipalityCode("273813"), "大阪府", "太子町", "ｵｵｻｶﾌ", "ﾀｲｼﾁｮｳ"),
    "273821": MunicipalityEntry(MunicipalityCode("273821"), "大阪府", "河南町", "ｵｵｻｶﾌ", "ｶﾅﾝﾁｮｳ"),
    "273830": MunicipalityEntry(MunicipalityCode("273830"), "大阪府", "千早赤阪村", "ｵｵｻｶﾌ", "ﾁﾊﾔｱｶｻｶﾑﾗ"),
    "280003": MunicipalityEntry(MunicipalityCode("280003"), "兵庫県", "", "ﾋｮｳｺﾞｹﾝ", ""),
    "281000": MunicipalityEntry(MunicipalityCode("281000"), "兵庫県", "神戸市", "ﾋｮｳｺﾞｹﾝ", "ｺｳﾍﾞｼ"),
    "282014": MunicipalityEntry(MunicipalityCode("282014"), "兵庫県", "姫路市", "ﾋｮｳｺﾞｹﾝ", "ﾋﾒｼﾞｼ"),
    "282022": MunicipalityEntry(MunicipalityCode("282022"), "兵庫県", "尼崎市", "ﾋｮｳｺﾞｹﾝ", "ｱﾏｶﾞｻｷｼ"),
    "282031": MunicipalityEntry(MunicipalityCode("282031"), "兵庫県", "明石市", "ﾋｮｳｺﾞｹﾝ", "ｱｶｼｼ"),
    "282049": MunicipalityEntry(MunicipalityCode("282049"), "兵庫県", "西宮市", "ﾋｮｳｺﾞｹﾝ", "ﾆｼﾉﾐﾔｼ"),
    "282057": MunicipalityEntry(MunicipalityCode("282057"), "兵庫県", "洲本市", "ﾋｮｳｺﾞｹﾝ", "ｽﾓﾄｼ"),
    "282065": MunicipalityEntry(MunicipalityCode("282065"), "兵庫県", "芦屋市", "ﾋｮｳｺﾞｹﾝ", "ｱｼﾔｼ"),
    "282073": MunicipalityEntry(MunicipalityCode("282073"), "兵庫県", "伊丹市", "ﾋｮｳｺﾞｹﾝ", "ｲﾀﾐｼ"),
    "282081": MunicipalityEntry(MunicipalityCode("282081"), "兵庫県", "相生市", "ﾋｮｳｺﾞｹﾝ", "ｱｲｵｲｼ"),
    "282090": MunicipalityEntry(MunicipalityCode("282090"), "兵庫県", "豊岡市", "ﾋｮｳｺﾞｹﾝ", "ﾄﾖｵｶｼ"),
    "282103": MunicipalityEntry(MunicipalityCode("282103"), "兵庫県", "加古川市", "ﾋｮｳｺﾞｹﾝ", "ｶｺｶﾞﾜｼ"),
    "282120": MunicipalityEntry(MunicipalityCode("282120"), "兵庫県", "赤穂市", "ﾋｮｳｺﾞｹﾝ", "ｱｺｳｼ"),
    "282138": MunicipalityEntry(MunicipalityCode("282138"), "兵庫県", "西脇市", "ﾋｮｳｺﾞｹﾝ", "ﾆｼﾜｷｼ"),
    "282146": MunicipalityEntry(MunicipalityCode("282146"), "兵庫県", "宝塚市", "ﾋｮｳｺﾞｹﾝ", "ﾀｶﾗﾂﾞｶｼ"),
    "282154": MunicipalityEntry(MunicipalityCode("282154"), "兵庫県", "三木市", "ﾋｮｳｺﾞｹﾝ", "ﾐｷｼ"),
    "282162": MunicipalityEntry(MunicipalityCode("282162"), "兵庫県", "高砂市", "ﾋｮｳｺﾞｹﾝ", "ﾀｶｻｺﾞｼ"),
    "282171": MunicipalityEntry(MunicipalityCode("282171"), "兵庫県", "川西市", "ﾋｮｳｺﾞｹﾝ", "ｶﾜﾆｼｼ"),
    "282189": MunicipalityEntry(MunicipalityCode("282189"), "兵庫県", "小野市", "ﾋｮｳｺﾞｹﾝ", "ｵﾉｼ"),
    "282197": MunicipalityEntry(MunicipalityCode("282197"), "兵庫県", "三田市", "ﾋｮｳｺﾞｹﾝ", "ｻﾝﾀﾞｼ"),
    "282201": MunicipalityEntry(MunicipalityCode("282201"), "兵庫県", "加西市", "ﾋｮｳｺﾞｹﾝ", "ｶｻｲｼ"),
    "282219": MunicipalityEntry(MunicipalityCode("282219"), "兵庫県", "丹波篠山市", "ﾋｮｳｺﾞｹﾝ", "ﾀﾝﾊﾞｻｻﾔﾏｼ"),
    "282227": MunicipalityEntry(MunicipalityCode("282227"), "兵庫県", "養父市", "ﾋｮｳｺﾞｹﾝ", "ﾔﾌﾞｼ"),
    "282235": MunicipalityEntry(MunicipalityCode("282235"), "兵庫県", "丹波市", "ﾋｮｳｺﾞｹﾝ", "ﾀﾝﾊﾞｼ"),
    "282243": MunicipalityEntry(MunicipalityCode("282243"), "兵庫県", "南あわじ市", "ﾋｮｳｺﾞｹﾝ", "ﾐﾅﾐｱﾜｼﾞｼ"),
    "282251": MunicipalityEntry(MunicipalityCode("282251"), "兵庫県", "朝来市", "ﾋｮｳｺﾞｹﾝ", "ｱｻｺﾞｼ"),
    "282260": MunicipalityEntry(MunicipalityCode("282260"), "兵庫県", "淡路市", "ﾋｮｳｺﾞｹﾝ", "ｱﾜｼﾞｼ"),
    "282278": MunicipalityEntry(MunicipalityCode("282278"), "兵庫県", "宍粟市", "ﾋｮｳｺﾞｹﾝ", "ｼｿｳｼ"),
    "282286": MunicipalityEntry(MunicipalityCode("282286"), "兵庫県", "加東市", "ﾋｮｳｺﾞｹﾝ", "ｶﾄｳｼ"),
    "282294": MunicipalityEntry(MunicipalityCode("282294"), "兵庫県", "たつの市", "ﾋｮｳｺﾞｹﾝ", "ﾀﾂﾉｼ"),
    "283011": MunicipalityEntry(MunicipalityCode("283011"), "兵庫県", "猪名川町", "ﾋｮｳｺﾞｹﾝ", "ｲﾅｶﾞﾜﾁｮｳ"),
    "283657": MunicipalityEntry(MunicipalityCode("283657"), "兵庫県", "多可町", "ﾋｮｳｺﾞｹﾝ", "ﾀｶﾁｮｳ"),
    "283819": MunicipalityEntry(MunicipalityCode("283819"), "兵庫県", "稲美町", "ﾋｮｳｺﾞｹﾝ", "ｲﾅﾐﾁｮｳ"),
    "283827": MunicipalityEntry(MunicipalityCode("283827"), "兵庫県", "播磨町", "ﾋｮｳｺﾞｹﾝ", "ﾊﾘﾏﾁｮｳ"),
    "284424": MunicipalityEntry(MunicipalityCode("284424"), "兵庫県", "市川町", "ﾋｮｳｺﾞｹﾝ", "ｲﾁｶﾜﾁｮｳ"),
    "284432": MunicipalityEntry(MunicipalityCode("284432"), "兵庫県", "福崎町", "ﾋｮｳｺﾞｹﾝ", "ﾌｸｻｷﾁｮｳ"),
    "284467": MunicipalityEntry(MunicipalityCode("284467"), "兵庫県", "神河町", "ﾋｮｳｺﾞｹﾝ", "ｶﾐｶﾜﾁｮｳ"),
    "284645": MunicipalityEntry(MunicipalityCode("284645"), "兵庫県", "太子町", "ﾋｮｳｺﾞｹﾝ", "ﾀｲｼﾁｮｳ"),
    "284815": MunicipalityEntry(MunicipalityCode("284815"), "兵庫県", "上郡町", "ﾋｮｳｺﾞｹﾝ", "ｶﾐｺﾞｵﾘﾁｮｳ"),
    "285013": MunicipalityEntry(MunicipalityCode("285013"), "兵庫県", "佐用町", "ﾋｮｳｺﾞｹﾝ", "ｻﾖｳﾁｮｳ"),
    "285854": MunicipalityEntry(MunicipalityCode("285854"), "兵庫県", "香美町", "ﾋｮｳｺﾞｹﾝ", "ｶﾐﾁｮｳ"),
    "285862": MunicipalityEntry(MunicipalityCode("285862"), "兵庫県", "新温泉町", "ﾋｮｳｺﾞｹﾝ", "ｼﾝｵﾝｾﾝﾁｮｳ"),
    "290009": MunicipalityEntry(MunicipalityCode("290009"), "奈良県", "", "ﾅﾗｹﾝ", ""),
    "292010": MunicipalityEntry(MunicipalityCode("292010"), "奈良県", "奈良市", "ﾅﾗｹﾝ", "ﾅﾗｼ"),
    "292028": MunicipalityEntry(MunicipalityCode("292028"), "奈良県", "大和高田市", "ﾅﾗｹﾝ", "ﾔﾏﾄﾀｶﾀﾞｼ"),
    "292036": MunicipalityEntry(MunicipalityCode("292036"), "奈良県", "大和郡山市", "ﾅﾗｹﾝ", "ﾔﾏﾄｺｵﾘﾔﾏｼ"),
    "292044": MunicipalityEntry(MunicipalityCode("292044"), "奈良県", "天理市", "ﾅﾗｹﾝ", "ﾃﾝﾘｼ"),
    "292052": MunicipalityEntry(MunicipalityCode("292052"), "奈良県", "橿原市", "ﾅﾗｹﾝ", "ｶｼﾊﾗｼ"),
    "292061": MunicipalityEntry(MunicipalityCode("292061"), "奈良県", "桜井市", "ﾅﾗｹﾝ", "ｻｸﾗｲｼ"),
    "292079": MunicipalityEntry(MunicipalityCode("292079"), "奈良県", "五條市", "ﾅﾗｹﾝ", "ｺﾞｼﾞｮｳｼ"),
    "292087": MunicipalityEntry(MunicipalityCode("292087"), "奈良県", "御所市", "ﾅﾗｹﾝ", "ｺﾞｾｼ"),
    "292095": MunicipalityEntry(MunicipalityCode("292095"), "奈良県", "生駒市", "ﾅﾗｹﾝ", "ｲｺﾏｼ"),
    "292109": MunicipalityEntry(MunicipalityCode("292109"), "奈良県", "香芝市", "ﾅﾗｹﾝ", "ｶｼﾊﾞｼ"),
    "292117": MunicipalityEntry(MunicipalityCode("292117"), "奈良県", "葛城市", "ﾅﾗｹﾝ", "ｶﾂﾗｷﾞｼ"),
    "292125": MunicipalityEntry(MunicipalityCode("292125"), "奈良県", "宇陀市", "ﾅﾗｹﾝ", "ｳﾀﾞｼ"),
    "293229": MunicipalityEntry(MunicipalityCode("293229"), "奈良県", "山添村", "ﾅﾗｹﾝ", "ﾔﾏｿﾞｴﾑﾗ"),
    "293423": MunicipalityEntry(MunicipalityCode("293423"), "奈良県", "平群町", "ﾅﾗｹﾝ", "ﾍｸﾞﾘﾁｮｳ"),
    "293431": MunicipalityEntry(MunicipalityCode("293431"), "奈良県", "三郷町", "ﾅﾗｹﾝ", "ｻﾝｺﾞｳﾁｮｳ"),
    "293440": MunicipalityEntry(MunicipalityCode("293440"), "奈良県", "斑鳩町", "ﾅﾗｹﾝ", "ｲｶﾙｶﾞﾁｮｳ"),
    "293458": MunicipalityEntry(MunicipalityCode("293458"), "奈良県", "安堵町", "ﾅﾗｹﾝ", "ｱﾝﾄﾞﾁｮｳ"),
    "293610": MunicipalityEntry(MunicipalityCode("293610"), "奈良県", "川西町", "ﾅﾗｹﾝ", "ｶﾜﾆｼﾁｮｳ"),
    "293628": MunicipalityEntry(MunicipalityCode("293628"), "奈良県", "三宅町", "ﾅﾗｹﾝ", "ﾐﾔｹﾁｮｳ"),
    "293636": MunicipalityEntry(MunicipalityCode("293636"), "奈良県", "田原本町", "ﾅﾗｹﾝ", "ﾀﾜﾗﾓﾄﾁｮｳ"),
    "293857": MunicipalityEntry(MunicipalityCode("293857"), "奈良県", "曽爾村", "ﾅﾗｹﾝ", "ｿﾆﾑﾗ"),
    "293865": MunicipalityEntry(MunicipalityCode("293865"), "奈良県", "御杖村", "ﾅﾗｹﾝ", "ﾐﾂｴﾑﾗ"),
    "294012": MunicipalityEntry(MunicipalityCode("294012"), "奈良県", "高取町", "ﾅﾗｹﾝ", "ﾀｶﾄﾘﾁｮｳ"),
    "294021": MunicipalityEntry(MunicipalityCode("294021"), "奈良県", "明日香村", "ﾅﾗｹﾝ", "ｱｽｶﾑﾗ"),
    "294241": MunicipalityEntry(MunicipalityCode("294241"), "奈良県", "上牧町", "ﾅﾗｹﾝ", "ｶﾝﾏｷﾁｮｳ"),
    "294250": MunicipalityEntry(MunicipalityCode("294250"), "奈良県", "王寺町", "ﾅﾗｹﾝ", "ｵｳｼﾞﾁｮｳ"),
    "294268": MunicipalityEntry(MunicipalityCode("294268"), "奈良県", "広陵町", "ﾅﾗｹﾝ", "ｺｳﾘﾖｳﾁｮｳ"),
    "294276": MunicipalityEntry(MunicipalityCode("294276"), "奈良県", "河合町", "ﾅﾗｹﾝ", "ｶﾜｲﾁｮｳ"),
    "294411": MunicipalityEntry(MunicipalityCode("294411"), "奈良県", "吉野町", "ﾅﾗｹﾝ", "ﾖｼﾉﾁｮｳ"),
    "294420": MunicipalityEntry(MunicipalityCode("294420"), "奈良県", "大淀町", "ﾅﾗｹﾝ", "ｵｵﾖﾄﾞﾁｮｳ"),
    "294438": MunicipalityEntry(MunicipalityCode("294438"), "奈良県", "下市町", "ﾅﾗｹﾝ", "ｼﾓｲﾁﾁｮｳ"),
    "294446": MunicipalityEntry(MunicipalityCode("294446"), "奈良県", "黒滝村", "ﾅﾗｹﾝ", "ｸﾛﾀｷﾑﾗ"),
    "294462": MunicipalityEntry(MunicipalityCode("294462"), "奈良県", "天川村", "ﾅﾗｹﾝ", "ﾃﾝｶﾜﾑﾗ"),
    "294471": MunicipalityEntry(MunicipalityCode("294471"), "奈良県", "野迫川村", "ﾅﾗｹﾝ", "ﾉｾｶﾞﾜﾑﾗ"),
    "294497": MunicipalityEntry(MunicipalityCode("294497"), "奈良県", "十津川村", "ﾅﾗｹﾝ", "ﾄﾂｶﾜﾑﾗ"),
    "294501": MunicipalityEntry(MunicipalityCode("294501"), "奈良県", "下北山村", "ﾅﾗｹﾝ", "ｼﾓｷﾀﾔﾏﾑﾗ"),
    "294519": MunicipalityEntry(MunicipalityCode("294519"), "奈良県", "上北山村", "ﾅﾗｹﾝ", "ｶﾐｷﾀﾔﾏﾑﾗ"),
    "294527": MunicipalityEntry(MunicipalityCode("294527"), "奈良県", "川上村", "ﾅﾗｹﾝ", "ｶﾜｶﾐﾑﾗ"),
    "294535": MunicipalityEntry(MunicipalityCode("294535"), "奈良県", "東吉野村", "ﾅﾗｹﾝ", "ﾋｶﾞｼﾖｼﾉﾑﾗ"),
    "300004": MunicipalityEntry(MunicipalityCode("300004"), "和歌山県", "", "ﾜｶﾔﾏｹﾝ", ""),
    "302015": MunicipalityEntry(MunicipalityCode("302015"), "和歌山県", "和歌山市", "ﾜｶﾔﾏｹﾝ", "ﾜｶﾔﾏｼ"),
    "302023": MunicipalityEntry(MunicipalityCode("302023"), "和歌山県", "海南市", "ﾜｶﾔﾏｹﾝ", "ｶｲﾅﾝｼ"),
    "302031": MunicipalityEntry(MunicipalityCode("302031"), "和歌山県", "橋本市", "ﾜｶﾔﾏｹﾝ", "ﾊｼﾓﾄｼ"),
    "302040": MunicipalityEntry(MunicipalityCode("302040"), "和歌山県", "有田市", "ﾜｶﾔﾏｹﾝ", "ｱﾘﾀﾞｼ"),
    "302058": MunicipalityEntry(MunicipalityCode("302058"), "和歌山県", "御坊市", "ﾜｶﾔﾏｹﾝ", "ｺﾞﾎﾞｳｼ"),
    "302066": MunicipalityEntry(MunicipalityCode("302066"), "和歌山県", "田辺市", "ﾜｶﾔﾏｹﾝ", "ﾀﾅﾍﾞｼ"),
    "302074": MunicipalityEntry(MunicipalityCode("302074"), "和歌山県", "新宮市", "ﾜｶﾔﾏｹﾝ", "ｼﾝｸﾞｳｼ"),
    "302082": MunicipalityEntry(MunicipalityCode("302082"), "和歌山県", "紀の川市", "ﾜｶﾔﾏｹﾝ", "ｷﾉｶﾜｼ"),
    "302091": MunicipalityEntry(MunicipalityCode("302091"), "和歌山県", "岩出市", "ﾜｶﾔﾏｹﾝ", "ｲﾜﾃﾞｼ"),
    "303046": MunicipalityEntry(MunicipalityCode("303046"), "和歌山県", "紀美野町", "ﾜｶﾔﾏｹﾝ", "ｷﾐﾉﾁｮｳ"),
    "303411": MunicipalityEntry(MunicipalityCode("303411"), "和歌山県", "かつらぎ町", "ﾜｶﾔﾏｹﾝ", "ｶﾂﾗｷﾞﾁｮｳ"),
    "303437": MunicipalityEntry(MunicipalityCode("303437"), "和歌山県", "九度山町", "ﾜｶﾔﾏｹﾝ", "ｸﾄﾞﾔﾏﾁｮｳ"),
    "303445": MunicipalityEntry(MunicipalityCode("303445"), "和歌山県", "高野町", "ﾜｶﾔﾏｹﾝ", "ｺｳﾔﾁｮｳ"),
    "303615": MunicipalityEntry(MunicipalityCode("303615"), "和歌山県", "湯浅町", "ﾜｶﾔﾏｹﾝ", "ﾕｱｻﾁｮｳ"),
    "303623": MunicipalityEntry(MunicipalityCode("303623"), "和歌山県", "広川町", "ﾜｶﾔﾏｹﾝ", "ﾋﾛｶﾞﾜﾁｮｳ"),
    "303666": MunicipalityEntry(MunicipalityCode("303666"), "和歌山県", "有田川町", "ﾜｶﾔﾏｹﾝ", "ｱﾘﾀﾞｶﾞﾜﾁｮｳ"),
    "303810": MunicipalityEntry(MunicipalityCode("303810"), "和歌山県", "美浜町", "ﾜｶﾔﾏｹﾝ", "ﾐﾊﾏﾁｮｳ"),
    "303828": MunicipalityEntry(MunicipalityCode("303828"), "和歌山県", "日高町", "ﾜｶﾔﾏｹﾝ", "ﾋﾀﾞｶﾁｮｳ"),
    "303836": MunicipalityEntry(MunicipalityCode("303836"), "和歌山県", "由良町", "ﾜｶﾔﾏｹﾝ", "ﾕﾗﾁｮｳ"),
    "303909": MunicipalityEntry(MunicipalityCode("303909"), "和歌山県", "印南町", "ﾜｶﾔﾏｹﾝ", "ｲﾅﾐﾁｮｳ"),
    "303917": MunicipalityEntry(MunicipalityCode("303917"), "和歌山県", "みなべ町", "ﾜｶﾔﾏｹﾝ", "ﾐﾅﾍﾞﾁｮｳ"),
    "303925": MunicipalityEntry(MunicipalityCode("303925"), "和歌山県", "日高川町", "ﾜｶﾔﾏｹﾝ", "ﾋﾀﾞｶｶﾞﾜﾁｮｳ"),
    "304018": MunicipalityEntry(MunicipalityCode("304018"), "和歌山県", "白浜町", "ﾜｶﾔﾏｹﾝ", "ｼﾗﾊﾏﾁｮｳ"),
    "304042": MunicipalityEntry(MunicipalityCode("304042"), "和歌山県", "上富田町", "ﾜｶﾔﾏｹﾝ", "ｶﾐﾄﾝﾀﾞﾁｮｳ"),
    "304069": MunicipalityEntry(MunicipalityCode("304069"), "和歌山県", "すさみ町", "ﾜｶﾔﾏｹﾝ", "ｽｻﾐﾁｮｳ"),
    "304212": MunicipalityEntry(MunicipalityCode("304212"), "和歌山県", "那智勝浦町", "ﾜｶﾔﾏｹﾝ", "ﾅﾁｶﾂｳﾗﾁｮｳ"),
    "304221": MunicipalityEntry(MunicipalityCode("304221"), "和歌山県", "太地町", "ﾜｶﾔﾏｹﾝ", "ﾀｲｼﾞﾁｮｳ"),
    "304247": MunicipalityEntry(MunicipalityCode("304247"), "和歌山県", "古座川町", "ﾜｶﾔﾏｹﾝ", "ｺｻﾞｶﾞﾜﾁｮｳ"),
    "304271": MunicipalityEntry(MunicipalityCode("304271"), "和歌山県", "北山村", "ﾜｶﾔﾏｹﾝ", "ｷﾀﾔﾏﾑﾗ"),
    "304280": MunicipalityEntry(MunicipalityCode("304280"), "和歌山県", "串本町", "ﾜｶﾔﾏｹﾝ", "ｸｼﾓﾄﾁｮｳ"),
    "310000": MunicipalityEntry(MunicipalityCode("310000"), "鳥取県", "", "ﾄｯﾄﾘｹﾝ", ""),
    "312011": MunicipalityEntry(MunicipalityCode("312011"), "鳥取県", "鳥取市", "ﾄｯﾄﾘｹﾝ", "ﾄｯﾄﾘｼ"),
    "312029": MunicipalityEntry(MunicipalityCode("312029"), "鳥取県", "米子市", "ﾄｯﾄﾘｹﾝ", "ﾖﾅｺﾞｼ"),
    "312037": MunicipalityEntry(MunicipalityCode("312037"), "鳥取県", "倉吉市", "ﾄｯﾄﾘｹﾝ", "ｸﾗﾖｼｼ"),
    "312045": MunicipalityEntry(MunicipalityCode("312045"), "鳥取県", "境港市", "ﾄｯﾄﾘｹﾝ", "ｻｶｲﾐﾅﾄｼ"),
    "313025": MunicipalityEntry(MunicipalityCode("313025"), "鳥取県", "岩美町", "ﾄｯﾄﾘｹﾝ", "ｲﾜﾐﾁｮｳ"),
    "313254": MunicipalityEntry(MunicipalityCode("313254"), "鳥取県", "若桜町", "ﾄｯﾄﾘｹﾝ", "ﾜｶｻﾁｮｳ"),
    "313289": MunicipalityEntry(MunicipalityCode("313289"), "鳥取県", "智頭町", "ﾄｯﾄﾘｹﾝ", "ﾁﾂﾞﾁｮｳ"),
    "313297": MunicipalityEntry(MunicipalityCode("313297"), "鳥取県", "八頭町", "ﾄｯﾄﾘｹﾝ", "ﾔｽﾞﾁｮｳ"),
    "313645": MunicipalityEntry(MunicipalityCode("313645"), "鳥取県", "三朝町", "ﾄｯﾄﾘｹﾝ", "ﾐｻｻﾁｮｳ"),
    "313700": MunicipalityEntry(MunicipalityCode("313700"), "鳥取県", "湯梨浜町", "ﾄｯﾄﾘｹﾝ", "ﾕﾘﾊﾏﾁｮｳ"),
    "313718": MunicipalityEntry(MunicipalityCode("313718"), "鳥取県", "琴浦町", "ﾄｯﾄﾘｹﾝ", "ｺﾄｳﾗﾁｮｳ"),
    "313726": MunicipalityEntry(MunicipalityCode("313726"), "鳥取県", "北栄町", "ﾄｯﾄﾘｹﾝ", "ﾎｸｴｲﾁｮｳ"),
    "313840": MunicipalityEntry(MunicipalityCode("313840"), "鳥取県", "日吉津村", "ﾄｯﾄﾘｹﾝ", "ﾋｴﾂﾞｿﾝ"),
    "313866": MunicipalityEntry(MunicipalityCode("313866"), "鳥取県", "大山町", "ﾄｯﾄﾘｹﾝ", "ﾀﾞｲｾﾝﾁｮｳ"),
    "313891": MunicipalityEntry(MunicipalityCode("313891"), "鳥取県", "南部町", "ﾄｯﾄﾘｹﾝ", "ﾅﾝﾌﾞﾁｮｳ"),
    "313904": MunicipalityEntry(MunicipalityCode("313904"), "鳥取県", "伯耆町", "ﾄｯﾄﾘｹﾝ", "ﾎｳｷﾁｮｳ"),
    "314013": MunicipalityEntry(MunicipalityCode("314013"), "鳥取県", "日南町", "ﾄｯﾄﾘｹﾝ", "ﾆﾁﾅﾝﾁｮｳ"),
    "314021": MunicipalityEntry(MunicipalityCode("314021"), "鳥取県", "日野町", "ﾄｯﾄﾘｹﾝ", "ﾋﾉﾁｮｳ"),
    "314030": MunicipalityEntry(MunicipalityCode("314030"), "鳥取県", "江府町", "ﾄｯﾄﾘｹﾝ", "ｺｳﾌﾁｮｳ"),
    "320005": MunicipalityEntry(MunicipalityCode("320005"), "島根県", "", "ｼﾏﾈｹﾝ", ""),
    "322016": MunicipalityEntry(MunicipalityCode("322016"), "島根県", "松江市", "ｼﾏﾈｹﾝ", "ﾏﾂｴｼ"),
    "322024": MunicipalityEntry(MunicipalityCode("322024"), "島根県", "浜田市", "ｼﾏﾈｹﾝ", "ﾊﾏﾀﾞｼ"),
    "322032": MunicipalityEntry(MunicipalityCode("322032"), "島根県", "出雲市", "ｼﾏﾈｹﾝ", "ｲｽﾞﾓｼ"),
    "322041": MunicipalityEntry(MunicipalityCode("322041"), "島根県", "益田市", "ｼﾏﾈｹﾝ", "ﾏｽﾀﾞｼ"),
    "322059": MunicipalityEntry(MunicipalityCode("322059"), "島根県", "大田市", "ｼﾏﾈｹﾝ", "ｵｵﾀﾞｼ"),
    "322067": MunicipalityEntry(MunicipalityCode("322067"), "島根県", "安来市", "ｼﾏﾈｹﾝ", "ﾔｽｷﾞｼ"),
    "322075": MunicipalityEntry(MunicipalityCode("322075"), "島根県", "江津市", "ｼﾏﾈｹﾝ", "ｺﾞｳﾂｼ"),
    "322091": MunicipalityEntry(MunicipalityCode("322091"), "島根県", "雲南市", "ｼﾏﾈｹﾝ", "ｳﾝﾅﾝｼ"),
    "323438": MunicipalityEntry(MunicipalityCode("323438"), "島根県", "奥出雲町", "ｼﾏﾈｹﾝ", "ｵｸｲｽﾞﾓﾁｮｳ"),
    "323861": MunicipalityEntry(MunicipalityCode("323861"), "島根県", "飯南町", "ｼﾏﾈｹﾝ", "ｲｲﾅﾝﾁｮｳ"),
    "324418": MunicipalityEntry(MunicipalityCode("324418"), "島根県", "川本町", "ｼﾏﾈｹﾝ", "ｶﾜﾓﾄﾏﾁ"),
    "324485": MunicipalityEntry(MunicipalityCode("324485"), "島根県", "美郷町", "ｼﾏﾈｹﾝ", "ﾐｻﾄﾁｮｳ"),
    "324493": MunicipalityEntry(MunicipalityCode("324493"), "島根県", "邑南町", "ｼﾏﾈｹﾝ", "ｵｵﾅﾝﾁｮｳ"),
    "325015": MunicipalityEntry(MunicipalityCode("325015"), "島根県", "津和野町", "ｼﾏﾈｹﾝ", "ﾂﾜﾉﾁｮｳ"),
    "325058": MunicipalityEntry(MunicipalityCode("325058"), "島根県", "吉賀町", "ｼﾏﾈｹﾝ", "ﾖｼｶﾁｮｳ"),
    "325252": MunicipalityEntry(MunicipalityCode("325252"), "島根県", "海士町", "ｼﾏﾈｹﾝ", "ｱﾏﾁｮｳ"),
    "325261": MunicipalityEntry(MunicipalityCode("325261"), "島根県", "西ノ島町", "ｼﾏﾈｹﾝ", "ﾆｼﾉｼﾏﾁｮｳ"),
    "325279": MunicipalityEntry(MunicipalityCode("325279"), "島根県", "知夫村", "ｼﾏﾈｹﾝ", "ﾁﾌﾞﾑﾗ"),
    "325287": MunicipalityEntry(MunicipalityCode("325287"), "島根県", "隠岐の島町", "ｼﾏﾈｹﾝ", "ｵｷﾉｼﾏﾁｮｳ"),
    "330001": MunicipalityEntry(MunicipalityCode("330001"), "岡山県", "", "ｵｶﾔﾏｹﾝ", ""),
    "331007": MunicipalityEntry(MunicipalityCode("331007"), "岡山県", "岡山市", "ｵｶﾔﾏｹﾝ", "ｵｶﾔﾏｼ"),
    "332020": MunicipalityEntry(MunicipalityCode("332020"), "岡山県", "倉敷市", "ｵｶﾔﾏｹﾝ", "ｸﾗｼｷｼ"),
    "332038": MunicipalityEntry(MunicipalityCode("332038"), "岡山県", "津山市", "ｵｶﾔﾏｹﾝ", "ﾂﾔﾏｼ"),
    "332046": MunicipalityEntry(MunicipalityCode("332046"), "岡山県", "玉野市", "ｵｶﾔﾏｹﾝ", "ﾀﾏﾉｼ"),
    "332054": MunicipalityEntry(MunicipalityCode("332054"), "岡山県", "笠岡市", "ｵｶﾔﾏｹﾝ", "ｶｻｵｶｼ"),
    "332071": MunicipalityEntry(MunicipalityCode("332071"), "岡山県", "井原市", "ｵｶﾔﾏｹﾝ", "ｲﾊﾞﾗｼ"),
    "332089": MunicipalityEntry(MunicipalityCode("332089"), "岡山県", "総社市", "ｵｶﾔﾏｹﾝ", "ｿｳｼﾞﾔｼ"),
    "332097": MunicipalityEntry(MunicipalityCode("332097"), "岡山県", "高梁市", "ｵｶﾔﾏｹﾝ", "ﾀｶﾊｼｼ"),
    "332101": MunicipalityEntry(MunicipalityCode("332101"), "岡山県", "新見市", "ｵｶﾔﾏｹﾝ", "ﾆｲﾐｼ"),
    "332119": MunicipalityEntry(MunicipalityCode("332119"), "岡山県", "備前市", "ｵｶﾔﾏｹﾝ", "ﾋﾞｾﾞﾝｼ"),
    "332127": MunicipalityEntry(MunicipalityCode("332127"), "岡山県", "瀬戸内市", "ｵｶﾔﾏｹﾝ", "ｾﾄｳﾁｼ"),
    "332135": MunicipalityEntry(MunicipalityCode("332135"), "岡山県", "赤磐市", "ｵｶﾔﾏｹﾝ", "ｱｶｲﾜｼ"),
    "332143": MunicipalityEntry(MunicipalityCode("332143"), "岡山県", "真庭市", "ｵｶﾔﾏｹﾝ", "ﾏﾆﾜｼ"),
    "332151": MunicipalityEntry(MunicipalityCode("332151"), "岡山県", "美作市", "ｵｶﾔﾏｹﾝ", "ﾐﾏｻｶｼ"),
    "332160": MunicipalityEntry(MunicipalityCode("332160"), "岡山県", "浅口市", "ｵｶﾔﾏｹﾝ", "ｱｻｸﾁｼ"),
    "333468": MunicipalityEntry(MunicipalityCode("333468"), "岡山県", "和気町", "ｵｶﾔﾏｹﾝ", "ﾜｹﾁｮｳ"),
    "334235": MunicipalityEntry(MunicipalityCode("334235"), "岡山県", "早島町", "ｵｶﾔﾏｹﾝ", "ﾊﾔｼﾏﾁｮｳ"),
    "334456": MunicipalityEntry(MunicipalityCode("334456"), "岡山県", "里庄町", "ｵｶﾔﾏｹﾝ", "ｻﾄｼｮｳﾁｮｳ"),
    "334618": MunicipalityEntry(MunicipalityCode("334618"), "岡山県", "矢掛町", "ｵｶﾔﾏｹﾝ", "ﾔｶｹﾞﾁｮｳ"),
    "335860": MunicipalityEntry(MunicipalityCode("335860"), "岡山県", "新庄村", "ｵｶﾔﾏｹﾝ", "ｼﾝｼﾞﾖｳｿﾝ"),
    "336068": MunicipalityEntry(MunicipalityCode("336068"), "岡山県", "鏡野町", "ｵｶﾔﾏｹﾝ", "ｶｶﾞﾐﾉﾁｮｳ"),
    "336220": MunicipalityEntry(MunicipalityCode("336220"), "岡山県", "勝央町", "ｵｶﾔﾏｹﾝ", "ｼｮｳｵｳﾁｮｳ"),
    "336238": MunicipalityEntry(MunicipalityCode("336238"), "岡山県", "奈義町", "ｵｶﾔﾏｹﾝ", "ﾅｷﾞﾁｮｳ"),
    "336432": MunicipalityEntry(MunicipalityCode("336432"), "岡山県", "西粟倉村", "ｵｶﾔﾏｹﾝ", "ﾆｼｱﾜｸﾗｿﾝ"),
    "336637": MunicipalityEntry(MunicipalityCode("336637"), "岡山県", "久米南町", "ｵｶﾔﾏｹﾝ", "ｸﾒﾅﾝﾁｮｳ"),
    "336661": MunicipalityEntry(MunicipalityCode("336661"), "岡山県", "美咲町", "ｵｶﾔﾏｹﾝ", "ﾐｻｷﾁｮｳ"),
    "336815": MunicipalityEntry(MunicipalityCode("336815"), "岡山県", "吉備中央町", "ｵｶﾔﾏｹﾝ", "ｷﾋﾞﾁｭｳｵｳﾁｮｳ"),
    "340006": MunicipalityEntry(MunicipalityCode("340006"), "広島県", "", "ﾋﾛｼﾏｹﾝ", ""),
    "341002": MunicipalityEntry(MunicipalityCode("341002"), "広島県", "広島市", "ﾋﾛｼﾏｹﾝ", "ﾋﾛｼﾏｼ"),
    "342025": MunicipalityEntry(MunicipalityCode("342025"), "広島県", "呉市", "ﾋﾛｼﾏｹﾝ", "ｸﾚｼ"),
    "342033": MunicipalityEntry(MunicipalityCode("342033"), "広島県", "竹原市", "ﾋﾛｼﾏｹﾝ", "ﾀｹﾊﾗｼ"),
    "342041": MunicipalityEntry(MunicipalityCode("342041"), "広島県", "三原市", "ﾋﾛｼﾏｹﾝ", "ﾐﾊﾗｼ"),
    "342050": MunicipalityEntry(MunicipalityCode("342050"), "広島県", "尾道市", "ﾋﾛｼﾏｹﾝ", "ｵﾉﾐﾁｼ"),
    "342076": MunicipalityEntry(MunicipalityCode("342076"), "広島県", "福山市", "ﾋﾛｼﾏｹﾝ", "ﾌｸﾔﾏｼ"),
    "342084": MunicipalityEntry(MunicipalityCode("342084"), "広島県", "府中市", "ﾋﾛｼﾏｹﾝ", "ﾌﾁｭｳｼ"),
    "342092": MunicipalityEntry(MunicipalityCode("342092"), "広島県", "三次市", "ﾋﾛｼﾏｹﾝ", "ﾐﾖｼｼ"),
    "342106": MunicipalityEntry(MunicipalityCode("342106"), "広島県", "庄原市", "ﾋﾛｼﾏｹﾝ", "ｼｮｳﾊﾞﾗｼ"),
    "342114": MunicipalityEntry(MunicipalityCode("342114"), "広島県", "大竹市", "ﾋﾛｼﾏｹﾝ", "ｵｵﾀｹｼ"),
    "342122": MunicipalityEntry(MunicipalityCode("342122"), "広島県", "東広島市", "ﾋﾛｼﾏｹﾝ", "ﾋｶﾞｼﾋﾛｼﾏｼ"),
    "342131": MunicipalityEntry(MunicipalityCode("342131"), "広島県", "廿日市市", "ﾋﾛｼﾏｹﾝ", "ﾊﾂｶｲﾁｼ"),
    "342149": MunicipalityEntry(MunicipalityCode("342149"), "広島県", "安芸高田市", "ﾋﾛｼﾏｹﾝ", "ｱｷﾀｶﾀｼ"),
    "342157": MunicipalityEntry(MunicipalityCode("342157"), "広島県", "江田島市", "ﾋﾛｼﾏｹﾝ", "ｴﾀｼﾞﾏｼ"),
    "343021": MunicipalityEntry(MunicipalityCode("343021"), "広島県", "府中町", "ﾋﾛｼﾏｹﾝ", "ﾌﾁｭｳﾁｮｳ"),
    "343048": MunicipalityEntry(MunicipalityCode("343048"), "広島県", "海田町", "ﾋﾛｼﾏｹﾝ", "ｶｲﾀﾁｮｳ"),
    "343072": MunicipalityEntry(MunicipalityCode("343072"), "広島県", "熊野町", "ﾋﾛｼﾏｹﾝ", "ｸﾏﾉﾁｮｳ"),
    "343099": MunicipalityEntry(MunicipalityCode("343099"), "広島県", "坂町", "ﾋﾛｼﾏｹﾝ", "ｻｶﾁｮｳ"),
    "343684": MunicipalityEntry(MunicipalityCode("343684"), "広島県", "安芸太田町", "ﾋﾛｼﾏｹﾝ", "ｱｷｵｵﾀﾁｮｳ"),
    "343692": MunicipalityEntry(MunicipalityCode("343692"), "広島県", "北広島町", "ﾋﾛｼﾏｹﾝ", "ｷﾀﾋﾛｼﾏﾁｮｳ"),
    "344311": MunicipalityEntry(MunicipalityCode("344311"), "広島県", "大崎上島町", "ﾋﾛｼﾏｹﾝ", "ｵｵｻｷｶﾐｼﾞﾏﾁｮｳ"),
    "344621": MunicipalityEntry(MunicipalityCode("344621"), "広島県", "世羅町", "ﾋﾛｼﾏｹﾝ", "ｾﾗﾁｮｳ"),
    "345458": MunicipalityEntry(MunicipalityCode("345458"), "広島県", "神石高原町", "ﾋﾛｼﾏｹﾝ", "ｼﾞﾝｾｷｺｳｹﾞﾝﾁｮｳ"),
    "350001": MunicipalityEntry(MunicipalityCode("350001"), "山口県", "", "ﾔﾏｸﾞﾁｹﾝ", ""),
    "352012": MunicipalityEntry(MunicipalityCode("352012"), "山口県", "下関市", "ﾔﾏｸﾞﾁｹﾝ", "ｼﾓﾉｾｷｼ"),
    "352021": MunicipalityEntry(MunicipalityCode("352021"), "山口県", "宇部市", "ﾔﾏｸﾞﾁｹﾝ", "ｳﾍﾞｼ"),
    "352039": MunicipalityEntry(MunicipalityCode("352039"), "山口県", "山口市", "ﾔﾏｸﾞﾁｹﾝ", "ﾔﾏｸﾞﾁｼ"),
    "352047": MunicipalityEntry(MunicipalityCode("352047"), "山口県", "萩市", "ﾔﾏｸﾞﾁｹﾝ", "ﾊｷﾞｼ"),
    "352063": MunicipalityEntry(MunicipalityCode("352063"), "山口県", "防府市", "ﾔﾏｸﾞﾁｹﾝ", "ﾎｳﾌｼ"),
    "352071": MunicipalityEntry(MunicipalityCode("352071"), "山口県", "下松市", "ﾔﾏｸﾞﾁｹﾝ", "ｸﾀﾞﾏﾂｼ"),
    "352080": MunicipalityEntry(MunicipalityCode("352080"), "山口県", "岩国市", "ﾔﾏｸﾞﾁｹﾝ", "ｲﾜｸﾆｼ"),
    "352101": MunicipalityEntry(MunicipalityCode("352101"), "山口県", "光市", "ﾔﾏｸﾞﾁｹﾝ", "ﾋｶﾘｼ"),
    "352110": MunicipalityEntry(MunicipalityCode("352110"), "山口県", "長門市", "ﾔﾏｸﾞﾁｹﾝ", "ﾅｶﾞﾄｼ"),
    "352128": MunicipalityEntry(MunicipalityCode("352128"), "山口県", "柳井市", "ﾔﾏｸﾞﾁｹﾝ", "ﾔﾅｲｼ"),
    "352136": MunicipalityEntry(MunicipalityCode("352136"), "山口県", "美祢市", "ﾔﾏｸﾞﾁｹﾝ", "ﾐﾈｼ"),
    "352152": MunicipalityEntry(MunicipalityCode("352152"), "山口県", "周南市", "ﾔﾏｸﾞﾁｹﾝ", "ｼｭｳﾅﾝｼ"),
    "352161": MunicipalityEntry(MunicipalityCode("352161"), "山口県", "山陽小野田市", "ﾔﾏｸﾞﾁｹﾝ", "ｻﾝﾖｳｵﾉﾀﾞｼ"),
    "353051": MunicipalityEntry(MunicipalityCode("353051"), "山口県", "周防大島町", "ﾔﾏｸﾞﾁｹﾝ", "ｽｵｳｵｵｼﾏﾁｮｳ"),
    "353213": MunicipalityEntry(MunicipalityCode("353213"), "山口県", "和木町", "ﾔﾏｸﾞﾁｹﾝ", "ﾜｷﾁｮｳ"),
    "353418": MunicipalityEntry(MunicipalityCode("353418"), "山口県", "上関町", "ﾔﾏｸﾞﾁｹﾝ", "ｶﾐﾉｾｷﾁｮｳ"),
    "353434": MunicipalityEntry(MunicipalityCode("353434"), "山口県", "田布施町", "ﾔﾏｸﾞﾁｹﾝ", "ﾀﾌﾞｾﾁｮｳ"),
    "353442": MunicipalityEntry(MunicipalityCode("353442"), "山口県", "平生町", "ﾔﾏｸﾞﾁｹﾝ", "ﾋﾗｵﾁｮｳ"),
    "355020": MunicipalityEntry(MunicipalityCode("355020"), "山口県", "阿武町", "ﾔﾏｸﾞﾁｹﾝ", "ｱﾌﾞﾁｮｳ"),
    "360007": MunicipalityEntry(MunicipalityCode("360007"), "徳島県", "", "ﾄｸｼﾏｹﾝ", ""),
    "362018": MunicipalityEntry(MunicipalityCode("362018"), "徳島県", "徳島市", "ﾄｸｼﾏｹﾝ", "ﾄｸｼﾏｼ"),
    "362026": MunicipalityEntry(MunicipalityCode("362026"), "徳島県", "鳴門市", "ﾄｸｼﾏｹﾝ", "ﾅﾙﾄｼ"),
    "362034": MunicipalityEntry(MunicipalityCode("362034"), "徳島県", "小松島市", "ﾄｸｼﾏｹﾝ", "ｺﾏﾂｼﾏｼ"),
    "362042": MunicipalityEntry(MunicipalityCode("362042"), "徳島県", "阿南市", "ﾄｸｼﾏｹﾝ", "ｱﾅﾝｼ"),
    "362051": MunicipalityEntry(MunicipalityCode("362051"), "徳島県", "吉野川市", "ﾄｸｼﾏｹﾝ", "ﾖｼﾉｶﾞﾜｼ"),
    "362069": MunicipalityEntry(MunicipalityCode("362069"), "徳島県", "阿波市", "ﾄｸｼﾏｹﾝ", "ｱﾜｼ"),
    "362077": MunicipalityEntry(MunicipalityCode("362077"), "徳島県", "美馬市", "ﾄｸｼﾏｹﾝ", "ﾐﾏｼ"),
    "362085": MunicipalityEntry(MunicipalityCode("362085"), "徳島県", "三好市", "ﾄｸｼﾏｹﾝ", "ﾐﾖｼｼ"),
    "363014": MunicipalityEntry(MunicipalityCode("363014"), "徳島県", "勝浦町", "ﾄｸｼﾏｹﾝ", "ｶﾂｳﾗﾁｮｳ"),
    "363022": MunicipalityEntry(MunicipalityCode("363022"), "徳島県", "上勝町", "ﾄｸｼﾏｹﾝ", "ｶﾐｶﾂﾁｮｳ"),
    "363219": MunicipalityEntry(MunicipalityCode("363219"), "徳島県", "佐那河内村", "ﾄｸｼﾏｹﾝ", "ｻﾅｺﾞｳﾁｿﾝ"),
    "363413": MunicipalityEntry(MunicipalityCode("363413"), "徳島県", "石井町", "ﾄｸｼﾏｹﾝ", "ｲｼｲﾁｮｳ"),
    "363421": MunicipalityEntry(MunicipalityCode("363421"), "徳島県", "神山町", "ﾄｸｼﾏｹﾝ", "ｶﾐﾔﾏﾁｮｳ"),
    "363685": MunicipalityEntry(MunicipalityCode("363685"), "徳島県", "那賀町", "ﾄｸｼﾏｹﾝ", "ﾅｶﾁｮｳ"),
    "363839": MunicipalityEntry(MunicipalityCode("363839"), "徳島県", "牟岐町", "ﾄｸｼﾏｹﾝ", "ﾑｷﾞﾁｮｳ"),
    "363871": MunicipalityEntry(MunicipalityCode("363871"), "徳島県", "美波町", "ﾄｸｼﾏｹﾝ", "ﾐﾅﾐﾁｮｳ"),
    "363880": MunicipalityEntry(MunicipalityCode("363880"), "徳島県", "海陽町", "ﾄｸｼﾏｹﾝ", "ｶｲﾖｳﾁｮｳ"),
    "364011": MunicipalityEntry(MunicipalityCode("364011"), "徳島県", "松茂町", "ﾄｸｼﾏｹﾝ", "ﾏﾂｼｹﾞﾁｮｳ"),
    "364029": MunicipalityEntry(MunicipalityCode("364029"), "徳島県", "北島町", "ﾄｸｼﾏｹﾝ", "ｷﾀｼﾞﾏﾁｮｳ"),
    "364037": MunicipalityEntry(MunicipalityCode("364037"), "徳島県", "藍住町", "ﾄｸｼﾏｹﾝ", "ｱｲｽﾞﾐﾁｮｳ"),
    "364045": MunicipalityEntry(MunicipalityCode("364045"), "徳島県", "板野町", "ﾄｸｼﾏｹﾝ", "ｲﾀﾉﾁｮｳ"),
    "364053": MunicipalityEntry(MunicipalityCode("364053"), "徳島県", "上板町", "ﾄｸｼﾏｹﾝ", "ｶﾐｲﾀﾁｮｳ"),
    "364681": MunicipalityEntry(MunicipalityCode("364681"), "徳島県", "つるぎ町", "ﾄｸｼﾏｹﾝ", "ﾂﾙｷﾞﾁｮｳ"),
    "364894": MunicipalityEntry(MunicipalityCode("364894"), "徳島県", "東みよし町", "ﾄｸｼﾏｹﾝ", "ﾋｶﾞｼﾐﾖｼﾁｮｳ"),
    "370002": MunicipalityEntry(MunicipalityCode("370002"), "香川県", "", "ｶｶﾞﾜｹﾝ", ""),
    "372013": MunicipalityEntry(MunicipalityCode("372013"), "香川県", "高松市", "ｶｶﾞﾜｹﾝ", "ﾀｶﾏﾂｼ"),
    "372021": MunicipalityEntry(MunicipalityCode("372021"), "香川県", "丸亀市", "ｶｶﾞﾜｹﾝ", "ﾏﾙｶﾞﾒｼ"),
    "372030": MunicipalityEntry(MunicipalityCode("372030"), "香川県", "坂出市", "ｶｶﾞﾜｹﾝ", "ｻｶｲﾃﾞｼ"),
    "372048": MunicipalityEntry(MunicipalityCode("372048"), "香川県", "善通寺市", "ｶｶﾞﾜｹﾝ", "ｾﾞﾝﾂｳｼﾞｼ"),
    "372056": MunicipalityEntry(MunicipalityCode("372056"), "香川県", "観音寺市", "ｶｶﾞﾜｹﾝ", "ｶﾝｵﾝｼﾞｼ"),
    "372064": MunicipalityEntry(MunicipalityCode("372064"), "香川県", "さぬき市", "ｶｶﾞﾜｹﾝ", "ｻﾇｷｼ"),
    "372072": MunicipalityEntry(MunicipalityCode("372072"), "香川県", "東かがわ市", "ｶｶﾞﾜｹﾝ", "ﾋｶﾞｼｶｶﾞﾜｼ"),
    "372081": MunicipalityEntry(MunicipalityCode("372081"), "香川県", "三豊市", "ｶｶﾞﾜｹﾝ", "ﾐﾄﾖｼ"),
    "373222": MunicipalityEntry(MunicipalityCode("373222"), "香川県", "土庄町", "ｶｶﾞﾜｹﾝ", "ﾄﾉｼｮｳﾁｮｳ"),
    "373249": MunicipalityEntry(MunicipalityCode("373249"), "香川県", "小豆島町", "ｶｶﾞﾜｹﾝ", "ｼｮｳﾄﾞｼﾏﾁｮｳ"),
    "373419": MunicipalityEntry(MunicipalityCode("373419"), "香川県", "三木町", "ｶｶﾞﾜｹﾝ", "ﾐｷﾁｮｳ"),
    "373648": MunicipalityEntry(MunicipalityCode("373648"), "香川県", "直島町", "ｶｶﾞﾜｹﾝ", "ﾅｵｼﾏﾁｮｳ"),
    "373869": MunicipalityEntry(MunicipalityCode("373869"), "香川県", "宇多津町", "ｶｶﾞﾜｹﾝ", "ｳﾀﾂﾞﾁｮｳ"),
    "373877": MunicipalityEntry(MunicipalityCode("373877"), "香川県", "綾川町", "ｶｶﾞﾜｹﾝ", "ｱﾔｶﾞﾜﾁｮｳ"),
    "374032": MunicipalityEntry(MunicipalityCode("374032"), "香川県", "琴平町", "ｶｶﾞﾜｹﾝ", "ｺﾄﾋﾗﾁｮｳ"),
    "374041": MunicipalityEntry(MunicipalityCode("374041"), "香川県", "多度津町", "ｶｶﾞﾜｹﾝ", "ﾀﾄﾞﾂﾁｮｳ"),
    "374067": MunicipalityEntry(MunicipalityCode("374067"), "香川県", "まんのう町", "ｶｶﾞﾜｹﾝ", "ﾏﾝﾉｳﾁｮｳ"),
    "380008": MunicipalityEntry(MunicipalityCode("380008"), "愛媛県", "", "ｴﾋﾒｹﾝ", ""),
    "382019": MunicipalityEntry(MunicipalityCode("382019"), "愛媛県", "松山市", "ｴﾋﾒｹﾝ", "ﾏﾂﾔﾏｼ"),
    "382027": MunicipalityEntry(MunicipalityCode("382027"), "愛媛県", "今治市", "ｴﾋﾒｹﾝ", "ｲﾏﾊﾞﾘｼ"),
    "382035": MunicipalityEntry(MunicipalityCode("382035"), "愛媛県", "宇和島市", "ｴﾋﾒｹﾝ", "ｳﾜｼﾞﾏｼ"),
    "382043": MunicipalityEntry(MunicipalityCode("382043"), "愛媛県", "八幡浜市", "ｴﾋﾒｹﾝ", "ﾔﾜﾀﾊﾏｼ"),
    "382051": MunicipalityEntry(MunicipalityCode("382051"), "愛媛県", "新居浜市", "ｴﾋﾒｹﾝ", "ﾆｲﾊﾏｼ"),
    "382060": MunicipalityEntry(MunicipalityCode("382060"), "愛媛県", "西条市", "ｴﾋﾒｹﾝ", "ｻｲｼﾞｮｳｼ"),
    "382078": MunicipalityEntry(MunicipalityCode("382078"), "愛媛県", "大洲市", "ｴﾋﾒｹﾝ", "ｵｵｽﾞｼ"),
    "382108": MunicipalityEntry(MunicipalityCode("382108"), "愛媛県", "伊予市", "ｴﾋﾒｹﾝ", "ｲﾖｼ"),
    "382132": MunicipalityEntry(MunicipalityCode("382132"), "愛媛県", "四国中央市", "ｴﾋﾒｹﾝ", "ｼｺｸﾁｭｳｵｳｼ"),
    "382141": MunicipalityEntry(MunicipalityCode("382141"), "愛媛県", "西予市", "ｴﾋﾒｹﾝ", "ｾｲﾖｼ"),
    "382159": MunicipalityEntry(MunicipalityCode("382159"), "愛媛県", "東温市", "ｴﾋﾒｹﾝ", "ﾄｳｵﾝｼ"),
    "383562": MunicipalityEntry(MunicipalityCode("383562"), "愛媛県", "上島町", "ｴﾋﾒｹﾝ", "ｶﾐｼﾞﾏﾁｮｳ"),
    "383864": MunicipalityEntry(MunicipalityCode("383864"), "愛媛県", "久万高原町", "ｴﾋﾒｹﾝ", "ｸﾏｺｳｹﾞﾝﾁｮｳ"),
    "384011": MunicipalityEntry(MunicipalityCode("384011"), "愛媛県", "松前町", "ｴﾋﾒｹﾝ", "ﾏｻｷﾁｮｳ"),
    "384020": MunicipalityEntry(MunicipalityCode("384020"), "愛媛県", "砥部町", "ｴﾋﾒｹﾝ", "ﾄﾍﾞﾁｮｳ"),
    "384224": MunicipalityEntry(MunicipalityCode("384224"), "愛媛県", "内子町", "ｴﾋﾒｹﾝ", "ｳﾁｺﾁｮｳ"),
    "384429": MunicipalityEntry(MunicipalityCode("384429"), "愛媛県", "伊方町", "ｴﾋﾒｹﾝ", "ｲｶﾀﾁｮｳ"),
    "384844": MunicipalityEntry(MunicipalityCode("384844"), "愛媛県", "松野町", "ｴﾋﾒｹﾝ", "ﾏﾂﾉﾁｮｳ"),
    "384887": MunicipalityEntry(MunicipalityCode("384887"), "愛媛県", "鬼北町", "ｴﾋﾒｹﾝ", "ｷﾎｸﾁｮｳ"),
    "385069": MunicipalityEntry(MunicipalityCode("385069"), "愛媛県", "愛南町", "ｴﾋﾒｹﾝ", "ｱｲﾅﾝﾁｮｳ"),
    "390003": MunicipalityEntry(MunicipalityCode("390003"), "高知県", "", "ｺｳﾁｹﾝ", ""),
    "392014": MunicipalityEntry(MunicipalityCode("392014"), "高知県", "高知市", "ｺｳﾁｹﾝ", "ｺｳﾁｼ"),
    "392022": MunicipalityEntry(MunicipalityCode("392022"), "高知県", "室戸市", "ｺｳﾁｹﾝ", "ﾑﾛﾄｼ"),
    "392031": MunicipalityEntry(MunicipalityCode("392031"), "高知県", "安芸市", "ｺｳﾁｹﾝ", "ｱｷｼ"),
    "392049": MunicipalityEntry(MunicipalityCode("392049"), "高知県", "南国市", "ｺｳﾁｹﾝ", "ﾅﾝｺｸｼ"),
    "392057": MunicipalityEntry(MunicipalityCode("392057"), "高知県", "土佐市", "ｺｳﾁｹﾝ", "ﾄｻｼ"),
    "392065": MunicipalityEntry(MunicipalityCode("392065"), "高知県", "須崎市", "ｺｳﾁｹﾝ", "ｽｻｷｼ"),
    "392081": MunicipalityEntry(MunicipalityCode("392081"), "高知県", "宿毛市", "ｺｳﾁｹﾝ", "ｽｸﾓｼ"),
    "392090": MunicipalityEntry(MunicipalityCode("392090"), "高知県", "土佐清水市", "ｺｳﾁｹﾝ", "ﾄｻｼﾐｽﾞｼ"),
    "392103": MunicipalityEntry(MunicipalityCode("392103"), "高知県", "四万十市", "ｺｳﾁｹﾝ", "ｼﾏﾝﾄｼ"),
    "392111": MunicipalityEntry(MunicipalityCode("392111"), "高知県", "香南市", "ｺｳﾁｹﾝ", "ｺｳﾅﾝｼ"),
    "392120": MunicipalityEntry(MunicipalityCode("392120"), "高知県", "香美市", "ｺｳﾁｹﾝ", "ｶﾐｼ"),
    "393011": MunicipalityEntry(MunicipalityCode("393011"), "高知県", "東洋町", "ｺｳﾁｹﾝ", "ﾄｳﾖｳﾁｮｳ"),
    "393029": MunicipalityEntry(MunicipalityCode("393029"), "高知県", "奈半利町", "ｺｳﾁｹﾝ", "ﾅﾊﾘﾁｮｳ"),
    "393037": MunicipalityEntry(MunicipalityCode("393037"), "高知県", "田野町", "ｺｳﾁｹﾝ", "ﾀﾉﾁｮｳ"),
    "393045": MunicipalityEntry(MunicipalityCode("393045"), "高知県", "安田町", "ｺｳﾁｹﾝ", "ﾔｽﾀﾞﾁｮｳ"),
    "393053": MunicipalityEntry(MunicipalityCode("393053"), "高知県", "北川村", "ｺｳﾁｹﾝ", "ｷﾀｶﾞﾜﾑﾗ"),
    "393061": MunicipalityEntry(MunicipalityCode("393061"), "高知県", "馬路村", "ｺｳﾁｹﾝ", "ｳﾏｼﾞﾑﾗ"),
    "393070": MunicipalityEntry(MunicipalityCode("393070"), "高知県", "芸西村", "ｺｳﾁｹﾝ", "ｹﾞｲｾｲﾑﾗ"),
    "393410": MunicipalityEntry(MunicipalityCode("393410"), "高知県", "本山町", "ｺｳﾁｹﾝ", "ﾓﾄﾔﾏﾁｮｳ"),
    "393444": MunicipalityEntry(MunicipalityCode("393444"), "高知県", "大豊町", "ｺｳﾁｹﾝ", "ｵｵﾄﾖﾁｮｳ"),
    "393631": MunicipalityEntry(MunicipalityCode("393631"), "高知県", "土佐町", "ｺｳﾁｹﾝ", "ﾄｻﾁｮｳ"),
    "393649": MunicipalityEntry(MunicipalityCode("393649"), "高知県", "大川村", "ｺｳﾁｹﾝ", "ｵｵｶﾜﾑﾗ"),
    "393860": MunicipalityEntry(MunicipalityCode("393860"), "高知県", "いの町", "ｺｳﾁｹﾝ", "ｲﾉﾁｮｳ"),
    "393878": MunicipalityEntry(MunicipalityCode("393878"), "高知県", "仁淀川町", "ｺｳﾁｹﾝ", "ﾆﾖﾄﾞｶﾞﾜﾁｮｳ"),
    "394017": MunicipalityEntry(MunicipalityCode("394017"), "高知県", "中土佐町", "ｺｳﾁｹﾝ", "ﾅｶﾄｻﾁｮｳ"),
    "394025": MunicipalityEntry(MunicipalityCode("394025"), "高知県", "佐川町", "ｺｳﾁｹﾝ", "ｻｶﾜﾁｮｳ"),
    "394033": MunicipalityEntry(MunicipalityCode("394033"), "高知県", "越知町", "ｺｳﾁｹﾝ", "ｵﾁﾁｮｳ"),
    "394050": MunicipalityEntry(MunicipalityCode("394050"), "高知県", "梼原町", "ｺｳﾁｹﾝ", "ﾕｽﾊﾗﾁｮｳ"),
    "394106": MunicipalityEntry(MunicipalityCode("394106"), "高知県", "日高村", "ｺｳﾁｹﾝ", "ﾋﾀﾞｶﾑﾗ"),
    "394114": MunicipalityEntry(MunicipalityCode("394114"), "高知県", "津野町", "ｺｳﾁｹﾝ", "ﾂﾉﾁｮｳ"),
    "394122": MunicipalityEntry(MunicipalityCode("394122"), "高知県", "四万十町", "ｺｳﾁｹﾝ", "ｼﾏﾝﾄﾁｮｳ"),
    "394246": MunicipalityEntry(MunicipalityCode("394246"), "高知県", "大月町", "ｺｳﾁｹﾝ", "ｵｵﾂｷﾁｮｳ"),
    "394271": MunicipalityEntry(MunicipalityCode("394271"), "高知県", "三原村", "ｺｳﾁｹﾝ", "ﾐﾊﾗﾑﾗ"),
    "394289": MunicipalityEntry(MunicipalityCode("394289"), "高知県", "黒潮町", "ｺｳﾁｹﾝ", "ｸﾛｼｵﾁｮｳ"),
    "400009": MunicipalityEntry(MunicipalityCode("400009"), "福岡県", "", "ﾌｸｵｶｹﾝ", ""),
    "401005": MunicipalityEntry(MunicipalityCode("401005"), "福岡県", "北九州市", "ﾌｸｵｶｹﾝ", "ｷﾀｷｭｳｼｭｳｼ"),
    "401307": MunicipalityEntry(MunicipalityCode("401307"), "福岡県", "福岡市", "ﾌｸｵｶｹﾝ", "ﾌｸｵｶｼ"),
    "402028": MunicipalityEntry(MunicipalityCode("402028"), "福岡県", "大牟田市", "ﾌｸｵｶｹﾝ", "ｵｵﾑﾀｼ"),
    "402036": MunicipalityEntry(MunicipalityCode("402036"), "福岡県", "久留米市", "ﾌｸｵｶｹﾝ", "ｸﾙﾒｼ"),
    "402044": MunicipalityEntry(MunicipalityCode("402044"), "福岡県", "直方市", "ﾌｸｵｶｹﾝ", "ﾉｵｶﾞﾀｼ"),
    "402052": MunicipalityEntry(MunicipalityCode("402052"), "福岡県", "飯塚市", "ﾌｸｵｶｹﾝ", "ｲｲﾂﾞｶｼ"),
    "402061": MunicipalityEntry(MunicipalityCode("402061"), "福岡県", "田川市", "ﾌｸｵｶｹﾝ", "ﾀｶﾞﾜｼ"),
    "402079": MunicipalityEntry(MunicipalityCode("402079"), "福岡県", "柳川市", "ﾌｸｵｶｹﾝ", "ﾔﾅｶﾞﾜｼ"),
    "402109": MunicipalityEntry(MunicipalityCode("402109"), "福岡県", "八女市", "ﾌｸｵｶｹﾝ", "ﾔﾒｼ"),
    "402117": MunicipalityEntry(MunicipalityCode("402117"), "福岡県", "筑後市", "ﾌｸｵｶｹﾝ", "ﾁｸｺﾞｼ"),
    "402125": MunicipalityEntry(MunicipalityCode("402125"), "福岡県", "大川市", "ﾌｸｵｶｹﾝ", "ｵｵｶﾜｼ"),
    "402133": MunicipalityEntry(MunicipalityCode("402133"), "福岡県", "行橋市", "ﾌｸｵｶｹﾝ", "ﾕｸﾊｼｼ"),
    "402141": MunicipalityEntry(MunicipalityCode("402141"), "福岡県", "豊前市", "ﾌｸｵｶｹﾝ", "ﾌﾞｾﾞﾝｼ"),
    "402150": MunicipalityEntry(MunicipalityCode("402150"), "福岡県", "中間市", "ﾌｸｵｶｹﾝ", "ﾅｶﾏｼ"),
    "402168": MunicipalityEntry(MunicipalityCode("402168"), "福岡県", "小郡市", "ﾌｸｵｶｹﾝ", "ｵｺﾞｵﾘｼ"),
    "402176": MunicipalityEntry(MunicipalityCode("402176"), "福岡県", "筑紫野市", "ﾌｸｵｶｹﾝ", "ﾁｸｼﾉｼ"),
    "402184": MunicipalityEntry(MunicipalityCode("402184"), "福岡県", "春日市", "ﾌｸｵｶｹﾝ", "ｶｽｶﾞｼ"),
    "402192": MunicipalityEntry(MunicipalityCode("402192"), "福岡県", "大野城市", "ﾌｸｵｶｹﾝ", "ｵｵﾉｼﾞｮｳｼ"),
    "402206": MunicipalityEntry(MunicipalityCode("402206"), "福岡県", "宗像市", "ﾌｸｵｶｹﾝ", "ﾑﾅｶﾀｼ"),
    "402214": MunicipalityEntry(MunicipalityCode("402214"), "福岡県", "太宰府市", "ﾌｸｵｶｹﾝ", "ﾀﾞｻﾞｲﾌｼ"),
    "402231": MunicipalityEntry(MunicipalityCode("402231"), "福岡県", "古賀市", "ﾌｸｵｶｹﾝ", "ｺｶﾞｼ"),
    "402249": MunicipalityEntry(MunicipalityCode("402249"), "福岡県", "福津市", "ﾌｸｵｶｹﾝ", "ﾌｸﾂｼ"),
    "402257": MunicipalityEntry(MunicipalityCode("402257"), "福岡県", "うきは市", "ﾌｸｵｶｹﾝ", "ｳｷﾊｼ"),
    "402265": MunicipalityEntry(MunicipalityCode("402265"), "福岡県", "宮若市", "ﾌｸｵｶｹﾝ", "ﾐﾔﾜｶｼ"),
    "402273": MunicipalityEntry(MunicipalityCode("402273"), "福岡県", "嘉麻市", "ﾌｸｵｶｹﾝ", "ｶﾏｼ"),
    "402281": MunicipalityEntry(MunicipalityCode("402281"), "福岡県", "朝倉市", "ﾌｸｵｶｹﾝ", "ｱｻｸﾗｼ"),
    "402290": MunicipalityEntry(MunicipalityCode("402290"), "福岡県", "みやま市", "ﾌｸｵｶｹﾝ", "ﾐﾔﾏｼ"),
    "402303": MunicipalityEntry(MunicipalityCode("402303"), "福岡県", "糸島市", "ﾌｸｵｶｹﾝ", "ｲﾄｼﾏｼ"),
    "402311": MunicipalityEntry(MunicipalityCode("402311"), "福岡県", "那珂川市", "ﾌｸｵｶｹﾝ", "ﾅｶｶﾞﾜｼ"),
    "403415": MunicipalityEntry(MunicipalityCode("403415"), "福岡県", "宇美町", "ﾌｸｵｶｹﾝ", "ｳﾐﾏﾁ"),
    "403423": MunicipalityEntry(MunicipalityCode("403423"), "福岡県", "篠栗町", "ﾌｸｵｶｹﾝ", "ｻｻｸﾞﾘﾏﾁ"),
    "403431": MunicipalityEntry(MunicipalityCode("403431"), "福岡県", "志免町", "ﾌｸｵｶｹﾝ", "ｼﾒﾏﾁ"),
    "403440": MunicipalityEntry(MunicipalityCode("403440"), "福岡県", "須恵町", "ﾌｸｵｶｹﾝ", "ｽｴﾏﾁ"),
    "403458": MunicipalityEntry(MunicipalityCode("403458"), "福岡県", "新宮町", "ﾌｸｵｶｹﾝ", "ｼﾝｸﾞｳﾏﾁ"),
    "403482": MunicipalityEntry(MunicipalityCode("403482"), "福岡県", "久山町", "ﾌｸｵｶｹﾝ", "ﾋｻﾔﾏﾏﾁ"),
    "403491": MunicipalityEntry(MunicipalityCode("403491"), "福岡県", "粕屋町", "ﾌｸｵｶｹﾝ", "ｶｽﾔﾏﾁ"),
    "403814": MunicipalityEntry(MunicipalityCode("403814"), "福岡県", "芦屋町", "ﾌｸｵｶｹﾝ", "ｱｼﾔﾏﾁ"),
    "403822": MunicipalityEntry(MunicipalityCode("403822"), "福岡県", "水巻町", "ﾌｸｵｶｹﾝ", "ﾐｽﾞﾏｷﾏﾁ"),
    "403831": MunicipalityEntry(MunicipalityCode("403831"), "福岡県", "岡垣町", "ﾌｸｵｶｹﾝ", "ｵｶｶﾞｷﾏﾁ"),
    "403849": MunicipalityEntry(MunicipalityCode("403849"), "福岡県", "遠賀町", "ﾌｸｵｶｹﾝ", "ｵﾝｶﾞﾁｮｳ"),
    "404012": MunicipalityEntry(MunicipalityCode("404012"), "福岡県", "小竹町", "ﾌｸｵｶｹﾝ", "ｺﾀｹﾏﾁ"),
    "404021": MunicipalityEntry(MunicipalityCode("404021"), "福岡県", "鞍手町", "ﾌｸｵｶｹﾝ", "ｸﾗﾃﾏﾁ"),
    "404217": MunicipalityEntry(MunicipalityCode("404217"), "福岡県", "桂川町", "ﾌｸｵｶｹﾝ", "ｹｲｾﾝﾏﾁ"),
    "404471": MunicipalityEntry(MunicipalityCode("404471"), "福岡県", "筑前町", "ﾌｸｵｶｹﾝ", "ﾁｸｾﾞﾝﾏﾁ"),
    "404489": MunicipalityEntry(MunicipalityCode("404489"), "福岡県", "東峰村", "ﾌｸｵｶｹﾝ", "ﾄｳﾎｳﾑﾗ"),
    "405035": MunicipalityEntry(MunicipalityCode("405035"), "福岡県", "大刀洗町", "ﾌｸｵｶｹﾝ", "ﾀﾁｱﾗｲﾏﾁ"),
    "405221": MunicipalityEntry(MunicipalityCode("405221"), "福岡県", "大木町", "ﾌｸｵｶｹﾝ", "ｵｵｷﾏﾁ"),
    "405442": MunicipalityEntry(MunicipalityCode("405442"), "福岡県", "広川町", "ﾌｸｵｶｹﾝ", "ﾋﾛｶﾜﾏﾁ"),
    "406015": MunicipalityEntry(MunicipalityCode("406015"), "福岡県", "香春町", "ﾌｸｵｶｹﾝ", "ｶﾜﾗﾏﾁ"),
    "406023": MunicipalityEntry(MunicipalityCode("406023"), "福岡県", "添田町", "ﾌｸｵｶｹﾝ", "ｿｴﾀﾞﾏﾁ"),
    "406040": MunicipalityEntry(MunicipalityCode("406040"), "福岡県", "糸田町", "ﾌｸｵｶｹﾝ", "ｲﾄﾀﾞﾏﾁ"),
    "406058": MunicipalityEntry(MunicipalityCode("406058"), "福岡県", "川崎町", "ﾌｸｵｶｹﾝ", "ｶﾜｻｷﾏﾁ"),
    "406082": MunicipalityEntry(MunicipalityCode("406082"), "福岡県", "大任町", "ﾌｸｵｶｹﾝ", "ｵｵﾄｳﾏﾁ"),
    "406091": MunicipalityEntry(MunicipalityCode("406091"), "福岡県", "赤村", "ﾌｸｵｶｹﾝ", "ｱｶﾑﾗ"),
    "406104": MunicipalityEntry(MunicipalityCode("406104"), "福岡県", "福智町", "ﾌｸｵｶｹﾝ", "ﾌｸﾁﾏﾁ"),
    "406210": MunicipalityEntry(MunicipalityCode("406210"), "福岡県", "苅田町", "ﾌｸｵｶｹﾝ", "ｶﾝﾀﾞﾏﾁ"),
    "406252": MunicipalityEntry(MunicipalityCode("406252"), "福岡県", "みやこ町", "ﾌｸｵｶｹﾝ", "ﾐﾔｺﾏﾁ"),
    "406422": MunicipalityEntry(MunicipalityCode("406422"), "福岡県", "吉富町", "ﾌｸｵｶｹﾝ", "ﾖｼﾄﾐﾏﾁ"),
    "406465": MunicipalityEntry(MunicipalityCode("406465"), "福岡県", "上毛町", "ﾌｸｵｶｹﾝ", "ｺｳｹﾞﾏﾁ"),
    "406473": MunicipalityEntry(MunicipalityCode("406473"), "福岡県", "築上町", "ﾌｸｵｶｹﾝ", "ﾁｸｼﾞｮｳﾏﾁ"),
    "410004": MunicipalityEntry(MunicipalityCode("410004"), "佐賀県", "", "ｻｶﾞｹﾝ", ""),
    "412015": MunicipalityEntry(MunicipalityCode("412015"), "佐賀県", "佐賀市", "ｻｶﾞｹﾝ", "ｻｶﾞｼ"),
    "412023": MunicipalityEntry(MunicipalityCode("412023"), "佐賀県", "唐津市", "ｻｶﾞｹﾝ", "ｶﾗﾂｼ"),
    "412031": MunicipalityEntry(MunicipalityCode("412031"), "佐賀県", "鳥栖市", "ｻｶﾞｹﾝ", "ﾄｽｼ"),
    "412040": MunicipalityEntry(MunicipalityCode("412040"), "佐賀県", "多久市", "ｻｶﾞｹﾝ", "ﾀｸｼ"),
    "412058": MunicipalityEntry(MunicipalityCode("412058"), "佐賀県", "伊万里市", "ｻｶﾞｹﾝ", "ｲﾏﾘｼ"),
    "412066": MunicipalityEntry(MunicipalityCode("412066"), "佐賀県", "武雄市", "ｻｶﾞｹﾝ", "ﾀｹｵｼ"),
    "412074": MunicipalityEntry(MunicipalityCode("412074"), "佐賀県", "鹿島市", "ｻｶﾞｹﾝ", "ｶｼﾏｼ"),
    "412082": MunicipalityEntry(MunicipalityCode("412082"), "佐賀県", "小城市", "ｻｶﾞｹﾝ", "ｵｷﾞｼ"),
    "412091": MunicipalityEntry(MunicipalityCode("412091"), "佐賀県", "嬉野市", "ｻｶﾞｹﾝ", "ｳﾚｼﾉｼ"),
    "412104": MunicipalityEntry(MunicipalityCode("412104"), "佐賀県", "神埼市", "ｻｶﾞｹﾝ", "ｶﾝｻﾞｷｼ"),
    "413275": MunicipalityEntry(MunicipalityCode("413275"), "佐賀県", "吉野ヶ里町", "ｻｶﾞｹﾝ", "ﾖｼﾉｶﾞﾘﾁｮｳ"),
    "413411": MunicipalityEntry(MunicipalityCode("413411"), "佐賀県", "基山町", "ｻｶﾞｹﾝ", "ｷﾔﾏﾁｮｳ"),
    "413453": MunicipalityEntry(MunicipalityCode("413453"), "佐賀県", "上峰町", "ｻｶﾞｹﾝ", "ｶﾐﾐﾈﾁｮｳ"),
    "413461": MunicipalityEntry(MunicipalityCode("413461"), "佐賀県", "みやき町", "ｻｶﾞｹﾝ", "ﾐﾔｷﾁｮｳ"),
    "413879": MunicipalityEntry(MunicipalityCode("413879"), "佐賀県", "玄海町", "ｻｶﾞｹﾝ", "ｹﾞﾝｶｲﾁｮｳ"),
    "414018": MunicipalityEntry(MunicipalityCode("414018"), "佐賀県", "有田町", "ｻｶﾞｹﾝ", "ｱﾘﾀﾁｮｳ"),
    "414239": MunicipalityEntry(MunicipalityCode("414239"), "佐賀県", "大町町", "ｻｶﾞｹﾝ", "ｵｵﾏﾁﾁｮｳ"),
    "414247": MunicipalityEntry(MunicipalityCode("414247"), "佐賀県", "江北町", "ｻｶﾞｹﾝ", "ｺｳﾎｸﾏﾁ"),
    "414255": MunicipalityEntry(MunicipalityCode("414255"), "佐賀県", "白石町", "ｻｶﾞｹﾝ", "ｼﾛｲｼﾁｮｳ"),
    "414417": MunicipalityEntry(MunicipalityCode("414417"), "佐賀県", "太良町", "ｻｶﾞｹﾝ", "ﾀﾗﾁｮｳ"),
    "420000": MunicipalityEntry(MunicipalityCode("420000"), "長崎県", "", "ﾅｶﾞｻｷｹﾝ", ""),
    "422011": MunicipalityEntry(MunicipalityCode("422011"), "長崎県", "長崎市", "ﾅｶﾞｻｷｹﾝ", "ﾅｶﾞｻｷｼ"),
    "422029": MunicipalityEntry(MunicipalityCode("422029"), "長崎県", "佐世保市", "ﾅｶﾞｻｷｹﾝ", "ｻｾﾎﾞｼ"),
    "422037": MunicipalityEntry(MunicipalityCode("422037"), "長崎県", "島原市", "ﾅｶﾞｻｷｹﾝ", "ｼﾏﾊﾞﾗｼ"),
    "422045": MunicipalityEntry(MunicipalityCode("422045"), "長崎県", "諫早市", "ﾅｶﾞｻｷｹﾝ", "ｲｻﾊﾔｼ"),
    "422053": MunicipalityEntry(MunicipalityCode("422053"), "長崎県", "大村市", "ﾅｶﾞｻｷｹﾝ", "ｵｵﾑﾗｼ"),
    "422070": MunicipalityEntry(MunicipalityCode("422070"), "長崎県", "平戸市", "ﾅｶﾞｻｷｹﾝ", "ﾋﾗﾄﾞｼ"),
    "422088": MunicipalityEntry(MunicipalityCode("422088"), "長崎県", "松浦市", "ﾅｶﾞｻｷｹﾝ", "ﾏﾂｳﾗｼ"),
    "422096": MunicipalityEntry(MunicipalityCode("422096"), "長崎県", "対馬市", "ﾅｶﾞｻｷｹﾝ", "ﾂｼﾏｼ"),
    "422100": MunicipalityEntry(MunicipalityCode("422100"), "長崎県", "壱岐市", "ﾅｶﾞｻｷｹﾝ", "ｲｷｼ"),
    "422118": MunicipalityEntry(MunicipalityCode("422118"), "長崎県", "五島市", "ﾅｶﾞｻｷｹﾝ", "ｺﾞﾄｳｼ"),
    "422126": MunicipalityEntry(MunicipalityCode("422126"), "長崎県", "西海市", "ﾅｶﾞｻｷｹﾝ", "ｻｲｶｲｼ"),
    "422134": MunicipalityEntry(MunicipalityCode("422134"), "長崎県", "雲仙市", "ﾅｶﾞｻｷｹﾝ", "ｳﾝｾﾞﾝｼ"),
    "422142": MunicipalityEntry(MunicipalityCode("422142"), "長崎県", "南島原市", "ﾅｶﾞｻｷｹﾝ", "ﾐﾅﾐｼﾏﾊﾞﾗｼ"),
    "423076": MunicipalityEntry(MunicipalityCode("423076"), "長崎県", "長与町", "ﾅｶﾞｻｷｹﾝ", "ﾅｶﾞﾖﾁｮｳ"),
    "423084": MunicipalityEntry(MunicipalityCode("423084"), "長崎県", "時津町", "ﾅｶﾞｻｷｹﾝ", "ﾄｷﾞﾂﾁｮｳ"),
    "423211": MunicipalityEntry(MunicipalityCode("423211"), "長崎県", "東彼杵町", "ﾅｶﾞｻｷｹﾝ", "ﾋｶﾞｼｿﾉｷﾞﾁｮｳ"),
    "423220": MunicipalityEntry(MunicipalityCode("423220"), "長崎県", "川棚町", "ﾅｶﾞｻｷｹﾝ", "ｶﾜﾀﾅﾁｮｳ"),
    "423238": MunicipalityEntry(MunicipalityCode("423238"), "長崎県", "波佐見町", "ﾅｶﾞｻｷｹﾝ", "ﾊｻﾐﾁｮｳ"),
    "423831": MunicipalityEntry(MunicipalityCode("423831"), "長崎県", "小値賀町", "ﾅｶﾞｻｷｹﾝ", "ｵﾁﾞｶﾁｮｳ"),
    "423912": MunicipalityEntry(MunicipalityCode("423912"), "長崎県", "佐々町", "ﾅｶﾞｻｷｹﾝ", "ｻｻﾞﾁｮｳ"),
    "424111": MunicipalityEntry(MunicipalityCode("424111"), "長崎県", "新上五島町", "ﾅｶﾞｻｷｹﾝ", "ｼﾝｶﾐｺﾞﾄｳﾁｮｳ"),
    "430005": MunicipalityEntry(MunicipalityCode("430005"), "熊本県", "", "ｸﾏﾓﾄｹﾝ", ""),
    "431001": MunicipalityEntry(MunicipalityCode("431001"), "熊本県", "熊本市", "ｸﾏﾓﾄｹﾝ", "ｸﾏﾓﾄｼ"),
    "432024": MunicipalityEntry(MunicipalityCode("432024"), "熊本県", "八代市", "ｸﾏﾓﾄｹﾝ", "ﾔﾂｼﾛｼ"),
    "432032": MunicipalityEntry(MunicipalityCode("432032"), "熊本県", "人吉市", "ｸﾏﾓﾄｹﾝ", "ﾋﾄﾖｼｼ"),
    "432041": MunicipalityEntry(MunicipalityCode("432041"), "熊本県", "荒尾市", "ｸﾏﾓﾄｹﾝ", "ｱﾗｵｼ"),
    "432059": MunicipalityEntry(MunicipalityCode("432059"), "熊本県", "水俣市", "ｸﾏﾓﾄｹﾝ", "ﾐﾅﾏﾀｼ"),
    "432067": MunicipalityEntry(MunicipalityCode("432067"), "熊本県", "玉名市", "ｸﾏﾓﾄｹﾝ", "ﾀﾏﾅｼ"),
    "432083": MunicipalityEntry(MunicipalityCode("432083"), "熊本県", "山鹿市", "ｸﾏﾓﾄｹﾝ", "ﾔﾏｶﾞｼ"),
    "432105": MunicipalityEntry(MunicipalityCode("432105"), "熊本県", "菊池市", "ｸﾏﾓﾄｹﾝ", "ｷｸﾁｼ"),
    "432113": MunicipalityEntry(MunicipalityCode("432113"), "熊本県", "宇土市", "ｸﾏﾓﾄｹﾝ", "ｳﾄｼ"),
    "432121": MunicipalityEntry(MunicipalityCode("432121"), "熊本県", "上天草市", "ｸﾏﾓﾄｹﾝ", "ｶﾐｱﾏｸｻｼ"),
    "432130": MunicipalityEntry(MunicipalityCode("432130"), "熊本県", "宇城市", "ｸﾏﾓﾄｹﾝ", "ｳｷｼ"),
    "432148": MunicipalityEntry(MunicipalityCode("432148"), "熊本県", "阿蘇市", "ｸﾏﾓﾄｹﾝ", "ｱｿｼ"),
    "432156": MunicipalityEntry(MunicipalityCode("432156"), "熊本県", "天草市", "ｸﾏﾓﾄｹﾝ", "ｱﾏｸｻｼ"),
    "432164": MunicipalityEntry(MunicipalityCode("432164"), "熊本県", "合志市", "ｸﾏﾓﾄｹﾝ", "ｺｳｼｼ"),
    "433489": MunicipalityEntry(MunicipalityCode("433489"), "熊本県", "美里町", "ｸﾏﾓﾄｹﾝ", "ﾐｻﾄﾏﾁ"),
    "433641": MunicipalityEntry(MunicipalityCode("433641"), "熊本県", "玉東町", "ｸﾏﾓﾄｹﾝ", "ｷﾞｮｸﾄｳﾏﾁ"),
    "433675": MunicipalityEntry(MunicipalityCode("433675"), "熊本県", "南関町", "ｸﾏﾓﾄｹﾝ", "ﾅﾝｶﾝﾏﾁ"),
    "433683": MunicipalityEntry(MunicipalityCode("433683"), "熊本県", "長洲町", "ｸﾏﾓﾄｹﾝ", "ﾅｶﾞｽﾏﾁ"),
    "433691": MunicipalityEntry(MunicipalityCode("433691"), "熊本県", "和水町", "ｸﾏﾓﾄｹﾝ", "ﾅｺﾞﾐﾏﾁ"),
    "434035": MunicipalityEntry(MunicipalityCode("434035"), "熊本県", "大津町", "ｸﾏﾓﾄｹﾝ", "ｵｵﾂﾞﾏﾁ"),
    "434043": MunicipalityEntry(MunicipalityCode("434043"), "熊本県", "菊陽町", "ｸﾏﾓﾄｹﾝ", "ｷｸﾖｳﾏﾁ"),
    "434230": MunicipalityEntry(MunicipalityCode("434230"), "熊本県", "南小国町", "ｸﾏﾓﾄｹﾝ", "ﾐﾅﾐｵｸﾞﾆﾏﾁ"),
    "434248": MunicipalityEntry(MunicipalityCode("434248"), "熊本県", "小国町", "ｸﾏﾓﾄｹﾝ", "ｵｸﾞﾆﾏﾁ"),
    "434256": MunicipalityEntry(MunicipalityCode("434256"), "熊本県", "産山村", "ｸﾏﾓﾄｹﾝ", "ｳﾌﾞﾔﾏﾑﾗ"),
    "434281": MunicipalityEntry(MunicipalityCode("434281"), "熊本県", "高森町", "ｸﾏﾓﾄｹﾝ", "ﾀｶﾓﾘﾏﾁ"),
    "434329": MunicipalityEntry(MunicipalityCode("434329"), "熊本県", "西原村", "ｸﾏﾓﾄｹﾝ", "ﾆｼﾊﾗﾑﾗ"),
    "434337": MunicipalityEntry(MunicipalityCode("434337"), "熊本県", "南阿蘇村", "ｸﾏﾓﾄｹﾝ", "ﾐﾅﾐｱｿﾑﾗ"),
    "434418": MunicipalityEntry(MunicipalityCode("434418"), "熊本県", "御船町", "ｸﾏﾓﾄｹﾝ", "ﾐﾌﾈﾏﾁ"),
    "434426": MunicipalityEntry(MunicipalityCode("434426"), "熊本県", "嘉島町", "ｸﾏﾓﾄｹﾝ", "ｶｼﾏﾏﾁ"),
    "434434": MunicipalityEntry(MunicipalityCode("434434"), "熊本県", "益城町", "ｸﾏﾓﾄｹﾝ", "ﾏｼｷﾏﾁ"),
    "434442": MunicipalityEntry(MunicipalityCode("434442"), "熊本県", "甲佐町", "ｸﾏﾓﾄｹﾝ", "ｺｳｻﾏﾁ"),
    "434477": MunicipalityEntry(MunicipalityCode("434477"), "熊本県", "山都町", "ｸﾏﾓﾄｹﾝ", "ﾔﾏﾄﾁｮｳ"),
    "434680": MunicipalityEntry(MunicipalityCode("434680"), "熊本県", "氷川町", "ｸﾏﾓﾄｹﾝ", "ﾋｶﾜﾁｮｳ"),
    "434825": MunicipalityEntry(MunicipalityCode("434825"), "熊本県", "芦北町", "ｸﾏﾓﾄｹﾝ", "ｱｼｷﾀﾏﾁ"),
    "434841": MunicipalityEntry(MunicipalityCode("434841"), "熊本県", "津奈木町", "ｸﾏﾓﾄｹﾝ", "ﾂﾅｷﾞﾏﾁ"),
    "435015": MunicipalityEntry(MunicipalityCode("435015"), "熊本県", "錦町", "ｸﾏﾓﾄｹﾝ", "ﾆｼｷﾏﾁ"),
    "435058": MunicipalityEntry(MunicipalityCode("435058"), "熊本県", "多良木町", "ｸﾏﾓﾄｹﾝ", "ﾀﾗｷﾞﾏﾁ"),
    "435066": MunicipalityEntry(MunicipalityCode("435066"), "熊本県", "湯前町", "ｸﾏﾓﾄｹﾝ", "ﾕﾉﾏｴﾏﾁ"),
    "435074": MunicipalityEntry(MunicipalityCode("435074"), "熊本県", "水上村", "ｸﾏﾓﾄｹﾝ", "ﾐｽﾞｶﾐﾑﾗ"),
    "435104": MunicipalityEntry(MunicipalityCode("435104"), "熊本県", "相良村", "ｸﾏﾓﾄｹﾝ", "ｻｶﾞﾗﾑﾗ"),
    "435112": MunicipalityEntry(MunicipalityCode("435112"), "熊本県", "五木村", "ｸﾏﾓﾄｹﾝ", "ｲﾂｷﾑﾗ"),
    "435121": MunicipalityEntry(MunicipalityCode("435121"), "熊本県", "山江村", "ｸﾏﾓﾄｹﾝ", "ﾔﾏｴﾑﾗ"),
    "435139": MunicipalityEntry(MunicipalityCode("435139"), "熊本県", "球磨村", "ｸﾏﾓﾄｹﾝ", "ｸﾏﾑﾗ"),
    "435147": MunicipalityEntry(MunicipalityCode("435147"), "熊本県", "あさぎり町", "ｸﾏﾓﾄｹﾝ", "ｱｻｷﾞﾘﾁｮｳ"),
    "435317": MunicipalityEntry(MunicipalityCode("435317"), "熊本県", "苓北町", "ｸﾏﾓﾄｹﾝ", "ﾚｲﾎｸﾏﾁ"),
    "440001": MunicipalityEntry(MunicipalityCode("440001"), "大分県", "", "ｵｵｲﾀｹﾝ", ""),
    "442011": MunicipalityEntry(MunicipalityCode("442011"), "大分県", "大分市", "ｵｵｲﾀｹﾝ", "ｵｵｲﾀｼ"),
    "442020": MunicipalityEntry(MunicipalityCode("442020"), "大分県", "別府市", "ｵｵｲﾀｹﾝ", "ﾍﾞｯﾌﾟｼ"),
    "442038": MunicipalityEntry(MunicipalityCode("442038"), "大分県", "中津市", "ｵｵｲﾀｹﾝ", "ﾅｶﾂｼ"),
    "442046": MunicipalityEntry(MunicipalityCode("442046"), "大分県", "日田市", "ｵｵｲﾀｹﾝ", "ﾋﾀｼ"),
    "442054": MunicipalityEntry(MunicipalityCode("442054"), "大分県", "佐伯市", "ｵｵｲﾀｹﾝ", "ｻｲｷｼ"),
    "442062": MunicipalityEntry(MunicipalityCode("442062"), "大分県", "臼杵市", "ｵｵｲﾀｹﾝ", "ｳｽｷｼ"),
    "442071": MunicipalityEntry(MunicipalityCode("442071"), "大分県", "津久見市", "ｵｵｲﾀｹﾝ", "ﾂｸﾐｼ"),
    "442089": MunicipalityEntry(MunicipalityCode("442089"), "大分県", "竹田市", "ｵｵｲﾀｹﾝ", "ﾀｹﾀｼ"),
    "442097": MunicipalityEntry(MunicipalityCode("442097"), "大分県", "豊後高田市", "ｵｵｲﾀｹﾝ", "ﾌﾞﾝｺﾞﾀｶﾀﾞｼ"),
    "442101": MunicipalityEntry(MunicipalityCode("442101"), "大分県", "杵築市", "ｵｵｲﾀｹﾝ", "ｷﾂｷｼ"),
    "442119": MunicipalityEntry(MunicipalityCode("442119"), "大分県", "宇佐市", "ｵｵｲﾀｹﾝ", "ｳｻｼ"),
    "442127": MunicipalityEntry(MunicipalityCode("442127"), "大分県", "豊後大野市", "ｵｵｲﾀｹﾝ", "ﾌﾞﾝｺﾞｵｵﾉｼ"),
    "442135": MunicipalityEntry(MunicipalityCode("442135"), "大分県", "由布市", "ｵｵｲﾀｹﾝ", "ﾕﾌｼ"),
    "442143": MunicipalityEntry(MunicipalityCode("442143"), "大分県", "国東市", "ｵｵｲﾀｹﾝ", "ｸﾆｻｷｼ"),
    "443221": MunicipalityEntry(MunicipalityCode("443221"), "大分県", "姫島村", "ｵｵｲﾀｹﾝ", "ﾋﾒｼﾏﾑﾗ"),
    "443417": MunicipalityEntry(MunicipalityCode("443417"), "大分県", "日出町", "ｵｵｲﾀｹﾝ", "ﾋｼﾞﾏﾁ"),
    "444618": MunicipalityEntry(MunicipalityCode("444618"), "大分県", "九重町", "ｵｵｲﾀｹﾝ", "ｺｺﾉｴﾏﾁ"),
    "444626": MunicipalityEntry(MunicipalityCode("444626"), "大分県", "玖珠町", "ｵｵｲﾀｹﾝ", "ｸｽﾏﾁ"),
    "450006": MunicipalityEntry(MunicipalityCode("450006"), "宮崎県", "", "ﾐﾔｻﾞｷｹﾝ", ""),
    "452017": MunicipalityEntry(MunicipalityCode("452017"), "宮崎県", "宮崎市", "ﾐﾔｻﾞｷｹﾝ", "ﾐﾔｻﾞｷｼ"),
    "452025": MunicipalityEntry(MunicipalityCode("452025"), "宮崎県", "都城市", "ﾐﾔｻﾞｷｹﾝ", "ﾐﾔｺﾉｼﾞｮｳｼ"),
    "452033": MunicipalityEntry(MunicipalityCode("452033"), "宮崎県", "延岡市", "ﾐﾔｻﾞｷｹﾝ", "ﾉﾍﾞｵｶｼ"),
    "452041": MunicipalityEntry(MunicipalityCode("452041"), "宮崎県", "日南市", "ﾐﾔｻﾞｷｹﾝ", "ﾆﾁﾅﾝｼ"),
    "452050": MunicipalityEntry(MunicipalityCode("452050"), "宮崎県", "小林市", "ﾐﾔｻﾞｷｹﾝ", "ｺﾊﾞﾔｼｼ"),
    "452068": MunicipalityEntry(MunicipalityCode("452068"), "宮崎県", "日向市", "ﾐﾔｻﾞｷｹﾝ", "ﾋｭｳｶﾞｼ"),
    "452076": MunicipalityEntry(MunicipalityCode("452076"), "宮崎県", "串間市", "ﾐﾔｻﾞｷｹﾝ", "ｸｼﾏｼ"),
    "452084": MunicipalityEntry(MunicipalityCode("452084"), "宮崎県", "西都市", "ﾐﾔｻﾞｷｹﾝ", "ｻｲﾄｼ"),
    "452092": MunicipalityEntry(MunicipalityCode("452092"), "宮崎県", "えびの市", "ﾐﾔｻﾞｷｹﾝ", "ｴﾋﾞﾉｼ"),
    "453412": MunicipalityEntry(MunicipalityCode("453412"), "宮崎県", "三股町", "ﾐﾔｻﾞｷｹﾝ", "ﾐﾏﾀﾁｮｳ"),
    "453617": MunicipalityEntry(MunicipalityCode("453617"), "宮崎県", "高原町", "ﾐﾔｻﾞｷｹﾝ", "ﾀｶﾊﾙﾁｮｳ"),
    "453820": MunicipalityEntry(MunicipalityCode("453820"), "宮崎県", "国富町", "ﾐﾔｻﾞｷｹﾝ", "ｸﾆﾄﾐﾁｮｳ"),
    "453838": MunicipalityEntry(MunicipalityCode("453838"), "宮崎県", "綾町", "ﾐﾔｻﾞｷｹﾝ", "ｱﾔﾁｮｳ"),
    "454010": MunicipalityEntry(MunicipalityCode("454010"), "宮崎県", "高鍋町", "ﾐﾔｻﾞｷｹﾝ", "ﾀｶﾅﾍﾞﾁｮｳ"),
    "454028": MunicipalityEntry(MunicipalityCode("454028"), "宮崎県", "新富町", "ﾐﾔｻﾞｷｹﾝ", "ｼﾝﾄﾐﾁｮｳ"),
    "454036": MunicipalityEntry(MunicipalityCode("454036"), "宮崎県", "西米良村", "ﾐﾔｻﾞｷｹﾝ", "ﾆｼﾒﾗｿﾝ"),
    "454044": MunicipalityEntry(MunicipalityCode("454044"), "宮崎県", "木城町", "ﾐﾔｻﾞｷｹﾝ", "ｷｼﾞｮｳﾁｮｳ"),
    "454052": MunicipalityEntry(MunicipalityCode("454052"), "宮崎県", "川南町", "ﾐﾔｻﾞｷｹﾝ", "ｶﾜﾐﾅﾐﾁｮｳ"),
    "454061": MunicipalityEntry(MunicipalityCode("454061"), "宮崎県", "都農町", "ﾐﾔｻﾞｷｹﾝ", "ﾂﾉﾁｮｳ"),
    "454214": MunicipalityEntry(MunicipalityCode("454214"), "宮崎県", "門川町", "ﾐﾔｻﾞｷｹﾝ", "ｶﾄﾞｶﾞﾜﾁｮｳ"),
    "454290": MunicipalityEntry(MunicipalityCode("454290"), "宮崎県", "諸塚村", "ﾐﾔｻﾞｷｹﾝ", "ﾓﾛﾂｶｿﾝ"),
    "454303": MunicipalityEntry(MunicipalityCode("454303"), "宮崎県", "椎葉村", "ﾐﾔｻﾞｷｹﾝ", "ｼｲﾊﾞｿﾝ"),
    "454311": MunicipalityEntry(MunicipalityCode("454311"), "宮崎県", "美郷町", "ﾐﾔｻﾞｷｹﾝ", "ﾐｻﾄﾁｮｳ"),
    "454419": MunicipalityEntry(MunicipalityCode("454419"), "宮崎県", "高千穂町", "ﾐﾔｻﾞｷｹﾝ", "ﾀｶﾁﾎﾁｮｳ"),
    "454427": MunicipalityEntry(MunicipalityCode("454427"), "宮崎県", "日之影町", "ﾐﾔｻﾞｷｹﾝ", "ﾋﾉｶｹﾞﾁｮｳ"),
    "454435": MunicipalityEntry(MunicipalityCode("454435"), "宮崎県", "五ヶ瀬町", "ﾐﾔｻﾞｷｹﾝ", "ｺﾞｶｾﾁｮｳ"),
    "460001": MunicipalityEntry(MunicipalityCode("460001"), "鹿児島県", "", "ｶｺﾞｼﾏｹﾝ", ""),
    "462012": MunicipalityEntry(MunicipalityCode("462012"), "鹿児島県", "鹿児島市", "ｶｺﾞｼﾏｹﾝ", "ｶｺﾞｼﾏｼ"),
    "462039": MunicipalityEntry(MunicipalityCode("462039"), "鹿児島県", "鹿屋市", "ｶｺﾞｼﾏｹﾝ", "ｶﾉﾔｼ"),
    "462047": MunicipalityEntry(MunicipalityCode("462047"), "鹿児島県", "枕崎市", "ｶｺﾞｼﾏｹﾝ", "ﾏｸﾗｻﾞｷｼ"),
    "462063": MunicipalityEntry(MunicipalityCode("462063"), "鹿児島県", "阿久根市", "ｶｺﾞｼﾏｹﾝ", "ｱｸﾈｼ"),
    "462080": MunicipalityEntry(MunicipalityCode("462080"), "鹿児島県", "出水市", "ｶｺﾞｼﾏｹﾝ", "ｲｽﾞﾐｼ"),
    "462101": MunicipalityEntry(MunicipalityCode("462101"), "鹿児島県", "指宿市", "ｶｺﾞｼﾏｹﾝ", "ｲﾌﾞｽｷｼ"),
    "462136": MunicipalityEntry(MunicipalityCode("462136"), "鹿児島県", "西之表市", "ｶｺﾞｼﾏｹﾝ", "ﾆｼﾉｵﾓﾃｼ"),
    "462144": MunicipalityEntry(MunicipalityCode("462144"), "鹿児島県", "垂水市", "ｶｺﾞｼﾏｹﾝ", "ﾀﾙﾐｽﾞｼ"),
    "462152": MunicipalityEntry(MunicipalityCode("462152"), "鹿児島県", "薩摩川内市", "ｶｺﾞｼﾏｹﾝ", "ｻﾂﾏｾﾝﾀﾞｲｼ"),
    "462161": MunicipalityEntry(MunicipalityCode("462161"), "鹿児島県", "日置市", "ｶｺﾞｼﾏｹﾝ", "ﾋｵｷｼ"),
    "462179": MunicipalityEntry(MunicipalityCode("462179"), "鹿児島県", "曽於市", "ｶｺﾞｼﾏｹﾝ", "ｿｵｼ"),
    "462187": MunicipalityEntry(MunicipalityCode("462187"), "鹿児島県", "霧島市", "ｶｺﾞｼﾏｹﾝ", "ｷﾘｼﾏｼ"),
    "462195": MunicipalityEntry(MunicipalityCode("462195"), "鹿児島県", "いちき串木野市", "ｶｺﾞｼﾏｹﾝ", "ｲﾁｷｸｼｷﾉｼ"),
    "462209": MunicipalityEntry(MunicipalityCode("462209"), "鹿児島県", "南さつま市", "ｶｺﾞｼﾏｹﾝ", "ﾐﾅﾐｻﾂﾏｼ"),
    "462217": MunicipalityEntry(MunicipalityCode("462217"), "鹿児島県", "志布志市", "ｶｺﾞｼﾏｹﾝ", "ｼﾌﾞｼｼ"),
    "462225": MunicipalityEntry(MunicipalityCode("462225"), "鹿児島県", "奄美市", "ｶｺﾞｼﾏｹﾝ", "ｱﾏﾐｼ"),
    "462233": MunicipalityEntry(MunicipalityCode("462233"), "鹿児島県", "南九州市", "ｶｺﾞｼﾏｹﾝ", "ﾐﾅﾐｷｭｳｼｭｳｼ"),
    "462241": MunicipalityEntry(MunicipalityCode("462241"), "鹿児島県", "伊佐市", "ｶｺﾞｼﾏｹﾝ", "ｲｻｼ"),
    "462250": MunicipalityEntry(MunicipalityCode("462250"), "鹿児島県", "姶良市", "ｶｺﾞｼﾏｹﾝ", "ｱｲﾗｼ"),
    "463035": MunicipalityEntry(MunicipalityCode("463035"), "鹿児島県", "三島村", "ｶｺﾞｼﾏｹﾝ", "ﾐｼﾏﾑﾗ"),
    "463043": MunicipalityEntry(MunicipalityCode("463043"), "鹿児島県", "十島村", "ｶｺﾞｼﾏｹﾝ", "ﾄｼﾏﾑﾗ"),
    "463922": MunicipalityEntry(MunicipalityCode("463922"), "鹿児島県", "さつま町", "ｶｺﾞｼﾏｹﾝ", "ｻﾂﾏﾁｮｳ"),
    "464040": MunicipalityEntry(MunicipalityCode("464040"), "鹿児島県", "長島町", "ｶｺﾞｼﾏｹﾝ", "ﾅｶﾞｼﾏﾁｮｳ"),
    "464520": MunicipalityEntry(MunicipalityCode("464520"), "鹿児島県", "湧水町", "ｶｺﾞｼﾏｹﾝ", "ﾕｳｽｲﾁｮｳ"),
    "464686": MunicipalityEntry(MunicipalityCode("464686"), "鹿児島県", "大崎町", "ｶｺﾞｼﾏｹﾝ", "ｵｵｻｷﾁｮｳ"),
    "464821": MunicipalityEntry(MunicipalityCode("464821"), "鹿児島県", "東串良町", "ｶｺﾞｼﾏｹﾝ", "ﾋｶﾞｼｸｼﾗﾁｮｳ"),
    "464902": MunicipalityEntry(MunicipalityCode("464902"), "鹿児島県", "錦江町", "ｶｺﾞｼﾏｹﾝ", "ｷﾝｺｳﾁｮｳ"),
    "464911": MunicipalityEntry(MunicipalityCode("464911"), "鹿児島県", "南大隅町", "ｶｺﾞｼﾏｹﾝ", "ﾐﾅﾐｵｵｽﾐﾁｮｳ"),
    "464929": MunicipalityEntry(MunicipalityCode("464929"), "鹿児島県", "肝付町", "ｶｺﾞｼﾏｹﾝ", "ｷﾓﾂｷﾁｮｳ"),
    "465011": MunicipalityEntry(MunicipalityCode("465011"), "鹿児島県", "中種子町", "ｶｺﾞｼﾏｹﾝ", "ﾅｶﾀﾈﾁｮｳ"),
    "465020": MunicipalityEntry(MunicipalityCode("465020"), "鹿児島県", "南種子町", "ｶｺﾞｼﾏｹﾝ", "ﾐﾅﾐﾀﾈﾁｮｳ"),
    "465054": MunicipalityEntry(MunicipalityCode("465054"), "鹿児島県", "屋久島町", "ｶｺﾞｼﾏｹﾝ", "ﾔｸｼﾏﾁｮｳ"),
    "465232": MunicipalityEntry(MunicipalityCode("465232"), "鹿児島県", "大和村", "ｶｺﾞｼﾏｹﾝ", "ﾔﾏﾄｿﾝ"),
    "465241": MunicipalityEntry(MunicipalityCode("465241"), "鹿児島県", "宇検村", "ｶｺﾞｼﾏｹﾝ", "ｳｹﾝｿﾝ"),
    "465259": MunicipalityEntry(MunicipalityCode("465259"), "鹿児島県", "瀬戸内町", "ｶｺﾞｼﾏｹﾝ", "ｾﾄｳﾁﾁｮｳ"),
    "465275": MunicipalityEntry(MunicipalityCode("465275"), "鹿児島県", "龍郷町", "ｶｺﾞｼﾏｹﾝ", "ﾀﾂｺﾞｳﾁｮｳ"),
    "465291": MunicipalityEntry(MunicipalityCode("465291"), "鹿児島県", "喜界町", "ｶｺﾞｼﾏｹﾝ", "ｷｶｲﾁｮｳ"),
    "465305": MunicipalityEntry(MunicipalityCode("465305"), "鹿児島県", "徳之島町", "ｶｺﾞｼﾏｹﾝ", "ﾄｸﾉｼﾏﾁｮｳ"),
    "465313": MunicipalityEntry(MunicipalityCode("465313"), "鹿児島県", "天城町", "ｶｺﾞｼﾏｹﾝ", "ｱﾏｷﾞﾁｮｳ"),
    "465321": MunicipalityEntry(MunicipalityCode("465321"), "鹿児島県", "伊仙町", "ｶｺﾞｼﾏｹﾝ", "ｲｾﾝﾁｮｳ"),
    "465330": MunicipalityEntry(MunicipalityCode("465330"), "鹿児島県", "和泊町", "ｶｺﾞｼﾏｹﾝ", "ﾜﾄﾞﾏﾘﾁｮｳ"),
    "465348": MunicipalityEntry(MunicipalityCode("465348"), "鹿児島県", "知名町", "ｶｺﾞｼﾏｹﾝ", "ﾁﾅﾁｮｳ"),
    "465356": MunicipalityEntry(MunicipalityCode("465356"), "鹿児島県", "与論町", "ｶｺﾞｼﾏｹﾝ", "ﾖﾛﾝﾁｮｳ"),
    "470007": MunicipalityEntry(MunicipalityCode("470007"), "沖縄県", "", "ｵｷﾅﾜｹﾝ", ""),
    "472018": MunicipalityEntry(MunicipalityCode("472018"), "沖縄県", "那覇市", "ｵｷﾅﾜｹﾝ", "ﾅﾊｼ"),
    "472051": MunicipalityEntry(MunicipalityCode("472051"), "沖縄県", "宜野湾市", "ｵｷﾅﾜｹﾝ", "ｷﾞﾉﾜﾝｼ"),
    "472077": MunicipalityEntry(MunicipalityCode("472077"), "沖縄県", "石垣市", "ｵｷﾅﾜｹﾝ", "ｲｼｶﾞｷｼ"),
    "472085": MunicipalityEntry(MunicipalityCode("472085"), "沖縄県", "浦添市", "ｵｷﾅﾜｹﾝ", "ｳﾗｿｴｼ"),
    "472093": MunicipalityEntry(MunicipalityCode("472093"), "沖縄県", "名護市", "ｵｷﾅﾜｹﾝ", "ﾅｺﾞｼ"),
    "472107": MunicipalityEntry(MunicipalityCode("472107"), "沖縄県", "糸満市", "ｵｷﾅﾜｹﾝ", "ｲﾄﾏﾝｼ"),
    "472115": MunicipalityEntry(MunicipalityCode("472115"), "沖縄県", "沖縄市", "ｵｷﾅﾜｹﾝ", "ｵｷﾅﾜｼ"),
    "472123": MunicipalityEntry(MunicipalityCode("472123"), "沖縄県", "豊見城市", "ｵｷﾅﾜｹﾝ", "ﾄﾐｸﾞｽｸｼ"),
    "472131": MunicipalityEntry(MunicipalityCode("472131"), "沖縄県", "うるま市", "ｵｷﾅﾜｹﾝ", "ｳﾙﾏｼ"),
    "472140": MunicipalityEntry(MunicipalityCode("472140"), "沖縄県", "宮古島市", "ｵｷﾅﾜｹﾝ", "ﾐﾔｺｼﾞﾏｼ"),
    "472158": MunicipalityEntry(MunicipalityCode("472158"), "沖縄県", "南城市", "ｵｷﾅﾜｹﾝ", "ﾅﾝｼﾞｮｳｼ"),
    "473014": MunicipalityEntry(MunicipalityCode("473014"), "沖縄県", "国頭村", "ｵｷﾅﾜｹﾝ", "ｸﾆｶﾞﾐｿﾝ"),
    "473022": MunicipalityEntry(MunicipalityCode("473022"), "沖縄県", "大宜味村", "ｵｷﾅﾜｹﾝ", "ｵｵｷﾞﾐｿﾝ"),
    "473031": MunicipalityEntry(MunicipalityCode("473031"), "沖縄県", "東村", "ｵｷﾅﾜｹﾝ", "ﾋｶﾞｼｿﾝ"),
    "473065": MunicipalityEntry(MunicipalityCode("473065"), "沖縄県", "今帰仁村", "ｵｷﾅﾜｹﾝ", "ﾅｷｼﾞﾝｿﾝ"),
    "473081": MunicipalityEntry(MunicipalityCode("473081"), "沖縄県", "本部町", "ｵｷﾅﾜｹﾝ", "ﾓﾄﾌﾞﾁｮｳ"),
    "473111": MunicipalityEntry(MunicipalityCode("473111"), "沖縄県", "恩納村", "ｵｷﾅﾜｹﾝ", "ｵﾝﾅｿﾝ"),
    "473138": MunicipalityEntry(MunicipalityCode("473138"), "沖縄県", "宜野座村", "ｵｷﾅﾜｹﾝ", "ｷﾞﾉｻﾞｿﾝ"),
    "473146": MunicipalityEntry(MunicipalityCode("473146"), "沖縄県", "金武町", "ｵｷﾅﾜｹﾝ", "ｷﾝﾁｮｳ"),
    "473154": MunicipalityEntry(MunicipalityCode("473154"), "沖縄県", "伊江村", "ｵｷﾅﾜｹﾝ", "ｲｴｿﾝ"),
    "473243": MunicipalityEntry(MunicipalityCode("473243"), "沖縄県", "読谷村", "ｵｷﾅﾜｹﾝ", "ﾖﾐﾀﾝｿﾝ"),
    "473251": MunicipalityEntry(MunicipalityCode("473251"), "沖縄県", "嘉手納町", "ｵｷﾅﾜｹﾝ", "ｶﾃﾞﾅﾁｮｳ"),
    "473260": MunicipalityEntry(MunicipalityCode("473260"), "沖縄県", "北谷町", "ｵｷﾅﾜｹﾝ", "ﾁﾔﾀﾝﾁｮｳ"),
    "473278": MunicipalityEntry(MunicipalityCode("473278"), "沖縄県", "北中城村", "ｵｷﾅﾜｹﾝ", "ｷﾀﾅｶｸﾞｽｸｿﾝ"),
    "473286": MunicipalityEntry(MunicipalityCode("473286"), "沖縄県", "中城村", "ｵｷﾅﾜｹﾝ", "ﾅｶｸﾞｽｸｿﾝ"),
    "473294": MunicipalityEntry(MunicipalityCode("473294"), "沖縄県", "西原町", "ｵｷﾅﾜｹﾝ", "ﾆｼﾊﾗﾁｮｳ"),
    "473481": MunicipalityEntry(MunicipalityCode("473481"), "沖縄県", "与那原町", "ｵｷﾅﾜｹﾝ", "ﾖﾅﾊﾞﾙﾁｮｳ"),
    "473502": MunicipalityEntry(MunicipalityCode("473502"), "沖縄県", "南風原町", "ｵｷﾅﾜｹﾝ", "ﾊｴﾊﾞﾙﾁｮｳ"),
    "473537": MunicipalityEntry(MunicipalityCode("473537"), "沖縄県", "渡嘉敷村", "ｵｷﾅﾜｹﾝ", "ﾄｶｼｷｿﾝ"),
    "473545": MunicipalityEntry(MunicipalityCode("473545"), "沖縄県", "座間味村", "ｵｷﾅﾜｹﾝ", "ｻﾞﾏﾐｿﾝ"),
    "473553": MunicipalityEntry(MunicipalityCode("473553"), "沖縄県", "粟国村", "ｵｷﾅﾜｹﾝ", "ｱｸﾞﾆｿﾝ"),
    "473561": MunicipalityEntry(MunicipalityCode("473561"), "沖縄県", "渡名喜村", "ｵｷﾅﾜｹﾝ", "ﾄﾅｷｿﾝ"),
    "473570": MunicipalityEntry(MunicipalityCode("473570"), "沖縄県", "南大東村", "ｵｷﾅﾜｹﾝ", "ﾐﾅﾐﾀﾞｲﾄｳｿﾝ"),
    "473588": MunicipalityEntry(MunicipalityCode("473588"), "沖縄県", "北大東村", "ｵｷﾅﾜｹﾝ", "ｷﾀﾀﾞｲﾄｳｿﾝ"),
    "473596": MunicipalityEntry(MunicipalityCode("473596"), "沖縄県", "伊平屋村", "ｵｷﾅﾜｹﾝ", "ｲﾍﾔｿﾝ"),
    "473600": MunicipalityEntry(MunicipalityCode("473600"), "沖縄県", "伊是名村", "ｵｷﾅﾜｹﾝ", "ｲｾﾞﾅｿﾝ"),
    "473618": MunicipalityEntry(MunicipalityCode("473618"), "沖縄県", "久米島町", "ｵｷﾅﾜｹﾝ", "ｸﾒｼﾞﾏﾁｮｳ"),
    "473626": MunicipalityEntry(MunicipalityCode("473626"), "沖縄県", "八重瀬町", "ｵｷﾅﾜｹﾝ", "ﾔｴｾﾁｮｳ"),
    "473758": MunicipalityEntry(MunicipalityCode("473758"), "沖縄県", "多良間村", "ｵｷﾅﾜｹﾝ", "ﾀﾗﾏｿﾝ"),
    "473812": MunicipalityEntry(MunicipalityCode("473812"), "沖縄県", "竹富町", "ｵｷﾅﾜｹﾝ", "ﾀｹﾄﾐﾁｮｳ"),
    "473821": MunicipalityEntry(MunicipalityCode("473821"), "沖縄県", "与那国町", "ｵｷﾅﾜｹﾝ", "ﾖﾅｸﾞﾆﾁｮｳ"),
}


def get_municipality(code: str) -> MunicipalityEntry | None:
    """団体コードから検索。"""
    return _MUNICIPALITIES.get(code)


def find_municipalities(
    *,
    prefecture: str | None = None,
    name: str | None = None,
) -> list[MunicipalityEntry]:
    """都道府県名や市区町村名で部分一致検索。"""
    results: list[MunicipalityEntry] = []
    for entry in _MUNICIPALITIES.values():
        if prefecture and prefecture not in entry.prefecture_name:
            continue
        if name and name not in entry.city_name and name not in entry.prefecture_name:
            continue
        results.append(entry)
    return results
